@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -15,19 +15,24 @@
  * ---------------------------------------------------------------------------*/
 
 #include "arkode/arkode_arkstep.h"
+#include "arkode/arkode_lsrkstep.h"
 #include "diffusion_2D.hpp"
+#include "sunadaptcontroller/sunadaptcontroller_imexgus.h"
+#include "sunadaptcontroller/sunadaptcontroller_soderlind.h"
 
 struct UserOptions
 {
   // Integrator settings
-  sunrealtype rtol   = SUN_RCONST(1.0e-5);  // relative tolerance
-  sunrealtype atol   = SUN_RCONST(1.0e-10); // absolute tolerance
-  sunrealtype hfixed = ZERO;                // fixed step size
-  int order          = 3;                   // ARKode method order
-  int controller     = 0;                   // step size adaptivity method
-  int maxsteps       = 0;                   // max steps between outputs
-  int onestep        = 0;                   // one step mode, number of steps
-  bool linear        = true;                // linearly implicit RHS
+  sunrealtype rtol       = SUN_RCONST(1.0e-5);  // relative tolerance
+  sunrealtype atol       = SUN_RCONST(1.0e-10); // absolute tolerance
+  sunrealtype hfixed     = ZERO;                // fixed step size
+  int order              = 3;                   // ARKode method order
+  std::string controller = "I";                 // step size adaptivity method
+  int maxsteps           = 0;                   // max steps between outputs
+  int onestep            = 0;    // one step mode, number of steps
+  bool linear            = true; // linearly implicit RHS
+  bool implicit = true; // implicit (ARKStep) vs explicit STS (LSRKStep)
+  ARKODE_LSRKMethodType lsrkmethod = ARKODE_LSRK_RKC_2; // LSRK method type
 
   // Linear solver and preconditioner settings
   std::string ls       = "cg";  // linear solver to use
@@ -43,6 +48,14 @@ struct UserOptions
   void print();
 };
 
+// -----------------------------------------------------------------------------
+// LSRKStep-specific dominant eigenvalue function prototype
+// -----------------------------------------------------------------------------
+
+static int dom_eig(sunrealtype t, N_Vector y, N_Vector fn, sunrealtype* lambdaR,
+                   sunrealtype* lambdaI, void* user_data, N_Vector temp1,
+                   N_Vector temp2, N_Vector temp3);
+
 // -----------------------------------------------------------------------------
 // Main Program
 // -----------------------------------------------------------------------------
@@ -58,8 +71,8 @@ int main(int argc, char* argv[])
 
   // Create SUNDIALS context
   MPI_Comm comm    = MPI_COMM_WORLD;
-  SUNContext ctx   = NULL;
-  SUNProfiler prof = NULL;
+  SUNContext ctx   = nullptr;
+  SUNProfiler prof = nullptr;
 
   flag = SUNContext_Create(comm, &ctx);
   if (check_flag(&flag, "SUNContextCreate", 1)) { return 1; }
@@ -109,6 +122,17 @@ int main(int argc, char* argv[])
       return 1;
     }
 
+    // Return with error on unsupported LSRK method type
+    if (!uopts.implicit)
+    {
+      if ((uopts.lsrkmethod != ARKODE_LSRK_RKC_2) &&
+          (uopts.lsrkmethod != ARKODE_LSRK_RKL_2))
+      {
+        cerr << "ERROR: illegal lsrkmethod" << endl;
+        return 1;
+      }
+    }
+
     // -----------------------------
     // Setup parallel decomposition
     // -----------------------------
@@ -152,12 +176,8 @@ int main(int argc, char* argv[])
       if (check_flag((void*)(uout.error), "N_VClone", 0)) { return 1; }
     }
 
-    // ---------------------
-    // Create linear solver
-    // ---------------------
-
-    // Create linear solver
-    SUNLinearSolver LS = NULL;
+    // Set up implicit solver, if applicable
+    SUNLinearSolver LS = nullptr;
     SUNMatrix A        = nullptr;
 #if defined(USE_SUPERLU_DIST)
     // SuperLU-DIST objects
@@ -172,144 +192,176 @@ int main(int argc, char* argv[])
     sunindextype* A_col_idxs = nullptr;
     sunindextype* A_row_ptrs = nullptr;
 #endif
-
-    int prectype = (uopts.preconditioning) ? SUN_PREC_RIGHT : SUN_PREC_NONE;
-
-    if (uopts.ls == "cg")
+    if (uopts.implicit)
     {
-      LS = SUNLinSol_PCG(u, prectype, uopts.liniters, ctx);
-      if (check_flag((void*)LS, "SUNLinSol_PCG", 0)) { return 1; }
+      // ---------------------
+      // Create linear solver
+      // ---------------------
+
+      // Create linear solver
+
+      int prectype = (uopts.preconditioning) ? SUN_PREC_RIGHT : SUN_PREC_NONE;
+
+      if (uopts.ls == "cg")
+      {
+        LS = SUNLinSol_PCG(u, prectype, uopts.liniters, ctx);
+        if (check_flag((void*)LS, "SUNLinSol_PCG", 0)) { return 1; }
+      }
+      else if (uopts.ls == "gmres")
+      {
+        LS = SUNLinSol_SPGMR(u, prectype, uopts.liniters, ctx);
+        if (check_flag((void*)LS, "SUNLinSol_SPGMR", 0)) { return 1; }
+      }
+      else
+      {
+#if defined(USE_SUPERLU_DIST)
+        // Initialize SuperLU-DIST grid
+        superlu_gridinit(udata.comm_c, udata.npx, udata.npy, &grid);
+
+        // Create arrays for CSR matrix: data, column indices, and row pointers
+        sunindextype nnz_loc = 5 * udata.nodes_loc;
+
+        A_data = (sunrealtype*)malloc(nnz_loc * sizeof(sunrealtype));
+        if (check_flag((void*)A_data, "malloc Adata", 0)) return 1;
+
+        A_col_idxs = (sunindextype*)malloc(nnz_loc * sizeof(sunindextype));
+        if (check_flag((void*)A_col_idxs, "malloc Acolind", 0)) return 1;
+
+        A_row_ptrs =
+          (sunindextype*)malloc((udata.nodes_loc + 1) * sizeof(sunindextype));
+        if (check_flag((void*)A_row_ptrs, "malloc Arowptr", 0)) return 1;
+
+        // Create and initialize SuperLU_DIST structures
+        dCreate_CompRowLoc_Matrix_dist(&A_super, udata.nodes, udata.nodes,
+                                       nnz_loc, udata.nodes_loc, 0, A_data,
+                                       A_col_idxs, A_row_ptrs, SLU_NR_loc,
+                                       SLU_D, SLU_GE);
+        dScalePermstructInit(udata.nodes, udata.nodes, &A_scaleperm);
+        dLUstructInit(udata.nodes, &A_lu);
+        PStatInit(&A_stat);
+        set_default_options_dist(&A_opts);
+        A_opts.PrintStat = NO;
+
+        // SUNDIALS structures
+        A = SUNMatrix_SLUNRloc(&A_super, &grid, ctx);
+        if (check_flag((void*)A, "SUNMatrix_SLUNRloc", 0)) return 1;
+
+        LS = SUNLinSol_SuperLUDIST(u, A, &grid, &A_lu, &A_scaleperm, &A_solve,
+                                   &A_stat, &A_opts, ctx);
+        if (check_flag((void*)LS, "SUNLinSol_SuperLUDIST", 0)) return 1;
+
+        uopts.preconditioning = false;
+#else
+        std::cerr
+          << "ERROR: Benchmark was not built with SuperLU_DIST enabled\n";
+        return 1;
+#endif
+      }
+
+      // Allocate preconditioner workspace
+      if (uopts.preconditioning)
+      {
+        udata.diag = N_VClone(u);
+        if (check_flag((void*)(udata.diag), "N_VClone", 0)) { return 1; }
+      }
     }
-    else if (uopts.ls == "gmres")
+
+    // ----------------------
+    // Setup ARKStep/LSRKStep
+    // ----------------------
+
+    // Create integrator
+    void* arkode_mem = nullptr;
+    if (uopts.implicit)
     {
-      LS = SUNLinSol_SPGMR(u, prectype, uopts.liniters, ctx);
-      if (check_flag((void*)LS, "SUNLinSol_SPGMR", 0)) { return 1; }
+      arkode_mem = ARKStepCreate(nullptr, diffusion, ZERO, u, ctx);
+      if (check_flag((void*)arkode_mem, "ARKStepCreate", 0)) { return 1; }
     }
     else
     {
-#if defined(USE_SUPERLU_DIST)
-      // Initialize SuperLU-DIST grid
-      superlu_gridinit(udata.comm_c, udata.npx, udata.npy, &grid);
-
-      // Create arrays for CSR matrix: data, column indices, and row pointers
-      sunindextype nnz_loc = 5 * udata.nodes_loc;
-
-      A_data = (sunrealtype*)malloc(nnz_loc * sizeof(sunrealtype));
-      if (check_flag((void*)A_data, "malloc Adata", 0)) return 1;
-
-      A_col_idxs = (sunindextype*)malloc(nnz_loc * sizeof(sunindextype));
-      if (check_flag((void*)A_col_idxs, "malloc Acolind", 0)) return 1;
-
-      A_row_ptrs =
-        (sunindextype*)malloc((udata.nodes_loc + 1) * sizeof(sunindextype));
-      if (check_flag((void*)A_row_ptrs, "malloc Arowptr", 0)) return 1;
-
-      // Create and initialize SuperLU_DIST structures
-      dCreate_CompRowLoc_Matrix_dist(&A_super, udata.nodes, udata.nodes, nnz_loc,
-                                     udata.nodes_loc, 0, A_data, A_col_idxs,
-                                     A_row_ptrs, SLU_NR_loc, SLU_D, SLU_GE);
-      dScalePermstructInit(udata.nodes, udata.nodes, &A_scaleperm);
-      dLUstructInit(udata.nodes, &A_lu);
-      PStatInit(&A_stat);
-      set_default_options_dist(&A_opts);
-      A_opts.PrintStat = NO;
-
-      // SUNDIALS structures
-      A = SUNMatrix_SLUNRloc(&A_super, &grid, ctx);
-      if (check_flag((void*)A, "SUNMatrix_SLUNRloc", 0)) return 1;
-
-      LS = SUNLinSol_SuperLUDIST(u, A, &grid, &A_lu, &A_scaleperm, &A_solve,
-                                 &A_stat, &A_opts, ctx);
-      if (check_flag((void*)LS, "SUNLinSol_SuperLUDIST", 0)) return 1;
-
-      uopts.preconditioning = false;
-#else
-      std::cerr << "ERROR: Benchmark was not built with SuperLU_DIST enabled\n";
-      return 1;
-#endif
+      arkode_mem = LSRKStepCreateSTS(diffusion, ZERO, u, ctx);
+      if (check_flag((void*)arkode_mem, "LSRKStepCreateSTS", 0)) { return 1; }
     }
 
-    // Allocate preconditioner workspace
-    if (uopts.preconditioning)
-    {
-      udata.diag = N_VClone(u);
-      if (check_flag((void*)(udata.diag), "N_VClone", 0)) { return 1; }
-    }
-
-    // --------------
-    // Setup ARKStep
-    // --------------
-
-    // Create integrator
-    void* arkode_mem = ARKStepCreate(NULL, diffusion, ZERO, u, ctx);
-    if (check_flag((void*)arkode_mem, "ARKStepCreate", 0)) { return 1; }
-
     // Specify tolerances
-    flag = ARKStepSStolerances(arkode_mem, uopts.rtol, uopts.atol);
-    if (check_flag(&flag, "ARKStepSStolerances", 1)) { return 1; }
+    flag = ARKodeSStolerances(arkode_mem, uopts.rtol, uopts.atol);
+    if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
 
     // Attach user data
-    flag = ARKStepSetUserData(arkode_mem, (void*)&udata);
-    if (check_flag(&flag, "ARKStepSetUserData", 1)) { return 1; }
+    flag = ARKodeSetUserData(arkode_mem, (void*)&udata);
+    if (check_flag(&flag, "ARKodeSetUserData", 1)) { return 1; }
 
-    // Attach linear solver
-    flag = ARKStepSetLinearSolver(arkode_mem, LS, A);
-    if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) { return 1; }
+    // Configure implicit solver
+    if (uopts.implicit)
+    {
+      // Attach linear solver
+      flag = ARKodeSetLinearSolver(arkode_mem, LS, A);
+      if (check_flag(&flag, "ARKodeSetLinearSolver", 1)) { return 1; }
 
 #if defined(USE_SUPERLU_DIST)
-    if (uopts.ls == "sludist")
-    {
-      ARKStepSetJacFn(arkode_mem, diffusion_jac);
-      if (check_flag(&flag, "ARKStepSetJacFn", 1)) return 1;
-    }
+      if (uopts.ls == "sludist")
+      {
+        ARKodeSetJacFn(arkode_mem, diffusion_jac);
+        if (check_flag(&flag, "ARKodeSetJacFn", 1)) return 1;
+      }
 #endif
 
-    if (uopts.preconditioning)
-    {
-      // Attach preconditioner
-      flag = ARKStepSetPreconditioner(arkode_mem, PSetup, PSolve);
-      if (check_flag(&flag, "ARKStepSetPreconditioner", 1)) { return 1; }
+      if (uopts.preconditioning)
+      {
+        // Attach preconditioner
+        flag = ARKodeSetPreconditioner(arkode_mem, PSetup, PSolve);
+        if (check_flag(&flag, "ARKodeSetPreconditioner", 1)) { return 1; }
 
-      // Set linear solver setup frequency (update preconditioner)
-      flag = ARKStepSetLSetupFrequency(arkode_mem, uopts.msbp);
-      if (check_flag(&flag, "ARKStepSetLSetupFrequency", 1)) { return 1; }
+        // Set linear solver setup frequency (update preconditioner)
+        flag = ARKodeSetLSetupFrequency(arkode_mem, uopts.msbp);
+        if (check_flag(&flag, "ARKodeSetLSetupFrequency", 1)) { return 1; }
+      }
+
+      // Set linear solver tolerance factor
+      flag = ARKodeSetEpsLin(arkode_mem, uopts.epslin);
+      if (check_flag(&flag, "ARKodeSetEpsLin", 1)) { return 1; }
+
+      // Select method order
+      flag = ARKodeSetOrder(arkode_mem, uopts.order);
+      if (check_flag(&flag, "ARKodeSetOrder", 1)) { return 1; }
+
+      // Specify linearly implicit non-time-dependent RHS
+      if (uopts.linear)
+      {
+        flag = ARKodeSetLinear(arkode_mem, 0);
+        if (check_flag(&flag, "ARKodeSetLinear", 1)) { return 1; }
+      }
     }
+    else // Configure explicit STS solver
+    {
+      // Select LSRK method
+      flag = LSRKStepSetSTSMethod(arkode_mem, uopts.lsrkmethod);
+      if (check_flag(&flag, "LSRKStepSetSTSMethod", 1)) { return 1; }
 
-    // Set linear solver tolerance factor
-    flag = ARKStepSetEpsLin(arkode_mem, uopts.epslin);
-    if (check_flag(&flag, "ARKStepSetEpsLin", 1)) { return 1; }
-
-    // Select method order
-    flag = ARKStepSetOrder(arkode_mem, uopts.order);
-    if (check_flag(&flag, "ARKStepSetOrder", 1)) { return 1; }
+      // Provide dominant eigenvalue function
+      flag = LSRKStepSetDomEigFn(arkode_mem, dom_eig);
+      if (check_flag(&flag, "LSRKStepSetDomEigFn", 1)) { return 1; }
+    }
 
     // Set fixed step size or adaptivity method
     if (uopts.hfixed > ZERO)
     {
-      flag = ARKStepSetFixedStep(arkode_mem, uopts.hfixed);
-      if (check_flag(&flag, "ARKStepSetFixedStep", 1)) { return 1; }
+      flag = ARKodeSetFixedStep(arkode_mem, uopts.hfixed);
+      if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
     }
     else
     {
-      flag = ARKStepSetAdaptivityMethod(arkode_mem, uopts.controller, SUNTRUE,
-                                        SUNFALSE, NULL);
-      if (check_flag(&flag, "ARKStepSetAdaptivityMethod", 1)) { return 1; }
-    }
-
-    // Specify linearly implicit non-time-dependent RHS
-    if (uopts.linear)
-    {
-      flag = ARKStepSetLinear(arkode_mem, 0);
-      if (check_flag(&flag, "ARKStepSetLinear", 1)) { return 1; }
+      flag = ARKodeSetAdaptControllerByName(arkode_mem, uopts.controller.c_str());
+      if (check_flag(&flag, "ARKodeSetAdaptControllerByName", 1)) { return 1; }
     }
 
     // Set max steps between outputs
-    flag = ARKStepSetMaxNumSteps(arkode_mem, uopts.maxsteps);
-    if (check_flag(&flag, "ARKStepSetMaxNumSteps", 1)) { return 1; }
+    flag = ARKodeSetMaxNumSteps(arkode_mem, uopts.maxsteps);
+    if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
     // Set stopping time
-    flag = ARKStepSetStopTime(arkode_mem, udata.tf);
-    if (check_flag(&flag, "ARKStepSetStopTime", 1)) { return 1; }
+    flag = ARKodeSetStopTime(arkode_mem, udata.tf);
+    if (check_flag(&flag, "ARKodeSetStopTime", 1)) { return 1; }
 
     // -----------------------
     // Loop over output times
@@ -329,7 +381,7 @@ int main(int argc, char* argv[])
     sunrealtype dTout = udata.tf / uout.nout;
     sunrealtype tout  = dTout;
 
-    // Inital output
+    // Initial output
     flag = uout.open(&udata);
     if (check_flag(&flag, "UserOutput::open", 1)) { return 1; }
 
@@ -341,8 +393,8 @@ int main(int argc, char* argv[])
       SUNDIALS_MARK_BEGIN(prof, "Evolve");
 
       // Evolve in time
-      flag = ARKStepEvolve(arkode_mem, tout, u, &t, stepmode);
-      if (check_flag(&flag, "ARKStepEvolve", 1)) { break; }
+      flag = ARKodeEvolve(arkode_mem, tout, u, &t, stepmode);
+      if (check_flag(&flag, "ARKodeEvolve", 1)) { break; }
 
       SUNDIALS_MARK_END(prof, "Evolve");
 
@@ -367,8 +419,8 @@ int main(int argc, char* argv[])
     if (outproc)
     {
       cout << "Final integrator statistics:" << endl;
-      flag = ARKStepPrintAllStats(arkode_mem, stdout, SUN_OUTPUTFORMAT_TABLE);
-      if (check_flag(&flag, "ARKStepPrintAllStats", 1)) { return 1; }
+      flag = ARKodePrintAllStats(arkode_mem, stdout, SUN_OUTPUTFORMAT_TABLE);
+      if (check_flag(&flag, "ARKodePrintAllStats", 1)) { return 1; }
     }
 
     // ---------
@@ -378,21 +430,24 @@ int main(int argc, char* argv[])
     // Free MPI Cartesian communicator
     MPI_Comm_free(&(udata.comm_c));
 
-    ARKStepFree(&arkode_mem);
-    SUNLinSolFree(LS);
-
-    // Free the SuperLU_DIST structures (also frees user allocated arrays
-    // A_data, A_col_idxs, and A_row_ptrs)
-#if defined(USE_SUPERLU_DIST)
-    if (uopts.ls == "sludist")
+    ARKodeFree(&arkode_mem);
+    if (uopts.implicit)
     {
-      PStatFree(&A_stat);
-      dScalePermstructFree(&A_scaleperm);
-      dLUstructFree(&A_lu);
-      Destroy_CompRowLoc_Matrix_dist(&A_super);
-      superlu_gridexit(&grid);
-    }
+      SUNLinSolFree(LS);
+
+      // Free the SuperLU_DIST structures (also frees user allocated arrays
+      // A_data, A_col_idxs, and A_row_ptrs)
+#if defined(USE_SUPERLU_DIST)
+      if (uopts.ls == "sludist")
+      {
+        PStatFree(&A_stat);
+        dScalePermstructFree(&A_scaleperm);
+        dLUstructFree(&A_lu);
+        Destroy_CompRowLoc_Matrix_dist(&A_super);
+        superlu_gridexit(&grid);
+      }
 #endif
+    }
 
     // Free vectors
 #if defined(USE_HIP) || defined(USE_CUDA)
@@ -409,6 +464,26 @@ int main(int argc, char* argv[])
   return 0;
 }
 
+// -----------------------------------------------------------------------------
+// Dominant eigenvalue estimation function
+// -----------------------------------------------------------------------------
+
+static int dom_eig(sunrealtype t, N_Vector y, N_Vector fn, sunrealtype* lambdaR,
+                   sunrealtype* lambdaI, void* user_data, N_Vector temp1,
+                   N_Vector temp2, N_Vector temp3)
+{
+  // Access problem data
+  UserData* udata = (UserData*)user_data;
+
+  // Fill in spectral radius value
+  *lambdaR = -SUN_RCONST(8.0) * std::max(udata->kx / udata->dx / udata->dx,
+                                         udata->ky / udata->dy / udata->dy);
+  *lambdaI = SUN_RCONST(0.0);
+
+  // return with success
+  return 0;
+}
+
 // -----------------------------------------------------------------------------
 // UserOptions Helper functions
 // -----------------------------------------------------------------------------
@@ -445,6 +520,13 @@ int UserOptions::parse_args(vector<string>& args, bool outproc)
     args.erase(it, it + 2);
   }
 
+  it = find(args.begin(), args.end(), "--explicitSTS");
+  if (it != args.end())
+  {
+    implicit = false;
+    args.erase(it);
+  }
+
   it = find(args.begin(), args.end(), "--order");
   if (it != args.end())
   {
@@ -452,10 +534,17 @@ int UserOptions::parse_args(vector<string>& args, bool outproc)
     args.erase(it, it + 2);
   }
 
+  it = find(args.begin(), args.end(), "--lsrkmethod");
+  if (it != args.end())
+  {
+    lsrkmethod = (ARKODE_LSRKMethodType)stoi(*(it + 1));
+    args.erase(it, it + 2);
+  }
+
   it = find(args.begin(), args.end(), "--controller");
   if (it != args.end())
   {
-    controller = stoi(*(it + 1));
+    controller = *(it + 1);
     args.erase(it, it + 2);
   }
 
@@ -524,17 +613,23 @@ void UserOptions::help()
   cout << endl;
   cout << "Integrator command line options:" << endl;
   cout << "  --rtol <rtol>           : relative tolerance" << endl;
-  cout << "  --atol <atol>           : absoltue tolerance" << endl;
+  cout << "  --atol <atol>           : absolute tolerance" << endl;
+  cout << "  --controller <ctr>      : time step adaptivity controller" << endl;
+  cout << "  --fixedstep <step>      : used fixed step size" << endl;
+  cout << "  --explicitSTS           : use LSRKStep (instead of ARKStep)" << endl;
+  cout << endl;
+  cout << "Implicit (ARKStep) solver command line options:" << endl;
   cout << "  --nonlinear             : disable linearly implicit flag" << endl;
   cout << "  --order <ord>           : method order" << endl;
-  cout << "  --fixedstep <step>      : used fixed step size" << endl;
-  cout << "  --controller <ctr>      : time step adaptivity controller" << endl;
   cout << "  --ls <cg|gmres|sludist> : linear solver" << endl;
   cout << "  --lsinfo                : output residual history" << endl;
   cout << "  --liniters <iters>      : max number of iterations" << endl;
   cout << "  --epslin <factor>       : linear tolerance factor" << endl;
   cout << "  --noprec                : disable preconditioner" << endl;
   cout << "  --msbp <steps>          : max steps between prec setups" << endl;
+  cout << endl;
+  cout << "Explicit STS (LSRKStep) solver command line options:" << endl;
+  cout << "  --lsrkmethod            : LSRK method choice" << endl;
 }
 
 // Print user options
@@ -545,39 +640,57 @@ void UserOptions::print()
   cout << " --------------------------------- " << endl;
   cout << " rtol        = " << rtol << endl;
   cout << " atol        = " << atol << endl;
-  cout << " hfixed      = " << hfixed << endl;
-  cout << " order       = " << order << endl;
   cout << " controller  = " << controller << endl;
-  cout << " max steps   = " << maxsteps << endl;
-  cout << " linear RHS  = " << linear << endl;
+  cout << " hfixed      = " << hfixed << endl;
   cout << " --------------------------------- " << endl;
-
   cout << endl;
-  if (ls == "sludist")
+  if (implicit)
   {
-    cout << " Linear solver options:" << endl;
+    cout << " ARKStep options:" << endl;
     cout << " --------------------------------- " << endl;
+    cout << " order       = " << order << endl;
+    cout << " max steps   = " << maxsteps << endl;
+    cout << " linear RHS  = " << linear << endl;
+    cout << " --------------------------------- " << endl;
+    cout << endl;
+    if (ls == "sludist")
+    {
+      cout << " Linear solver options:" << endl;
+      cout << " --------------------------------- " << endl;
 #if defined(HAVE_HIP)
-    cout << " LS       = SuperLU_DIST (HIP enabled)" << endl;
+      cout << " LS       = SuperLU_DIST (HIP enabled)" << endl;
 #elif defined(HAVE_CUDA)
-    cout << " LS       = SuperLU_DIST (CUDA enabled)" << endl;
+      cout << " LS       = SuperLU_DIST (CUDA enabled)" << endl;
 #else
-    cout << " LS       = SuperLU_DIST" << endl;
+      cout << " LS       = SuperLU_DIST" << endl;
 #endif
-    cout << " LS info  = " << lsinfo << endl;
-    cout << " msbp     = " << msbp << endl;
-    cout << " --------------------------------- " << endl;
+      cout << " LS info  = " << lsinfo << endl;
+      cout << " msbp     = " << msbp << endl;
+      cout << " --------------------------------- " << endl;
+    }
+    else
+    {
+      cout << " Linear solver options:" << endl;
+      cout << " --------------------------------- " << endl;
+      cout << " LS       = " << ls << endl;
+      cout << " precond  = " << preconditioning << endl;
+      cout << " LS info  = " << lsinfo << endl;
+      cout << " LS iters = " << liniters << endl;
+      cout << " msbp     = " << msbp << endl;
+      cout << " epslin   = " << epslin << endl;
+      cout << " --------------------------------- " << endl;
+    }
   }
   else
   {
-    cout << " Linear solver options:" << endl;
+    cout << " LSRKStep options:" << endl;
     cout << " --------------------------------- " << endl;
-    cout << " LS       = " << ls << endl;
-    cout << " precond  = " << preconditioning << endl;
-    cout << " LS info  = " << lsinfo << endl;
-    cout << " LS iters = " << liniters << endl;
-    cout << " msbp     = " << msbp << endl;
-    cout << " epslin   = " << epslin << endl;
+    switch (lsrkmethod)
+    {
+    case (ARKODE_LSRK_RKC_2): cout << " method = RKC_2 " << endl; break;
+    case (ARKODE_LSRK_RKL_2): cout << " method = RKL_2 " << endl; break;
+    default: cout << " ERROR: illegal lsrkmethod " << endl;
+    }
     cout << " --------------------------------- " << endl;
   }
 }
