@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -310,7 +310,7 @@ int main(int argc, char* argv[])
     sunrealtype dTout = udata.tf / uout.nout;
     sunrealtype tout  = dTout;
 
-    // Inital output
+    // Initial output
     flag = uout.open(&udata);
     if (check_flag(&flag, "UserOutput::open", 1)) { return 1; }
 
@@ -479,7 +479,7 @@ void UserOptions::help()
   cout << endl;
   cout << "Integrator command line options:" << endl;
   cout << "  --rtol <rtol>           : relative tolerance" << endl;
-  cout << "  --atol <atol>           : absoltue tolerance" << endl;
+  cout << "  --atol <atol>           : absolute tolerance" << endl;
   cout << "  --ls <cg|gmres|sludist> : linear solver" << endl;
   cout << "  --lsinfo                : output residual history" << endl;
   cout << "  --liniters <iters>      : max number of iterations" << endl;
