@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner, Cody J. Balos @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -22,7 +22,7 @@
  *    w_t = -c * w_x + (B - w) / ep - w * u
  *
  * for t in [0, 10], x in [0, xmax] with periodic boundary conditions. The
- * initial condition is a Gaussian pertubation of the steady state
+ * initial condition is a Gaussian perturbation of the steady state
  * solution without advection
  *
  *    u(0,x) = k1 * A / k4 + p(x)
@@ -93,12 +93,14 @@ using EXEC_POLICY                = RAJA::hip_exec<512, false>;
 constexpr auto LocalNvector      = N_VNew_Hip;
 constexpr auto CopyVecFromDevice = N_VCopyFromDevice_Hip;
 
-#else
+#elif USE_SERIAL_NVEC
 #define NVECTOR_ID_STRING "Serial"
 using EXEC_POLICY           = RAJA::seq_exec;
 constexpr auto LocalNvector = N_VNew_Serial;
 #define CopyVecFromDevice(v)
 
+#else
+#error "Unknown backend"
 #endif // USE_RAJA_NVEC
 
 #ifdef USE_CUDA_OR_HIP
@@ -246,20 +248,20 @@ int EvolveProblemIMEX(SUNContext ctx, N_Vector y, UserData* udata,
   if (check_retval((void*)arkode_mem, "ARKStepCreate", 0)) { return 1; }
 
   /* Select the method order */
-  retval = ARKStepSetOrder(arkode_mem, uopt->order);
-  if (check_retval(&retval, "ARKStepSetOrder", 1)) { return 1; }
+  retval = ARKodeSetOrder(arkode_mem, uopt->order);
+  if (check_retval(&retval, "ARKodeSetOrder", 1)) { return 1; }
 
   /* Attach user data */
-  retval = ARKStepSetUserData(arkode_mem, (void*)udata);
-  if (check_retval(&retval, "ARKStepSetUserData*", 1)) { return 1; }
+  retval = ARKodeSetUserData(arkode_mem, (void*)udata);
+  if (check_retval(&retval, "ARKodeSetUserData*", 1)) { return 1; }
 
   /* Specify tolerances */
-  retval = ARKStepSStolerances(arkode_mem, uopt->rtol, uopt->atol);
-  if (check_retval(&retval, "ARKStepSStolerances", 1)) { return 1; }
+  retval = ARKodeSStolerances(arkode_mem, uopt->rtol, uopt->atol);
+  if (check_retval(&retval, "ARKodeSStolerances", 1)) { return 1; }
 
   /* Increase the max number of steps allowed between outputs */
-  retval = ARKStepSetMaxNumSteps(arkode_mem, 100000);
-  if (check_retval(&retval, "ARKStepSetMaxNumSteps", 1)) { return 1; }
+  retval = ARKodeSetMaxNumSteps(arkode_mem, 100000);
+  if (check_retval(&retval, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
   /* Create the (non)linear solver */
   if (uopt->global)
@@ -269,20 +271,20 @@ int EvolveProblemIMEX(SUNContext ctx, N_Vector y, UserData* udata,
     if (check_retval((void*)NLS, "SUNNonlinSol_Newton", 0)) { return 1; }
 
     /* Attach nonlinear solver */
-    retval = ARKStepSetNonlinearSolver(arkode_mem, NLS);
-    if (check_retval(&retval, "ARKStepSetNonlinearSolver", 1)) { return 1; }
+    retval = ARKodeSetNonlinearSolver(arkode_mem, NLS);
+    if (check_retval(&retval, "ARKodeSetNonlinearSolver", 1)) { return 1; }
 
     /* Create linear solver */
     LS = SUNLinSol_SPGMR(y, SUN_PREC_LEFT, 0, ctx);
     if (check_retval((void*)LS, "SUNLinSol_SPGMR", 0)) { return 1; }
 
     /* Attach linear solver */
-    retval = ARKStepSetLinearSolver(arkode_mem, LS, NULL);
-    if (check_retval(&retval, "ARKStepSetLinearSolver", 1)) { return 1; }
+    retval = ARKodeSetLinearSolver(arkode_mem, LS, NULL);
+    if (check_retval(&retval, "ARKodeSetLinearSolver", 1)) { return 1; }
 
     /* Attach preconditioner */
-    retval = ARKStepSetPreconditioner(arkode_mem, NULL, PSolve);
-    if (check_retval(&retval, "ARKStepSetPreconditioner", 1)) { return 1; }
+    retval = ARKodeSetPreconditioner(arkode_mem, NULL, PSolve);
+    if (check_retval(&retval, "ARKodeSetPreconditioner", 1)) { return 1; }
   }
   else
   {
@@ -292,8 +294,8 @@ int EvolveProblemIMEX(SUNContext ctx, N_Vector y, UserData* udata,
     if (check_retval((void*)NLS, "TaskLocalNewton", 0)) { return 1; }
 
     /* Attach nonlinear solver */
-    retval = ARKStepSetNonlinearSolver(arkode_mem, NLS);
-    if (check_retval(&retval, "ARKStepSetNonlinearSolver", 1)) { return 1; }
+    retval = ARKodeSetNonlinearSolver(arkode_mem, NLS);
+    if (check_retval(&retval, "ARKodeSetNonlinearSolver", 1)) { return 1; }
   }
 
   /* Output initial condition */
@@ -313,8 +315,8 @@ int EvolveProblemIMEX(SUNContext ctx, N_Vector y, UserData* udata,
 
   do {
     /* Integrate to output time */
-    retval = ARKStepEvolve(arkode_mem, tout, y, &t, ARK_NORMAL);
-    if (check_retval(&retval, "ARKStepEvolve", 1)) { break; }
+    retval = ARKodeEvolve(arkode_mem, tout, y, &t, ARK_NORMAL);
+    if (check_retval(&retval, "ARKodeEvolve", 1)) { break; }
 
     /* Output state */
     WriteOutput(t, y, udata, uopt);
@@ -328,24 +330,26 @@ int EvolveProblemIMEX(SUNContext ctx, N_Vector y, UserData* udata,
   while (iout < uopt->nout);
 
   /* Get final statistics */
-  retval = ARKStepGetNumSteps(arkode_mem, &nst);
-  check_retval(&retval, "ARKStepGetNumSteps", 1);
-  retval = ARKStepGetNumStepAttempts(arkode_mem, &nst_a);
-  check_retval(&retval, "ARKStepGetNumStepAttempts", 1);
-  retval = ARKStepGetNumRhsEvals(arkode_mem, &nfe, &nfi);
-  check_retval(&retval, "ARKStepGetNumRhsEvals", 1);
-  retval = ARKStepGetNumErrTestFails(arkode_mem, &netf);
-  check_retval(&retval, "ARKStepGetNumErrTestFails", 1);
-  retval = ARKStepGetNumNonlinSolvIters(arkode_mem, &nni);
-  check_retval(&retval, "ARKStepGetNumNonlinSolvIters", 1);
-  retval = ARKStepGetNumNonlinSolvConvFails(arkode_mem, &ncnf);
-  check_retval(&retval, "ARKStepGetNumNonlinSolvConvFails", 1);
+  retval = ARKodeGetNumSteps(arkode_mem, &nst);
+  check_retval(&retval, "ARKodeGetNumSteps", 1);
+  retval = ARKodeGetNumStepAttempts(arkode_mem, &nst_a);
+  check_retval(&retval, "ARKodeGetNumStepAttempts", 1);
+  retval = ARKodeGetNumRhsEvals(arkode_mem, 0, &nfe);
+  check_retval(&retval, "ARKodeGetNumRhsEvals", 1);
+  retval = ARKodeGetNumRhsEvals(arkode_mem, 1, &nfi);
+  check_retval(&retval, "ARKodeGetNumRhsEvals", 1);
+  retval = ARKodeGetNumErrTestFails(arkode_mem, &netf);
+  check_retval(&retval, "ARKodeGetNumErrTestFails", 1);
+  retval = ARKodeGetNumNonlinSolvIters(arkode_mem, &nni);
+  check_retval(&retval, "ARKodeGetNumNonlinSolvIters", 1);
+  retval = ARKodeGetNumNonlinSolvConvFails(arkode_mem, &ncnf);
+  check_retval(&retval, "ARKodeGetNumNonlinSolvConvFails", 1);
   if (uopt->global)
   {
-    retval = ARKStepGetNumLinIters(arkode_mem, &nli);
-    check_retval(&retval, "ARKStepGetNumLinIters", 1);
-    retval = ARKStepGetNumPrecSolves(arkode_mem, &npsol);
-    check_retval(&retval, "ARKStepGetNumPrecSolves", 1);
+    retval = ARKodeGetNumLinIters(arkode_mem, &nli);
+    check_retval(&retval, "ARKodeGetNumLinIters", 1);
+    retval = ARKodeGetNumPrecSolves(arkode_mem, &npsol);
+    check_retval(&retval, "ARKodeGetNumPrecSolves", 1);
   }
 
   /* Print final statistics */
@@ -366,7 +370,7 @@ int EvolveProblemIMEX(SUNContext ctx, N_Vector y, UserData* udata,
   }
 
   /* Clean up */
-  ARKStepFree(&arkode_mem);
+  ARKodeFree(&arkode_mem);
   SUNNonlinSolFree(NLS);
   if (LS) { SUNLinSolFree(LS); }
 
@@ -390,20 +394,20 @@ int EvolveProblemExplicit(SUNContext ctx, N_Vector y, UserData* udata,
   if (check_retval((void*)arkode_mem, "ERKStepCreate", 0)) { return 1; }
 
   /* Select the method order */
-  retval = ERKStepSetOrder(arkode_mem, uopt->order);
-  if (check_retval(&retval, "ERKStepSetOrder", 1)) { return 1; }
+  retval = ARKodeSetOrder(arkode_mem, uopt->order);
+  if (check_retval(&retval, "ARKodeSetOrder", 1)) { return 1; }
 
   /* Attach user data */
-  retval = ERKStepSetUserData(arkode_mem, (void*)udata);
-  if (check_retval(&retval, "ERKStepSetUserData", 1)) { return 1; }
+  retval = ARKodeSetUserData(arkode_mem, (void*)udata);
+  if (check_retval(&retval, "ARKodeSetUserData", 1)) { return 1; }
 
   /* Specify tolerances */
-  retval = ERKStepSStolerances(arkode_mem, uopt->rtol, uopt->atol);
-  if (check_retval(&retval, "ERKStepSStolerances", 1)) { return 1; }
+  retval = ARKodeSStolerances(arkode_mem, uopt->rtol, uopt->atol);
+  if (check_retval(&retval, "ARKodeSStolerances", 1)) { return 1; }
 
   /* Increase the max number of steps allowed between outputs */
-  retval = ERKStepSetMaxNumSteps(arkode_mem, 1000000);
-  if (check_retval(&retval, "ERKStepSetMaxNumSteps", 1)) { return 1; }
+  retval = ARKodeSetMaxNumSteps(arkode_mem, 1000000);
+  if (check_retval(&retval, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
   /* Output initial condition */
   if (udata->myid == 0 && uopt->monitor)
@@ -422,8 +426,8 @@ int EvolveProblemExplicit(SUNContext ctx, N_Vector y, UserData* udata,
 
   do {
     /* Integrate to output time */
-    retval = ERKStepEvolve(arkode_mem, tout, y, &t, ARK_NORMAL);
-    if (check_retval(&retval, "ERKStepEvolve", 1)) { break; }
+    retval = ARKodeEvolve(arkode_mem, tout, y, &t, ARK_NORMAL);
+    if (check_retval(&retval, "ARKodeEvolve", 1)) { break; }
 
     /* Output state */
     WriteOutput(t, y, udata, uopt);
@@ -437,14 +441,14 @@ int EvolveProblemExplicit(SUNContext ctx, N_Vector y, UserData* udata,
   while (iout < uopt->nout);
 
   /* Get final statistics */
-  retval = ERKStepGetNumSteps(arkode_mem, &nst);
-  check_retval(&retval, "ERKStepGetNumSteps", 1);
-  retval = ERKStepGetNumStepAttempts(arkode_mem, &nst_a);
-  check_retval(&retval, "ERKStepGetNumStepAttempts", 1);
-  retval = ERKStepGetNumRhsEvals(arkode_mem, &nfe);
-  check_retval(&retval, "ERKStepGetNumRhsEvals", 1);
-  retval = ERKStepGetNumErrTestFails(arkode_mem, &netf);
-  check_retval(&retval, "ERKStepGetNumErrTestFails", 1);
+  retval = ARKodeGetNumSteps(arkode_mem, &nst);
+  check_retval(&retval, "ARKodeGetNumSteps", 1);
+  retval = ARKodeGetNumStepAttempts(arkode_mem, &nst_a);
+  check_retval(&retval, "ARKodeGetNumStepAttempts", 1);
+  retval = ARKodeGetNumRhsEvals(arkode_mem, 0, &nfe);
+  check_retval(&retval, "ARKodeGetNumRhsEvals", 1);
+  retval = ARKodeGetNumErrTestFails(arkode_mem, &netf);
+  check_retval(&retval, "ARKodeGetNumErrTestFails", 1);
 
   /* Print final statistics */
   if (udata->myid == 0)
@@ -456,7 +460,7 @@ int EvolveProblemExplicit(SUNContext ctx, N_Vector y, UserData* udata,
   }
 
   /* Clean up */
-  ERKStepFree(&arkode_mem);
+  ARKodeFree(&arkode_mem);
 
   /* Return success */
   return (0);
@@ -911,9 +915,9 @@ int TaskLocalNlsResidual(N_Vector ycor, N_Vector F, void* arkode_mem)
   double tcur, gamma;
   void* user_data;
 
-  retval = ARKStepGetNonlinearSystemData(arkode_mem, &tcur, &zpred, &z, &Fi,
-                                         &gamma, &sdata, &user_data);
-  if (check_retval((void*)&retval, "ARKStepGetNonlinearSystemData", 1))
+  retval = ARKodeGetNonlinearSystemData(arkode_mem, &tcur, &zpred, &z, &Fi,
+                                        &gamma, &sdata, &user_data);
+  if (check_retval((void*)&retval, "ARKodeGetNonlinearSystemData", 1))
   {
     return (-1);
   }
@@ -956,9 +960,9 @@ int TaskLocalLSolve(N_Vector delta, void* arkode_mem)
   double tcur, gamma;
   void* user_data = NULL;
 
-  retval = ARKStepGetNonlinearSystemData(arkode_mem, &tcur, &zpred, &z, &Fi,
-                                         &gamma, &sdata, &user_data);
-  if (check_retval((void*)&retval, "ARKStepGetNonlinearSystemData", 1))
+  retval = ARKodeGetNonlinearSystemData(arkode_mem, &tcur, &zpred, &z, &Fi,
+                                        &gamma, &sdata, &user_data);
+  if (check_retval((void*)&retval, "ARKodeGetNonlinearSystemData", 1))
   {
     return (-1);
   }
@@ -1086,7 +1090,6 @@ int TaskLocalNewton_GetNumConvFails(SUNNonlinearSolver NLS, long int* nconvfails
 
 SUNNonlinearSolver TaskLocalNewton(SUNContext ctx, N_Vector y)
 {
-  void* tmp_comm;
   SUNNonlinearSolver NLS;
   TaskLocalNewton_Content content;
 
@@ -1355,9 +1358,11 @@ int EnableFusedVectorOps(N_Vector y)
 #elif defined(USE_OMPDEV_NVEC)
   retval = N_VEnableFusedOps_OpenMPDEV(N_VGetLocalVector_MPIPlusX(y), 1);
   if (check_retval(&retval, "N_VEnableFusedOps_OpenMPDEV", 1)) return (-1);
-#else
+#elif defined(USE_SERIAL_NVEC)
   retval = N_VEnableFusedOps_Serial(N_VGetLocalVector_MPIPlusX(y), 1);
   if (check_retval(&retval, "N_VEnableFusedOps_Serial", 1)) { return (-1); }
+#else
+#error "Unknown backend"
 #endif
 
   return (0);
@@ -1410,18 +1415,18 @@ int SetupProblem(int argc, char* argv[], UserData* udata, UserOptions* uopt,
   udata->WFID = NULL;
 
   /* set default integrator options */
-  uopt->order     = 3;          /* method order             */
-  uopt->expl      = 0;          /* imex or explicit         */
-  uopt->t0        = 0.0;        /* initial time             */
-  uopt->tf        = 10.0;       /* final time               */
-  uopt->rtol      = 1.0e-6;     /* relative tolerance       */
-  uopt->atol      = 1.0e-9;     /* absolute tolerance       */
-  uopt->global    = 0;          /* use global NLS           */
-  uopt->fused     = 0;          /* use fused vector ops     */
-  uopt->monitor   = 0;          /* print solution to screen */
-  uopt->printtime = 0;          /* print timing             */
-  uopt->nout      = 40;         /* number of output times   */
-  uopt->outputdir = (char*)"."; /* output directory         */
+  uopt->order     = 3;      /* method order             */
+  uopt->expl      = 0;      /* imex or explicit         */
+  uopt->t0        = 0.0;    /* initial time             */
+  uopt->tf        = 10.0;   /* final time               */
+  uopt->rtol      = 1.0e-6; /* relative tolerance       */
+  uopt->atol      = 1.0e-9; /* absolute tolerance       */
+  uopt->global    = 0;      /* use global NLS           */
+  uopt->fused     = 0;      /* use fused vector ops     */
+  uopt->monitor   = 0;      /* print solution to screen */
+  uopt->printtime = 0;      /* print timing             */
+  uopt->nout      = 40;     /* number of output times   */
+  uopt->outputdir = ".";    /* output directory         */
 
   /* check for input args */
   if (argc > 1)
@@ -1562,11 +1567,13 @@ int SetupProblem(int argc, char* argv[], UserData* udata, UserOptions* uopt,
 
   udata->Erecv = (double*)omp_target_alloc(udata->nvar * sizeof(double), dev);
   if (check_retval((void*)udata->Erecv, "omp_target_alloc", 0)) return 1;
-#else
+#elif defined(USE_SERIAL_NVEC)
   udata->Wsend = new double[udata->nvar];
   udata->Wrecv = new double[udata->nvar];
   udata->Esend = new double[udata->nvar];
   udata->Erecv = new double[udata->nvar];
+#else
+#error "Unknown backend"
 #endif
 
   /* Create the solution masks */
@@ -1670,11 +1677,13 @@ UserData::~UserData()
   omp_target_free(Wrecv);
   omp_target_free(Esend);
   omp_target_free(Erecv);
-#else
+#elif USE_SERIAL_NVEC
   delete[] Wsend;
   delete[] Wrecv;
   delete[] Esend;
   delete[] Erecv;
+#else
+#error "Unknown backend"
 #endif
 
   /* close output streams */
@@ -1730,7 +1739,7 @@ void InputError(char* name)
  * opt == 0  means the function allocates memory and returns a
  *           pointer so check if a NULL pointer was returned
  * opt == 1  means the function returns an integer where a
- *           value < 0 indicates an error occured
+ *           value < 0 indicates an error occurred
  * --------------------------------------------------------------*/
 int check_retval(void* returnvalue, const char* funcname, int opt)
 {
