@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -16,7 +16,7 @@
  *   u_t = Dux u_xx + Duy u_yy + A + u * u * v - (B + 1) * u
  *   v_t = Dvx u_xx + Dvy u_yy + B * u - u * u * v
  *
- * where u and v represent the concentrations of the two chemcial species, the
+ * where u and v represent the concentrations of the two chemical species, the
  * diffusion rates are Dux = Duy = Dvx = Dvy = 1e-3, and the species with
  * constant concentration over time are A = 1 and B = 3.
  *
@@ -63,6 +63,7 @@
 #include <limits>
 #include <random>
 #include <sstream>
+#include <string>
 
 // Include MPI
 #include "mpi.h"
@@ -159,7 +160,7 @@ struct UserData
   bool reaction  = true;
 
   // --------------------------
-  // Discretization parameteres
+  // Discretization parameters
   // --------------------------
 
   // Global and local number of nodes in the x and y directions
@@ -228,7 +229,7 @@ struct UserData
   sunrealtype* SWsend = NULL;
   sunrealtype* NErecv = NULL;
 
-  // Recieve and send requests
+  // Receive and send requests
   MPI_Request reqRW, reqRE, reqRS, reqRN;
   MPI_Request reqSW, reqSE, reqSS, reqSN;
   MPI_Request reqRC, reqSC;
@@ -282,10 +283,10 @@ struct UserData
   // Shared IMEX and MRI settings
   // ----------------------------
 
-  int controller   = 0;     // step size adaptivity method (0 = use default)
-  int maxsteps     = 0;     // max steps between outputs (0 = use default)
-  bool linear      = true;  // enable/disable linearly implicit option
-  bool diagnostics = false; // output diagnostics
+  string controller = "I";   // step size adaptivity method
+  int maxsteps      = 0;     // max steps between outputs (0 = use default)
+  bool linear       = true;  // enable/disable linearly implicit option
+  bool diagnostics  = false; // output diagnostics
 
   // -----------------------------------------
   // Nonlinear solver settings
@@ -307,7 +308,7 @@ struct UserData
   N_Vector diag      = NULL;  // inverse of Jacobian diagonal
 
   // ---------------
-  // Ouput variables
+  // Output variables
   // ---------------
 
   int output = 1;  // 0 = no output, 1 = output stats, 2 = write to disk
@@ -379,11 +380,10 @@ static int SetupDecomp(UserData* udata);
 
 // Integrator setup functions
 static int SetupARK(SUNContext ctx, UserData* udata, N_Vector u,
-                    SUNLinearSolver LS, SUNAdaptController* Ctrl,
-                    void** arkode_mem);
+                    SUNLinearSolver LS, void** arkode_mem);
 static int SetupMRI(SUNContext ctx, UserData* udata, N_Vector u,
-                    SUNLinearSolver LS, SUNAdaptController* Ctrl,
-                    void** arkode_mem, MRIStepInnerStepper* stepper);
+                    SUNLinearSolver LS, void** arkode_mem,
+                    MRIStepInnerStepper* stepper);
 static int SetupMRICVODE(SUNContext ctx, UserData* udata, N_Vector u,
                          SUNLinearSolver LS, SUNNonlinearSolver* NLS,
                          void** arkode_mem, MRIStepInnerStepper* stepper);
@@ -557,18 +557,15 @@ int main(int argc, char* argv[])
   // Inner stepper nonlinear solver (CVODE)
   SUNNonlinearSolver NLS = NULL;
 
-  // Timestep adaptivity controller
-  SUNAdaptController Ctrl = NULL;
-
   // Create integrator
   switch (udata.integrator)
   {
   case (0):
-    flag = SetupARK(ctx, &udata, u, LS, &Ctrl, &arkode_mem);
+    flag = SetupARK(ctx, &udata, u, LS, &arkode_mem);
     if (check_flag((void*)arkode_mem, "SetupARK", 0)) { return 1; }
     break;
   case (1):
-    flag = SetupMRI(ctx, &udata, u, LS, &Ctrl, &arkode_mem, &stepper);
+    flag = SetupMRI(ctx, &udata, u, LS, &arkode_mem, &stepper);
     if (check_flag((void*)arkode_mem, "SetupMRI", 0)) { return 1; }
     break;
   case (2):
@@ -597,7 +594,7 @@ int main(int argc, char* argv[])
   sunrealtype dTout = udata.tf / udata.nout;
   sunrealtype tout  = dTout;
 
-  // Inital output
+  // Initial output
   flag = OpenOutput(&udata);
   if (check_flag(&flag, "OpenOutput", 1)) { return 1; }
 
@@ -611,16 +608,8 @@ int main(int argc, char* argv[])
     udata.evolve.start();
 
     // Evolve
-    if (udata.integrator)
-    {
-      flag = MRIStepEvolve(arkode_mem, tout, u, &t, stepmode);
-      if (check_flag(&flag, "MRIStepEvolve", 1)) { break; }
-    }
-    else
-    {
-      flag = ARKStepEvolve(arkode_mem, tout, u, &t, stepmode);
-      if (check_flag(&flag, "ARKStepEvolve", 1)) { break; }
-    }
+    flag = ARKodeEvolve(arkode_mem, tout, u, &t, stepmode);
+    if (check_flag(&flag, "ARKodeEvolve", 1)) { break; }
 
     // Stop timer
     udata.evolve.stop();
@@ -678,14 +667,14 @@ int main(int argc, char* argv[])
 
   switch (udata.integrator)
   {
-  case (0): ARKStepFree(&arkode_mem); break;
+  case (0): ARKodeFree(&arkode_mem); break;
   case (1):
   {
     void* inner_arkode_mem = NULL;
     MRIStepInnerStepper_GetContent(stepper, &inner_arkode_mem);
-    ARKStepFree(&inner_arkode_mem);
+    ARKodeFree(&inner_arkode_mem);
     MRIStepInnerStepper_Free(&stepper);
-    MRIStepFree(&arkode_mem);
+    ARKodeFree(&arkode_mem);
     break;
   }
   case (2):
@@ -698,7 +687,7 @@ int main(int argc, char* argv[])
     delete content;
     MRIStepInnerStepper_Free(&stepper);
     SUNNonlinSolFree(NLS);
-    MRIStepFree(&arkode_mem);
+    ARKodeFree(&arkode_mem);
     break;
   }
   default: cerr << "Invalid integrator option" << endl; break;
@@ -708,7 +697,6 @@ int main(int argc, char* argv[])
   N_VDestroy(N_VGetLocalVector_MPIPlusX(u));
   N_VDestroy(u);
   FreeUserData(&udata);
-  (void)SUNAdaptController_Destroy(Ctrl);
   SUNContext_Free(&ctx);
   flag = MPI_Finalize();
   return 0;
@@ -914,8 +902,7 @@ static int SetupDecomp(UserData* udata)
 // -----------------------------------------------------------------------------
 
 static int SetupARK(SUNContext ctx, UserData* udata, N_Vector u,
-                    SUNLinearSolver LS, SUNAdaptController* Ctrl,
-                    void** arkode_mem)
+                    SUNLinearSolver LS, void** arkode_mem)
 {
   int flag;
 
@@ -928,81 +915,72 @@ static int SetupARK(SUNContext ctx, UserData* udata, N_Vector u,
   if (check_flag((void*)*arkode_mem, "ARKStepCreate", 0)) { return 1; }
 
   // Specify tolerances
-  flag = ARKStepSStolerances(*arkode_mem, udata->rtol_imex, udata->atol_imex);
-  if (check_flag(&flag, "ARKStepSStolerances", 1)) { return 1; }
+  flag = ARKodeSStolerances(*arkode_mem, udata->rtol_imex, udata->atol_imex);
+  if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
 
   // Attach user data
-  flag = ARKStepSetUserData(*arkode_mem, (void*)udata);
-  if (check_flag(&flag, "ARKStepSetUserData", 1)) { return 1; }
+  flag = ARKodeSetUserData(*arkode_mem, (void*)udata);
+  if (check_flag(&flag, "ARKodeSetUserData", 1)) { return 1; }
 
   if (udata->diffusion)
   {
     // Attach linear solver
-    flag = ARKStepSetLinearSolver(*arkode_mem, LS, NULL);
-    if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) { return 1; }
+    flag = ARKodeSetLinearSolver(*arkode_mem, LS, NULL);
+    if (check_flag(&flag, "ARKodeSetLinearSolver", 1)) { return 1; }
 
     if (udata->prec)
     {
       // Attach preconditioner
-      flag = ARKStepSetPreconditioner(*arkode_mem, NULL, PSolve);
-      if (check_flag(&flag, "ARKStepSetPreconditioner", 1)) { return 1; }
+      flag = ARKodeSetPreconditioner(*arkode_mem, NULL, PSolve);
+      if (check_flag(&flag, "ARKodeSetPreconditioner", 1)) { return 1; }
 
       // Set linear solver setup frequency (update preconditioner)
-      flag = ARKStepSetLSetupFrequency(*arkode_mem, udata->msbp);
-      if (check_flag(&flag, "ARKStepSetLSetupFrequency", 1)) { return 1; }
+      flag = ARKodeSetLSetupFrequency(*arkode_mem, udata->msbp);
+      if (check_flag(&flag, "ARKodeSetLSetupFrequency", 1)) { return 1; }
     }
 
     // Set linear solver tolerance factor
-    flag = ARKStepSetEpsLin(*arkode_mem, udata->epslin);
-    if (check_flag(&flag, "ARKStepSetEpsLin", 1)) { return 1; }
+    flag = ARKodeSetEpsLin(*arkode_mem, udata->epslin);
+    if (check_flag(&flag, "ARKodeSetEpsLin", 1)) { return 1; }
 
     // Specify linearly implicit non-time-dependent RHS
     if (udata->linear)
     {
-      flag = ARKStepSetLinear(*arkode_mem, 0);
-      if (check_flag(&flag, "ARKStepSetLinear", 1)) { return 1; }
+      flag = ARKodeSetLinear(*arkode_mem, 0);
+      if (check_flag(&flag, "ARKodeSetLinear", 1)) { return 1; }
     }
   }
 
   // Select method order
-  flag = ARKStepSetOrder(*arkode_mem, udata->order_imex);
-  if (check_flag(&flag, "ARKStepSetOrder", 1)) { return 1; }
+  flag = ARKodeSetOrder(*arkode_mem, udata->order_imex);
+  if (check_flag(&flag, "ARKodeSetOrder", 1)) { return 1; }
 
   // Set fixed step size or adaptivity method
   if (udata->h_imex > ZERO)
   {
-    flag = ARKStepSetFixedStep(*arkode_mem, udata->h_imex);
-    if (check_flag(&flag, "ARKStepSetFixedStep", 1)) { return 1; }
+    flag = ARKodeSetFixedStep(*arkode_mem, udata->h_imex);
+    if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
   }
   else
   {
-    switch (udata->controller)
-    {
-    case (ARK_ADAPT_PID): *Ctrl = SUNAdaptController_PID(ctx); break;
-    case (ARK_ADAPT_PI): *Ctrl = SUNAdaptController_PI(ctx); break;
-    case (ARK_ADAPT_I): *Ctrl = SUNAdaptController_I(ctx); break;
-    case (ARK_ADAPT_EXP_GUS): *Ctrl = SUNAdaptController_ExpGus(ctx); break;
-    case (ARK_ADAPT_IMP_GUS): *Ctrl = SUNAdaptController_ImpGus(ctx); break;
-    case (ARK_ADAPT_IMEX_GUS): *Ctrl = SUNAdaptController_ImExGus(ctx); break;
-    }
-    flag = ARKStepSetAdaptController(*arkode_mem, *Ctrl);
-    if (check_flag(&flag, "ARKStepSetAdaptController", 1)) { return 1; }
+    flag = ARKodeSetAdaptControllerByName(*arkode_mem, udata->controller.c_str());
+    if (check_flag(&flag, "ARKodeSetAdaptControllerByName", 1)) { return 1; }
   }
 
   // Set max steps between outputs
-  flag = ARKStepSetMaxNumSteps(*arkode_mem, udata->maxsteps);
-  if (check_flag(&flag, "ARKStepSetMaxNumSteps", 1)) { return 1; }
+  flag = ARKodeSetMaxNumSteps(*arkode_mem, udata->maxsteps);
+  if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
   // Set stopping time
-  flag = ARKStepSetStopTime(*arkode_mem, udata->tf);
-  if (check_flag(&flag, "ARKStepSetStopTime", 1)) { return 1; }
+  flag = ARKodeSetStopTime(*arkode_mem, udata->tf);
+  if (check_flag(&flag, "ARKodeSetStopTime", 1)) { return 1; }
 
   return 0;
 }
 
 static int SetupMRI(SUNContext ctx, UserData* udata, N_Vector y,
-                    SUNLinearSolver LS, SUNAdaptController* Ctrl,
-                    void** arkode_mem, MRIStepInnerStepper* stepper)
+                    SUNLinearSolver LS, void** arkode_mem,
+                    MRIStepInnerStepper* stepper)
 {
   int flag;
 
@@ -1015,46 +993,37 @@ static int SetupMRI(SUNContext ctx, UserData* udata, N_Vector y,
   if (check_flag((void*)inner_arkode_mem, "ARKStepCreate", 0)) { return 1; }
 
   // Specify tolerances
-  flag = ARKStepSStolerances(inner_arkode_mem, udata->rtol_fast,
-                             udata->atol_fast);
-  if (check_flag(&flag, "ARKStepSStolerances", 1)) { return 1; }
+  flag = ARKodeSStolerances(inner_arkode_mem, udata->rtol_fast, udata->atol_fast);
+  if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
 
   // Attach user data
-  flag = ARKStepSetUserData(inner_arkode_mem, (void*)udata);
-  if (check_flag(&flag, "ARKStepSetUserData", 1)) { return 1; }
+  flag = ARKodeSetUserData(inner_arkode_mem, (void*)udata);
+  if (check_flag(&flag, "ARKodeSetUserData", 1)) { return 1; }
 
   // Select method order
-  flag = ARKStepSetOrder(inner_arkode_mem, udata->order_fast);
-  if (check_flag(&flag, "ARKStepSetOrder", 1)) { return 1; }
+  flag = ARKodeSetOrder(inner_arkode_mem, udata->order_fast);
+  if (check_flag(&flag, "ARKodeSetOrder", 1)) { return 1; }
 
   // Set fixed step size or adaptivity method
   if (udata->h_fast > ZERO)
   {
-    flag = ARKStepSetFixedStep(inner_arkode_mem, udata->h_fast);
-    if (check_flag(&flag, "ARKStepSetFixedStep", 1)) { return 1; }
+    flag = ARKodeSetFixedStep(inner_arkode_mem, udata->h_fast);
+    if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
   }
   else
   {
-    switch (udata->controller)
-    {
-    case (ARK_ADAPT_PID): *Ctrl = SUNAdaptController_PID(ctx); break;
-    case (ARK_ADAPT_PI): *Ctrl = SUNAdaptController_PI(ctx); break;
-    case (ARK_ADAPT_I): *Ctrl = SUNAdaptController_I(ctx); break;
-    case (ARK_ADAPT_EXP_GUS): *Ctrl = SUNAdaptController_ExpGus(ctx); break;
-    case (ARK_ADAPT_IMP_GUS): *Ctrl = SUNAdaptController_ImpGus(ctx); break;
-    case (ARK_ADAPT_IMEX_GUS): *Ctrl = SUNAdaptController_ImExGus(ctx); break;
-    }
-    flag = ARKStepSetAdaptController(inner_arkode_mem, *Ctrl);
-    if (check_flag(&flag, "ARKStepSetAdaptController", 1)) { return 1; }
+    flag = ARKodeSetAdaptControllerByName(inner_arkode_mem,
+                                          udata->controller.c_str());
+    if (check_flag(&flag, "ARKodeSetAdaptControllerByName", 1)) { return 1; }
   }
 
   // Set max steps between outputs
-  flag = ARKStepSetMaxNumSteps(inner_arkode_mem, udata->maxsteps);
-  if (check_flag(&flag, "ARKStepSetMaxNumSteps", 1)) { return 1; }
+  flag = ARKodeSetMaxNumSteps(inner_arkode_mem, udata->maxsteps);
+  if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
   // Wrap ARKODE as an MRIStepInnerStepper
-  flag = ARKStepCreateMRIStepInnerStepper(inner_arkode_mem, stepper);
-  if (check_flag(&flag, "ARKStepCreateMRIStepInnerStepper", 1)) { return 1; }
+  flag = ARKodeCreateMRIStepInnerStepper(inner_arkode_mem, stepper);
+  if (check_flag(&flag, "ARKodeCreateMRIStepInnerStepper", 1)) { return 1; }
 
   // -------------------------
   // Setup the slow integrator
@@ -1075,50 +1044,50 @@ static int SetupMRI(SUNContext ctx, UserData* udata, N_Vector y,
   MRIStepCoupling_Free(C);
 
   // Set the slow step size
-  flag = MRIStepSetFixedStep(*arkode_mem, udata->h_slow);
-  if (check_flag(&flag, "MRIStepSetFixedStep", 1)) { return 1; }
+  flag = ARKodeSetFixedStep(*arkode_mem, udata->h_slow);
+  if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
 
   // Specify tolerances
-  flag = MRIStepSStolerances(*arkode_mem, udata->rtol_slow, udata->atol_slow);
-  if (check_flag(&flag, "MRIStepSStolerances", 1)) { return 1; }
+  flag = ARKodeSStolerances(*arkode_mem, udata->rtol_slow, udata->atol_slow);
+  if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
 
   // Attach user data
-  flag = MRIStepSetUserData(*arkode_mem, (void*)udata);
-  if (check_flag(&flag, "MRIStepSetUserData", 1)) { return 1; }
+  flag = ARKodeSetUserData(*arkode_mem, (void*)udata);
+  if (check_flag(&flag, "ARKodeSetUserData", 1)) { return 1; }
 
   // Attach linear solver
-  flag = MRIStepSetLinearSolver(*arkode_mem, LS, NULL);
-  if (check_flag(&flag, "MRIStepSetLinearSolver", 1)) { return 1; }
+  flag = ARKodeSetLinearSolver(*arkode_mem, LS, NULL);
+  if (check_flag(&flag, "ARKodeSetLinearSolver", 1)) { return 1; }
 
   if (udata->prec)
   {
     // Attach preconditioner
-    flag = MRIStepSetPreconditioner(*arkode_mem, NULL, PSolve);
-    if (check_flag(&flag, "MRIStepSetPreconditioner", 1)) { return 1; }
+    flag = ARKodeSetPreconditioner(*arkode_mem, NULL, PSolve);
+    if (check_flag(&flag, "ARKodeSetPreconditioner", 1)) { return 1; }
 
     // Set linear solver setup frequency (update preconditioner)
-    flag = MRIStepSetLSetupFrequency(*arkode_mem, udata->msbp);
-    if (check_flag(&flag, "MRIStepSetLSetupFrequency", 1)) { return 1; }
+    flag = ARKodeSetLSetupFrequency(*arkode_mem, udata->msbp);
+    if (check_flag(&flag, "ARKodeSetLSetupFrequency", 1)) { return 1; }
   }
 
   // Set linear solver tolerance factor
-  flag = MRIStepSetEpsLin(*arkode_mem, udata->epslin);
-  if (check_flag(&flag, "MRIStepSetEpsLin", 1)) { return 1; }
+  flag = ARKodeSetEpsLin(*arkode_mem, udata->epslin);
+  if (check_flag(&flag, "ARKodeSetEpsLin", 1)) { return 1; }
 
   // Specify linearly implicit non-time-dependent RHS
   if (udata->linear)
   {
-    flag = MRIStepSetLinear(*arkode_mem, 0);
-    if (check_flag(&flag, "MRIStepSetLinear", 1)) { return 1; }
+    flag = ARKodeSetLinear(*arkode_mem, 0);
+    if (check_flag(&flag, "ARKodeSetLinear", 1)) { return 1; }
   }
 
   // Set max steps between outputs
-  flag = MRIStepSetMaxNumSteps(*arkode_mem, udata->maxsteps);
-  if (check_flag(&flag, "MRIStepSetMaxNumSteps", 1)) { return 1; }
+  flag = ARKodeSetMaxNumSteps(*arkode_mem, udata->maxsteps);
+  if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
   // Set stopping time
-  flag = MRIStepSetStopTime(*arkode_mem, udata->tf);
-  if (check_flag(&flag, "MRIStepSetStopTime", 1)) { return 1; }
+  flag = ARKodeSetStopTime(*arkode_mem, udata->tf);
+  if (check_flag(&flag, "ARKodeSetStopTime", 1)) { return 1; }
 
   return 0;
 }
@@ -1219,50 +1188,50 @@ static int SetupMRICVODE(SUNContext ctx, UserData* udata, N_Vector y,
   MRIStepCoupling_Free(C);
 
   // Set the slow step size
-  flag = MRIStepSetFixedStep(*arkode_mem, udata->h_slow);
-  if (check_flag(&flag, "MRIStepSetFixedStep", 1)) { return 1; }
+  flag = ARKodeSetFixedStep(*arkode_mem, udata->h_slow);
+  if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
 
   // Specify tolerances
-  flag = MRIStepSStolerances(*arkode_mem, udata->rtol_slow, udata->atol_slow);
-  if (check_flag(&flag, "MRIStepSStolerances", 1)) { return 1; }
+  flag = ARKodeSStolerances(*arkode_mem, udata->rtol_slow, udata->atol_slow);
+  if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
 
   // Attach user data
-  flag = MRIStepSetUserData(*arkode_mem, (void*)udata);
-  if (check_flag(&flag, "MRIStepSetUserData", 1)) { return 1; }
+  flag = ARKodeSetUserData(*arkode_mem, (void*)udata);
+  if (check_flag(&flag, "ARKodeSetUserData", 1)) { return 1; }
 
   // Attach linear solver
-  flag = MRIStepSetLinearSolver(*arkode_mem, LS, NULL);
-  if (check_flag(&flag, "MRIStepSetLinearSolver", 1)) { return 1; }
+  flag = ARKodeSetLinearSolver(*arkode_mem, LS, NULL);
+  if (check_flag(&flag, "ARKodeSetLinearSolver", 1)) { return 1; }
 
   if (udata->prec)
   {
     // Attach preconditioner
-    flag = MRIStepSetPreconditioner(*arkode_mem, NULL, PSolve);
-    if (check_flag(&flag, "MRIStepSetPreconditioner", 1)) { return 1; }
+    flag = ARKodeSetPreconditioner(*arkode_mem, NULL, PSolve);
+    if (check_flag(&flag, "ARKodeSetPreconditioner", 1)) { return 1; }
 
     // Set linear solver setup frequency (update preconditioner)
-    flag = MRIStepSetLSetupFrequency(*arkode_mem, udata->msbp);
-    if (check_flag(&flag, "MRIStepSetLSetupFrequency", 1)) { return 1; }
+    flag = ARKodeSetLSetupFrequency(*arkode_mem, udata->msbp);
+    if (check_flag(&flag, "ARKodeSetLSetupFrequency", 1)) { return 1; }
   }
 
   // Set linear solver tolerance factor
-  flag = MRIStepSetEpsLin(*arkode_mem, udata->epslin);
-  if (check_flag(&flag, "MRIStepSetEpsLin", 1)) { return 1; }
+  flag = ARKodeSetEpsLin(*arkode_mem, udata->epslin);
+  if (check_flag(&flag, "ARKodeSetEpsLin", 1)) { return 1; }
 
   // Specify linearly implicit non-time-dependent RHS
   if (udata->linear)
   {
-    flag = MRIStepSetLinear(*arkode_mem, 0);
-    if (check_flag(&flag, "MRIStepSetLinear", 1)) { return 1; }
+    flag = ARKodeSetLinear(*arkode_mem, 0);
+    if (check_flag(&flag, "ARKodeSetLinear", 1)) { return 1; }
   }
 
   // Set max steps between outputs
-  flag = MRIStepSetMaxNumSteps(*arkode_mem, udata->maxsteps);
-  if (check_flag(&flag, "MRIStepSetMaxNumSteps", 1)) { return 1; }
+  flag = ARKodeSetMaxNumSteps(*arkode_mem, udata->maxsteps);
+  if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
   // Set stopping time
-  flag = MRIStepSetStopTime(*arkode_mem, udata->tf);
-  if (check_flag(&flag, "MRIStepSetStopTime", 1)) { return 1; }
+  flag = ARKodeSetStopTime(*arkode_mem, udata->tf);
+  if (check_flag(&flag, "ARKodeSetStopTime", 1)) { return 1; }
 
   return 0;
 }
@@ -2230,10 +2199,7 @@ static int ReadInputs(int* argc, char*** argv, UserData* udata)
     else if (arg == "--h_slow") { udata->h_slow = stod((*argv)[arg_idx++]); }
     else if (arg == "--h_fast") { udata->h_fast = stod((*argv)[arg_idx++]); }
     // Shared IMEX and MRI settings
-    else if (arg == "--controller")
-    {
-      udata->controller = stoi((*argv)[arg_idx++]);
-    }
+    else if (arg == "--controller") { udata->controller = (*argv)[arg_idx++]; }
     else if (arg == "--nonlinear") { udata->linear = false; }
     else if (arg == "--diagnostics") { udata->diagnostics = true; }
     // Linear solver settings
@@ -2358,14 +2324,14 @@ static void InputHelp()
     << "  --mri-cvode-local            : use MRI with CVODE task-local stepper"
     << endl;
   cout << "  --rtol_imex <rtol>           : IMEX relative tolerance" << endl;
-  cout << "  --atol_imex <atol>           : IMEX absoltue tolerance" << endl;
+  cout << "  --atol_imex <atol>           : IMEX absolute tolerance" << endl;
   cout << "  --h_imex <h>                 : IMEX fixed step size" << endl;
   cout << "  --order_imex <ord>           : IMEX method order" << endl;
   cout << "  --rtol_slow <rtol>           : MRI slow relative tolerance" << endl;
-  cout << "  --atol_slow <atol>           : MRI slow absoltue tolerance" << endl;
+  cout << "  --atol_slow <atol>           : MRI slow absolute tolerance" << endl;
   cout << "  --h_slow <h>                 : MRI slow step size" << endl;
   cout << "  --rtol_fast <rtol>           : MRI fast relative tolerance" << endl;
-  cout << "  --atol_fast <atol>           : MRI fast absoltue tolerance" << endl;
+  cout << "  --atol_fast <atol>           : MRI fast absolute tolerance" << endl;
   cout << "  --h_fast <h>                 : MRI fast step size" << endl;
   cout << "  --controller <ctr>           : time step adaptivity" << endl;
   cout << "  --nonlinear                  : nonlinearly implicit" << endl;
@@ -2603,31 +2569,33 @@ static int OutputStatsIMEX(void* arkode_mem, UserData* udata)
 
   // Get integrator and solver stats
   long int nst, nst_a, netf, nfe, nfi, nni, ncfn, nli, nlcf, nsetups, nfi_ls, nJv;
-  flag = ARKStepGetNumSteps(arkode_mem, &nst);
-  if (check_flag(&flag, "ARKStepGetNumSteps", 1)) { return -1; }
-  flag = ARKStepGetNumStepAttempts(arkode_mem, &nst_a);
-  if (check_flag(&flag, "ARKStepGetNumStepAttempts", 1)) { return -1; }
-  flag = ARKStepGetNumErrTestFails(arkode_mem, &netf);
-  if (check_flag(&flag, "ARKStepGetNumErrTestFails", 1)) { return -1; }
-  flag = ARKStepGetNumRhsEvals(arkode_mem, &nfe, &nfi);
-  if (check_flag(&flag, "ARKStepGetNumRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumSteps(arkode_mem, &nst);
+  if (check_flag(&flag, "ARKodeGetNumSteps", 1)) { return -1; }
+  flag = ARKodeGetNumStepAttempts(arkode_mem, &nst_a);
+  if (check_flag(&flag, "ARKodeGetNumStepAttempts", 1)) { return -1; }
+  flag = ARKodeGetNumErrTestFails(arkode_mem, &netf);
+  if (check_flag(&flag, "ARKodeGetNumErrTestFails", 1)) { return -1; }
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 0, &nfe);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 1, &nfi);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return -1; }
 
   if (udata->diffusion)
   {
-    flag = ARKStepGetNumNonlinSolvIters(arkode_mem, &nni);
-    if (check_flag(&flag, "ARKStepGetNumNonlinSolvIters", 1)) { return -1; }
-    flag = ARKStepGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
-    if (check_flag(&flag, "ARKStepGetNumNonlinSolvConvFails", 1)) { return -1; }
-    flag = ARKStepGetNumLinIters(arkode_mem, &nli);
-    if (check_flag(&flag, "ARKStepGetNumLinIters", 1)) { return -1; }
-    flag = ARKStepGetNumLinConvFails(arkode_mem, &nlcf);
-    if (check_flag(&flag, "ARKStepGetNumLinConvFails", 1)) { return -1; }
-    flag = ARKStepGetNumLinSolvSetups(arkode_mem, &nsetups);
-    if (check_flag(&flag, "ARKStepGetNumLinSolvSetups", 1)) { return -1; }
-    flag = ARKStepGetNumLinRhsEvals(arkode_mem, &nfi_ls);
-    if (check_flag(&flag, "ARKStepGetNumLinRhsEvals", 1)) { return -1; }
-    flag = ARKStepGetNumJtimesEvals(arkode_mem, &nJv);
-    if (check_flag(&flag, "ARKStepGetNumJtimesEvals", 1)) { return -1; }
+    flag = ARKodeGetNumNonlinSolvIters(arkode_mem, &nni);
+    if (check_flag(&flag, "ARKodeGetNumNonlinSolvIters", 1)) { return -1; }
+    flag = ARKodeGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
+    if (check_flag(&flag, "ARKodeGetNumNonlinSolvConvFails", 1)) { return -1; }
+    flag = ARKodeGetNumLinIters(arkode_mem, &nli);
+    if (check_flag(&flag, "ARKodeGetNumLinIters", 1)) { return -1; }
+    flag = ARKodeGetNumLinConvFails(arkode_mem, &nlcf);
+    if (check_flag(&flag, "ARKodeGetNumLinConvFails", 1)) { return -1; }
+    flag = ARKodeGetNumLinSolvSetups(arkode_mem, &nsetups);
+    if (check_flag(&flag, "ARKodeGetNumLinSolvSetups", 1)) { return -1; }
+    flag = ARKodeGetNumLinRhsEvals(arkode_mem, &nfi_ls);
+    if (check_flag(&flag, "ARKodeGetNumLinRhsEvals", 1)) { return -1; }
+    flag = ARKodeGetNumJtimesEvals(arkode_mem, &nJv);
+    if (check_flag(&flag, "ARKodeGetNumJtimesEvals", 1)) { return -1; }
   }
 
   cout << fixed;
@@ -2663,10 +2631,10 @@ static int OutputStatsIMEX(void* arkode_mem, UserData* udata)
     if (udata->prec)
     {
       long int npe, nps;
-      flag = ARKStepGetNumPrecEvals(arkode_mem, &npe);
-      if (check_flag(&flag, "ARKStepGetNumPrecEvals", 1)) { return -1; }
-      flag = ARKStepGetNumPrecSolves(arkode_mem, &nps);
-      if (check_flag(&flag, "ARKStepGetNumPrecSolves", 1)) { return -1; }
+      flag = ARKodeGetNumPrecEvals(arkode_mem, &npe);
+      if (check_flag(&flag, "ARKodeGetNumPrecEvals", 1)) { return -1; }
+      flag = ARKodeGetNumPrecSolves(arkode_mem, &nps);
+      if (check_flag(&flag, "ARKodeGetNumPrecSolves", 1)) { return -1; }
 
       cout << "  Preconditioner setups = " << npe << endl;
       cout << "  Preconditioner solves = " << nps << endl;
@@ -2684,25 +2652,25 @@ static int OutputStatsMRI(void* arkode_mem, MRIStepInnerStepper stepper,
   int flag;
 
   // Get slow integrator and solver stats
-  long int nsts, nfse, nfsi, nni, ncfn, nli, nlcf, nsetups, nfi_ls, nJv;
-  flag = MRIStepGetNumSteps(arkode_mem, &nsts);
-  if (check_flag(&flag, "MRIStepGetNumSteps", 1)) { return -1; }
-  flag = MRIStepGetNumRhsEvals(arkode_mem, &nfse, &nfsi);
-  if (check_flag(&flag, "MRIStepGetNumRhsEvals", 1)) { return -1; }
-  flag = MRIStepGetNumNonlinSolvIters(arkode_mem, &nni);
-  if (check_flag(&flag, "MRIStepGetNumNonlinSolvIters", 1)) { return -1; }
-  flag = MRIStepGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
-  if (check_flag(&flag, "MRIStepGetNumNonlinSolvConvFails", 1)) { return -1; }
-  flag = MRIStepGetNumLinIters(arkode_mem, &nli);
-  if (check_flag(&flag, "MRIStepGetNumLinIters", 1)) { return -1; }
-  flag = MRIStepGetNumLinConvFails(arkode_mem, &nlcf);
-  if (check_flag(&flag, "MRIStepGetNumLinConvFails", 1)) { return -1; }
-  flag = MRIStepGetNumLinSolvSetups(arkode_mem, &nsetups);
-  if (check_flag(&flag, "MRIStepGetNumLinSolvSetups", 1)) { return -1; }
-  flag = MRIStepGetNumLinRhsEvals(arkode_mem, &nfi_ls);
-  if (check_flag(&flag, "MRIStepGetNumLinRhsEvals", 1)) { return -1; }
-  flag = MRIStepGetNumJtimesEvals(arkode_mem, &nJv);
-  if (check_flag(&flag, "MRIStepGetNumJtimesEvals", 1)) { return -1; }
+  long int nsts, nfsi, nni, ncfn, nli, nlcf, nsetups, nfi_ls, nJv;
+  flag = ARKodeGetNumSteps(arkode_mem, &nsts);
+  if (check_flag(&flag, "ARKodeGetNumSteps", 1)) { return -1; }
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 1, &nfsi);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumNonlinSolvIters(arkode_mem, &nni);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvIters", 1)) { return -1; }
+  flag = ARKodeGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvConvFails", 1)) { return -1; }
+  flag = ARKodeGetNumLinIters(arkode_mem, &nli);
+  if (check_flag(&flag, "ARKodeGetNumLinIters", 1)) { return -1; }
+  flag = ARKodeGetNumLinConvFails(arkode_mem, &nlcf);
+  if (check_flag(&flag, "ARKodeGetNumLinConvFails", 1)) { return -1; }
+  flag = ARKodeGetNumLinSolvSetups(arkode_mem, &nsetups);
+  if (check_flag(&flag, "ARKodeGetNumLinSolvSetups", 1)) { return -1; }
+  flag = ARKodeGetNumLinRhsEvals(arkode_mem, &nfi_ls);
+  if (check_flag(&flag, "ARKodeGetNumLinRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumJtimesEvals(arkode_mem, &nJv);
+  if (check_flag(&flag, "ARKodeGetNumJtimesEvals", 1)) { return -1; }
 
   cout << fixed;
   cout << setprecision(6);
@@ -2731,10 +2699,10 @@ static int OutputStatsMRI(void* arkode_mem, MRIStepInnerStepper stepper,
   if (udata->prec)
   {
     long int npe, nps;
-    flag = MRIStepGetNumPrecEvals(arkode_mem, &npe);
-    if (check_flag(&flag, "MRIStepGetNumPrecEvals", 1)) { return -1; }
-    flag = MRIStepGetNumPrecSolves(arkode_mem, &nps);
-    if (check_flag(&flag, "MRIStepGetNumPrecSolves", 1)) { return -1; }
+    flag = ARKodeGetNumPrecEvals(arkode_mem, &npe);
+    if (check_flag(&flag, "ARKodeGetNumPrecEvals", 1)) { return -1; }
+    flag = ARKodeGetNumPrecSolves(arkode_mem, &nps);
+    if (check_flag(&flag, "ARKodeGetNumPrecSolves", 1)) { return -1; }
 
     cout << "  Preconditioner setups = " << npe << endl;
     cout << "  Preconditioner solves = " << nps << endl;
@@ -2745,16 +2713,16 @@ static int OutputStatsMRI(void* arkode_mem, MRIStepInnerStepper stepper,
   void* inner_arkode_mem;
   MRIStepInnerStepper_GetContent(stepper, &inner_arkode_mem);
 
-  long int nstf, nstf_a, netff, nffe, nffi;
+  long int nstf, nstf_a, netff, nffe;
 
-  flag = ARKStepGetNumSteps(inner_arkode_mem, &nstf);
-  if (check_flag(&flag, "ARKStepGetNumSteps", 1)) { return -1; }
-  flag = ARKStepGetNumStepAttempts(inner_arkode_mem, &nstf_a);
-  if (check_flag(&flag, "ARKStepGetNumStepAttempts", 1)) { return -1; }
-  flag = ARKStepGetNumErrTestFails(inner_arkode_mem, &netff);
-  if (check_flag(&flag, "ARKStepGetNumErrTestFails", 1)) { return -1; }
-  flag = ARKStepGetNumRhsEvals(inner_arkode_mem, &nffe, &nffi);
-  if (check_flag(&flag, "ARKStepGetNumRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumSteps(inner_arkode_mem, &nstf);
+  if (check_flag(&flag, "ARKodeGetNumSteps", 1)) { return -1; }
+  flag = ARKodeGetNumStepAttempts(inner_arkode_mem, &nstf_a);
+  if (check_flag(&flag, "ARKodeGetNumStepAttempts", 1)) { return -1; }
+  flag = ARKodeGetNumErrTestFails(inner_arkode_mem, &netff);
+  if (check_flag(&flag, "ARKodeGetNumErrTestFails", 1)) { return -1; }
+  flag = ARKodeGetNumRhsEvals(inner_arkode_mem, 0, &nffe);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return -1; }
 
   cout << "Fast Integrator:" << endl;
   cout << "  Steps            = " << nstf << endl;
@@ -2772,25 +2740,25 @@ static int OutputStatsMRICVODE(void* arkode_mem, MRIStepInnerStepper stepper,
   int flag;
 
   // Get slow integrator and solver stats
-  long int nsts, nfse, nfsi, nni, ncfn, nli, nlcf, nsetups, nfi_ls, nJv;
-  flag = MRIStepGetNumSteps(arkode_mem, &nsts);
-  if (check_flag(&flag, "MRIStepGetNumSteps", 1)) { return -1; }
-  flag = MRIStepGetNumRhsEvals(arkode_mem, &nfse, &nfsi);
-  if (check_flag(&flag, "MRIStepGetNumRhsEvals", 1)) { return -1; }
-  flag = MRIStepGetNumNonlinSolvIters(arkode_mem, &nni);
-  if (check_flag(&flag, "MRIStepGetNumNonlinSolvIters", 1)) { return -1; }
-  flag = MRIStepGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
-  if (check_flag(&flag, "MRIStepGetNumNonlinSolvConvFails", 1)) { return -1; }
-  flag = MRIStepGetNumLinIters(arkode_mem, &nli);
-  if (check_flag(&flag, "MRIStepGetNumLinIters", 1)) { return -1; }
-  flag = MRIStepGetNumLinConvFails(arkode_mem, &nlcf);
-  if (check_flag(&flag, "MRIStepGetNumLinConvFails", 1)) { return -1; }
-  flag = MRIStepGetNumLinSolvSetups(arkode_mem, &nsetups);
-  if (check_flag(&flag, "MRIStepGetNumLinSolvSetups", 1)) { return -1; }
-  flag = MRIStepGetNumLinRhsEvals(arkode_mem, &nfi_ls);
-  if (check_flag(&flag, "MRIStepGetNumLinRhsEvals", 1)) { return -1; }
-  flag = MRIStepGetNumJtimesEvals(arkode_mem, &nJv);
-  if (check_flag(&flag, "MRIStepGetNumJtimesEvals", 1)) { return -1; }
+  long int nsts, nfsi, nni, ncfn, nli, nlcf, nsetups, nfi_ls, nJv;
+  flag = ARKodeGetNumSteps(arkode_mem, &nsts);
+  if (check_flag(&flag, "ARKodeGetNumSteps", 1)) { return -1; }
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 1, &nfsi);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumNonlinSolvIters(arkode_mem, &nni);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvIters", 1)) { return -1; }
+  flag = ARKodeGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvConvFails", 1)) { return -1; }
+  flag = ARKodeGetNumLinIters(arkode_mem, &nli);
+  if (check_flag(&flag, "ARKodeGetNumLinIters", 1)) { return -1; }
+  flag = ARKodeGetNumLinConvFails(arkode_mem, &nlcf);
+  if (check_flag(&flag, "ARKodeGetNumLinConvFails", 1)) { return -1; }
+  flag = ARKodeGetNumLinSolvSetups(arkode_mem, &nsetups);
+  if (check_flag(&flag, "ARKodeGetNumLinSolvSetups", 1)) { return -1; }
+  flag = ARKodeGetNumLinRhsEvals(arkode_mem, &nfi_ls);
+  if (check_flag(&flag, "ARKodeGetNumLinRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumJtimesEvals(arkode_mem, &nJv);
+  if (check_flag(&flag, "ARKodeGetNumJtimesEvals", 1)) { return -1; }
 
   cout << fixed;
   cout << setprecision(6);
@@ -2819,10 +2787,10 @@ static int OutputStatsMRICVODE(void* arkode_mem, MRIStepInnerStepper stepper,
   if (udata->prec)
   {
     long int npe, nps;
-    flag = MRIStepGetNumPrecEvals(arkode_mem, &npe);
-    if (check_flag(&flag, "MRIStepGetNumPrecEvals", 1)) { return -1; }
-    flag = MRIStepGetNumPrecSolves(arkode_mem, &nps);
-    if (check_flag(&flag, "MRIStepGetNumPrecSolves", 1)) { return -1; }
+    flag = ARKodeGetNumPrecEvals(arkode_mem, &npe);
+    if (check_flag(&flag, "ARKodeGetNumPrecEvals", 1)) { return -1; }
+    flag = ARKodeGetNumPrecSolves(arkode_mem, &nps);
+    if (check_flag(&flag, "ARKodeGetNumPrecSolves", 1)) { return -1; }
 
     cout << "  Preconditioner setups = " << npe << endl;
     cout << "  Preconditioner solves = " << nps << endl;
@@ -2848,7 +2816,7 @@ static int OutputStatsMRICVODE(void* arkode_mem, MRIStepInnerStepper stepper,
   return 0;
 }
 
-// Ouput timing stats
+// Output timing stats
 static int OutputTiming(UserData* udata)
 {
   if (udata->outproc)
