@@ -3,7 +3,7 @@
  * Programmer(s): Cody J. Balos @ LLNL
  * ----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -113,10 +113,6 @@ int SolveProblem(ProgramArgs* args, ProblemResult* result, SUNContext sunctx)
   SUNNonlinearSolver NLS = NULL;
   UserData udata         = NULL;
   sunrealtype* ydata     = NULL;
-  sunrealtype tout       = NAN;
-  sunrealtype tret       = NAN;
-  sunrealtype H0         = NAN;
-  sunrealtype L0         = NAN;
   sunrealtype num_orbits = 0;
   FILE* conserved_fp     = NULL;
   FILE* solution_fp      = NULL;
@@ -161,8 +157,8 @@ int SolveProblem(ProgramArgs* args, ProblemResult* result, SUNContext sunctx)
     /* Optional: enable temporal root-finding */
     if (count_orbits)
     {
-      SPRKStepRootInit(arkode_mem, 1, rootfn);
-      if (check_retval(&retval, "SPRKStepRootInit", 1)) { return 1; }
+      ARKodeRootInit(arkode_mem, 1, rootfn);
+      if (check_retval(&retval, "ARKodeRootInit", 1)) { return 1; }
     }
 
     retval = SPRKStepSetMethodName(arkode_mem, method_name);
@@ -173,11 +169,11 @@ int SolveProblem(ProgramArgs* args, ProblemResult* result, SUNContext sunctx)
 
     if (step_mode == 0)
     {
-      retval = SPRKStepSetFixedStep(arkode_mem, dt);
-      if (check_retval(&retval, "SPRKStepSetFixedStep", 1)) { return 1; }
+      retval = ARKodeSetFixedStep(arkode_mem, dt);
+      if (check_retval(&retval, "ARKodeSetFixedStep", 1)) { return 1; }
 
-      retval = SPRKStepSetMaxNumSteps(arkode_mem, ((long int)ceil(Tf / dt)) + 1);
-      if (check_retval(&retval, "SPRKStepSetMaxNumSteps", 1)) { return 1; }
+      retval = ARKodeSetMaxNumSteps(arkode_mem, ((long int)ceil(Tf / dt)) + 1);
+      if (check_retval(&retval, "ARKodeSetMaxNumSteps", 1)) { return 1; }
     }
     else
     {
@@ -186,8 +182,8 @@ int SolveProblem(ProgramArgs* args, ProblemResult* result, SUNContext sunctx)
       return 1;
     }
 
-    retval = SPRKStepSetUserData(arkode_mem, (void*)udata);
-    if (check_retval(&retval, "SPRKStepSetUserData", 1)) { return 1; }
+    retval = ARKodeSetUserData(arkode_mem, (void*)udata);
+    if (check_retval(&retval, "ARKodeSetUserData", 1)) { return 1; }
   }
   else if (stepper == 1)
   {
@@ -198,21 +194,21 @@ int SolveProblem(ProgramArgs* args, ProblemResult* result, SUNContext sunctx)
 
     if (count_orbits)
     {
-      ARKStepRootInit(arkode_mem, 1, rootfn);
-      if (check_retval(&retval, "ARKStepRootInit", 1)) { return 1; }
+      ARKodeRootInit(arkode_mem, 1, rootfn);
+      if (check_retval(&retval, "ARKodeRootInit", 1)) { return 1; }
     }
 
-    retval = ARKStepSetUserData(arkode_mem, (void*)udata);
-    if (check_retval(&retval, "ARKStepSetUserData", 1)) { return 1; }
+    retval = ARKodeSetUserData(arkode_mem, (void*)udata);
+    if (check_retval(&retval, "ARKodeSetUserData", 1)) { return 1; }
 
-    retval = ARKStepSetMaxNumSteps(arkode_mem, ((long int)ceil(Tf / dt)) + 1);
-    if (check_retval(&retval, "ARKStepSetMaxNumSteps", 1)) { return 1; }
+    retval = ARKodeSetMaxNumSteps(arkode_mem, ((long int)ceil(Tf / dt)) + 1);
+    if (check_retval(&retval, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
-    if (step_mode == 0) { retval = ARKStepSetFixedStep(arkode_mem, dt); }
+    if (step_mode == 0) { retval = ARKodeSetFixedStep(arkode_mem, dt); }
     else
     {
-      retval = ARKStepSStolerances(arkode_mem, dt, dt);
-      if (check_retval(&retval, "ARKStepSStolerances", 1)) { return 1; }
+      retval = ARKodeSStolerances(arkode_mem, dt, dt);
+      if (check_retval(&retval, "ARKodeSStolerances", 1)) { return 1; }
     }
   }
 
@@ -245,10 +241,10 @@ int SolveProblem(ProgramArgs* args, ProblemResult* result, SUNContext sunctx)
   }
 
   /* Print out starting energy, momentum before integrating */
-  tret = T0;
-  tout = T0 + dTout;
-  H0   = Hamiltonian(y);
-  L0   = AngularMomentum(y);
+  sunrealtype tret = T0;
+  sunrealtype tout = T0 + dTout;
+  sunrealtype H0   = Hamiltonian(y);
+  sunrealtype L0   = AngularMomentum(y);
   fprintf(stdout, "t = %.4Lf, H(p,q) = %.16Lf, L(p,q) = %.16Lf\n",
           (long double)tret, (long double)H0, (long double)L0);
   fprintf(times_fp, "%.16Lf\n", (long double)tret);
@@ -264,15 +260,15 @@ int SolveProblem(ProgramArgs* args, ProblemResult* result, SUNContext sunctx)
          exact requested output time will not be hit (even with a fixed
          time-step due to roundoff error accumulation) and interpolation will be
          used to get the solution at the output time. */
-      if (args->use_tstop) { SPRKStepSetStopTime(arkode_mem, tout); }
-      retval = SPRKStepEvolve(arkode_mem, tout, y, &tret, ARK_NORMAL);
+      if (args->use_tstop) { ARKodeSetStopTime(arkode_mem, tout); }
+      retval = ARKodeEvolve(arkode_mem, tout, y, &tret, ARK_NORMAL);
 
       if (retval == ARK_ROOT_RETURN)
       {
         num_orbits += SUN_RCONST(0.5);
 
         fprintf(stdout, "ROOT RETURN:\t");
-        SPRKStepGetRootInfo(arkode_mem, &rootsfound);
+        ARKodeGetRootInfo(arkode_mem, &rootsfound);
         fprintf(stdout, "  g[0] = %3d, y[0] = %3Lg, y[1] = %3Lg, num. orbits is now %.2Lf\n",
                 rootsfound, (long double)ydata[0], (long double)ydata[1],
                 (long double)num_orbits);
@@ -311,15 +307,15 @@ int SolveProblem(ProgramArgs* args, ProblemResult* result, SUNContext sunctx)
          exact requested output time will not be hit (even with a fixed
          time-step due to roundoff error accumulation) and interpolation will be
          used to get the solution at the output time. */
-      if (args->use_tstop) { ARKStepSetStopTime(arkode_mem, tout); }
-      retval = ARKStepEvolve(arkode_mem, tout, y, &tret, ARK_NORMAL);
+      if (args->use_tstop) { ARKodeSetStopTime(arkode_mem, tout); }
+      retval = ARKodeEvolve(arkode_mem, tout, y, &tret, ARK_NORMAL);
 
       if (retval == ARK_ROOT_RETURN)
       {
         num_orbits += SUN_RCONST(0.5);
 
         fprintf(stdout, "ROOT RETURN:\t");
-        ARKStepGetRootInfo(arkode_mem, &rootsfound);
+        ARKodeGetRootInfo(arkode_mem, &rootsfound);
         fprintf(stdout, "  g[0] = %3d, y[0] = %3Lg, y[1] = %3Lg, num. orbits is now %.2Lf\n",
                 rootsfound, (long double)ydata[0], (long double)ydata[1],
                 (long double)num_orbits);
@@ -361,17 +357,8 @@ int SolveProblem(ProgramArgs* args, ProblemResult* result, SUNContext sunctx)
   fclose(solution_fp);
   if (NLS) { SUNNonlinSolFree(NLS); }
   N_VDestroy(y);
-  if (stepper == 0)
-  {
-    SPRKStepPrintAllStats(arkode_mem, stdout, SUN_OUTPUTFORMAT_TABLE);
-    SPRKStepFree(&arkode_mem);
-  }
-  else
-  {
-    ARKStepPrintAllStats(arkode_mem, stdout, SUN_OUTPUTFORMAT_TABLE);
-    ARKStepFree(&arkode_mem);
-  }
-
+  ARKodePrintAllStats(arkode_mem, stdout, SUN_OUTPUTFORMAT_TABLE);
+  ARKodeFree(&arkode_mem);
   return 0;
 }
 
