@@ -3,7 +3,7 @@
 ! Based on ark_kpr_mri.c in examples/arkode/C_serial.
 ! -------------------------------------------------------------------
 ! SUNDIALS Copyright Start
-! Copyright (c) 2002-2024, Lawrence Livermore National Security
+! Copyright (c) 2002-2025, Lawrence Livermore National Security
 ! and Southern Methodist University.
 ! All rights reserved.
 !
@@ -86,23 +86,23 @@ module kpr_mod
 
   ! Constants
   real(c_double) :: ZERO = 0.0d0
-  real(c_double) :: ONE  = 1.0d0
-  real(c_double) :: TWO  = 2.0d0
+  real(c_double) :: ONE = 1.0d0
+  real(c_double) :: TWO = 2.0d0
 
   ! general problem parameters
-  real(c_double), parameter  :: T0          = 0.0d0    ! initial time
-  real(c_double), parameter  :: Tf          = 5.0d0    ! final time
-  real(c_double), parameter  :: dTout       = 0.1d0    ! time between outputs
-  integer(c_long), parameter :: NEQ         = 2        ! number of dependent vars.
-  integer(c_int), parameter  :: Nt          = ceiling(Tf/dTout) ! number of output times
+  real(c_double), parameter  :: T0 = 0.0d0    ! initial time
+  real(c_double), parameter  :: Tf = 5.0d0    ! final time
+  real(c_double), parameter  :: dTout = 0.1d0    ! time between outputs
+  integer(c_int64_t), parameter :: NEQ = 2        ! number of dependent vars.
+  integer(c_int), parameter  :: Nt = ceiling(Tf/dTout) ! number of output times
 
   ! parameters that can be modified via CLI args or are derived
-  real(c_double) :: hs         = 0.01d0   ! slow step size
-  real(c_double) :: e          = 0.5d0    ! fast/slow coupling strength
-  real(c_double) :: G          = -100.0d0 ! stiffness at slow time scale
-  real(c_double) :: w          = 100.0d0  ! time-scale separation factor
-  real(c_double) :: reltol     = 0.01d0   ! integrator tolerances
-  real(c_double) :: abstol     = 1e-11
+  real(c_double) :: hs = 0.01d0   ! slow step size
+  real(c_double) :: e = 0.5d0    ! fast/slow coupling strength
+  real(c_double) :: G = -100.0d0 ! stiffness at slow time scale
+  real(c_double) :: w = 100.0d0  ! time-scale separation factor
+  real(c_double) :: reltol = 0.01d0   ! integrator tolerances
+  real(c_double) :: abstol = 1e-11
 
 contains
 
@@ -121,7 +121,7 @@ contains
     real(c_double), value :: t
     type(N_Vector)        :: yvec
     type(N_Vector)        :: ydotvec
-    type(c_ptr),    value :: user_data
+    type(c_ptr), value :: user_data
 
     real(c_double) :: u, v
     real(c_double) :: tmp1, tmp2
@@ -139,8 +139,8 @@ contains
     ! fill in the RHS function:
     !  [0  0]*[(-1+u^2-r(t))/(2*u)] + [         0          ]
     !  [e -1] [(-2+v^2-s(t))/(2*v)]   [sdot(t)/(2*vtrue(t))]
-    tmp1 = (-ONE+u*u-r(t))/(TWO*u)
-    tmp2 = (-TWO+v*v-s(t))/(TWO*v)
+    tmp1 = (-ONE + u*u - r(t))/(TWO*u)
+    tmp2 = (-TWO + v*v - s(t))/(TWO*v)
     ydotarr(1) = ZERO
     ydotarr(2) = e*tmp1 - tmp2 + sdot(t)/(TWO*vtrue(t))
 
@@ -162,7 +162,7 @@ contains
     real(c_double), value :: t
     type(N_Vector)       :: yvec
     type(N_Vector)       :: ydotvec
-    type(c_ptr),   value :: user_data
+    type(c_ptr), value :: user_data
 
     real(c_double) :: u, v
     real(c_double) :: tmp1, tmp2
@@ -180,8 +180,8 @@ contains
     ! fill in the RHS function:
     !  [G e]*[(-1+u^2-r(t))/(2*u))] + [rdot(t)/(2*u)]
     !  [0 0] [(-2+v^2-s(t))/(2*v)]    [      0      ]
-    tmp1 = (-ONE+u*u-r(t))/(TWO*u)
-    tmp2 = (-TWO+v*v-s(t))/(TWO*v)
+    tmp1 = (-ONE + u*u - r(t))/(TWO*u)
+    tmp2 = (-TWO + v*v - s(t))/(TWO*v)
     ydotarr(1) = G*tmp1 + e*tmp2 + rdot(t)/(TWO*u)
     ydotarr(2) = ZERO
 
@@ -203,7 +203,7 @@ contains
     real(c_double), value :: t
     type(N_Vector)        :: yvec
     type(N_Vector)        :: ydotvec
-    type(c_ptr),    value :: user_data
+    type(c_ptr), value :: user_data
 
     real(c_double) :: u, v
     real(c_double), pointer, dimension(NEQ) :: yarr(:)
@@ -241,7 +241,7 @@ contains
     real(c_double), value :: t
     type(N_Vector)        :: yvec
     type(N_Vector)        :: ydotvec
-    type(c_ptr),    value :: user_data
+    type(c_ptr), value :: user_data
 
     real(c_double) :: u, v
     real(c_double) :: tmp1, tmp2
@@ -259,8 +259,8 @@ contains
     ! fill in the slow implicit RHS function:
     !  [G e]*[(-1+u^2-r(t))/(2*u))]
     !  [0 0] [(-2+v^2-s(t))/(2*v)]
-    tmp1 = (-ONE+u*u-r(t))/(TWO*u)
-    tmp2 = (-TWO+v*v-s(t))/(TWO*v)
+    tmp1 = (-ONE + u*u - r(t))/(TWO*u)
+    tmp2 = (-TWO + v*v - s(t))/(TWO*v)
     ydotarr(1) = G*tmp1 + e*tmp2
     ydotarr(2) = ZERO
 
@@ -281,7 +281,7 @@ contains
     real(c_double), value :: t
     type(N_Vector)        :: yvec
     type(N_Vector)        :: ydotvec
-    type(c_ptr),    value :: user_data
+    type(c_ptr), value :: user_data
 
     real(c_double) :: u, v
     real(c_double) :: tmp1, tmp2
@@ -299,8 +299,8 @@ contains
     ! fill in the RHS function:
     !  [G e]*[(-1+u^2-r(t))/(2*u))] + [rdot(t)/(2*u)]
     !  [e -1] [(-2+v^2-s(t))/(2*v)]   [sdot(t)/(2*vtrue(t))]
-    tmp1 = (-ONE+u*u-r(t))/(TWO*u)
-    tmp2 = (-TWO+v*v-s(t))/(TWO*v)
+    tmp1 = (-ONE + u*u - r(t))/(TWO*u)
+    tmp2 = (-TWO + v*v - s(t))/(TWO*v)
     ydotarr(1) = G*tmp1 + e*tmp2 + rdot(t)/(TWO*u)
     ydotarr(2) = e*tmp1 - tmp2 + sdot(t)/(TWO*vtrue(t))
 
@@ -321,7 +321,7 @@ contains
     real(c_double), value :: t
     type(N_Vector)        :: yvec
     type(N_Vector)        :: ydotvec
-    type(c_ptr),    value :: user_data
+    type(c_ptr), value :: user_data
 
     call FN_VConst(ZERO, ydotvec)
 
@@ -346,18 +346,18 @@ contains
     type(N_Vector)        :: y
     type(N_Vector)        :: fy
     type(SUNMatrix)       :: J
-    type(c_ptr),    value :: user_data
+    type(c_ptr), value :: user_data
     type(N_Vector)        :: tmp1, tmp2, tmp3
 
     real(c_double) :: u, v
     real(c_double), pointer, dimension(NEQ) :: yarr(:)
-    real(c_double), pointer, dimension(NEQ,NEQ) :: Jarr(:,:)
+    real(c_double), pointer, dimension(NEQ, NEQ) :: Jarr(:, :)
 
     ! get N_Vector data arrays
     yarr => FN_VGetArrayPointer(y)
 
     ! get Jacobian data array
-    Jarr(1:NEQ,1:NEQ) => FSUNDenseMatrix_Data(J)
+    Jarr(1:NEQ, 1:NEQ) => FSUNDenseMatrix_Data(J)
 
     ! extract variables
     u = yarr(1)
@@ -366,10 +366,10 @@ contains
     ! fill in the Jacobian:
     !  [G/2 + (w*(1+r(t))-rdot(t))/(2*u^2)   e/2 + e*(2+s(t))/(2*v^2)]
     !  [                 0                              0            ]
-    Jarr(1,1) = G/TWO + (G*(ONE+r(t))-rdot(t))/(2*u*u)
-    Jarr(2,1) = ZERO
-    Jarr(1,2) = e/TWO + e*(TWO+s(t))/(TWO*v*v)
-    Jarr(2,2) = ZERO
+    Jarr(1, 1) = G/TWO + (G*(ONE + r(t)) - rdot(t))/(2*u*u)
+    Jarr(2, 1) = ZERO
+    Jarr(1, 2) = e/TWO + e*(TWO + s(t))/(TWO*v*v)
+    Jarr(2, 2) = ZERO
 
     ! return success
     ierr = 0
@@ -388,18 +388,18 @@ contains
     type(N_Vector)        :: y
     type(N_Vector)        :: fy
     type(SUNMatrix)       :: J
-    type(c_ptr),    value :: user_data
+    type(c_ptr), value :: user_data
     type(N_Vector)        :: tmp1, tmp2, tmp3
 
     real(c_double) :: u, v
     real(c_double), pointer, dimension(NEQ) :: yarr(:)
-    real(c_double), pointer, dimension(NEQ,NEQ) :: Jarr(:,:)
+    real(c_double), pointer, dimension(NEQ, NEQ) :: Jarr(:, :)
 
     ! get N_Vector data array
     yarr => FN_VGetArrayPointer(y)
 
     ! get Jacobian data array
-    Jarr(1:NEQ,1:NEQ) => FSUNDenseMatrix_Data(J)
+    Jarr(1:NEQ, 1:NEQ) => FSUNDenseMatrix_Data(J)
 
     ! extract variables
     u = yarr(1)
@@ -408,10 +408,10 @@ contains
     ! fill in the Jacobian:
     !  [G/2 + (G*(1+r(t)))/(2*u^2)   e/2+e*(2+s(t))/(2*v^2)]
     !  [                 0                             0   ]
-    Jarr(1,1) = G/TWO + (G*(ONE+r(t)))/(2*u*u)
-    Jarr(2,1) = ZERO
-    Jarr(1,2) = e/TWO + e*(TWO+s(t))/(TWO*v*v)
-    Jarr(2,2) = ZERO
+    Jarr(1, 1) = G/TWO + (G*(ONE + r(t)))/(2*u*u)
+    Jarr(2, 1) = ZERO
+    Jarr(1, 2) = e/TWO + e*(TWO + s(t))/(TWO*v*v)
+    Jarr(2, 2) = ZERO
 
     ! return success
     ierr = 0
@@ -430,18 +430,18 @@ contains
     type(N_Vector)        :: y
     type(N_Vector)        :: fy
     type(SUNMatrix)       :: J
-    type(c_ptr),    value :: user_data
+    type(c_ptr), value :: user_data
     type(N_Vector)        :: tmp1, tmp2, tmp3
 
     real(c_double) :: u, v
     real(c_double), pointer, dimension(NEQ) :: yarr(:)
-    real(c_double), pointer, dimension(NEQ,NEQ) :: Jarr(:,:)
+    real(c_double), pointer, dimension(NEQ, NEQ) :: Jarr(:, :)
 
     ! get N_Vector data array
     yarr => FN_VGetArrayPointer(y)
 
     ! get Jacobian data array
-    Jarr(1:NEQ,1:NEQ) => FSUNDenseMatrix_Data(J)
+    Jarr(1:NEQ, 1:NEQ) => FSUNDenseMatrix_Data(J)
 
     ! extract variables
     u = yarr(1)
@@ -450,10 +450,10 @@ contains
     ! fill in the Jacobian:
     ! [G/2 + (G*(1+r(t))-rdot(t))/(2*u^2)     e/2 + e*(2+s(t))/(2*v^2)]
     ! [e/2 + e*(1+r(t))/(2*u^2)              -1/2 - (2+s(t))/(2*v^2)]
-    Jarr(1,1) = G/TWO + (G*(1+r(t))-rdot(t))/(TWO*u*u)
-    Jarr(2,1) = e/TWO + e*(ONE+r(t))/(TWO*u*u)
-    Jarr(1,2) = e/TWO + e*(TWO+s(t))/(TWO*v*v)
-    Jarr(2,2) = -ONE/TWO - (TWO+s(t))/(TWO*v*v)
+    Jarr(1, 1) = G/TWO + (G*(1 + r(t)) - rdot(t))/(TWO*u*u)
+    Jarr(2, 1) = e/TWO + e*(ONE + r(t))/(TWO*u*u)
+    Jarr(1, 2) = e/TWO + e*(TWO + s(t))/(TWO*v*v)
+    Jarr(2, 2) = -ONE/TWO - (TWO + s(t))/(TWO*v*v)
 
     ! return success
     ierr = 0
@@ -526,7 +526,7 @@ contains
 
     real(c_double) :: t
 
-    result = sqrt(ONE+r(t))
+    result = sqrt(ONE + r(t))
     return
 
   end function utrue
@@ -540,7 +540,7 @@ contains
 
     real(c_double) :: t
 
-    result = sqrt(TWO+s(t))
+    result = sqrt(TWO + s(t))
     return
 
   end function vtrue
@@ -571,7 +571,6 @@ contains
 end module kpr_mod
 ! ------------------------------------------------------------------
 
-
 ! ------------------------------------------------------------------
 ! Main driver program
 ! ------------------------------------------------------------------
@@ -580,7 +579,6 @@ program main
   use kpr_mod
   implicit none
 
-
   ! general problem variables
   type(c_ptr) sunctx                                 ! SUNDIALS simulation context
   integer(c_int) :: retval                           ! reusable error-checking flag
@@ -600,11 +598,11 @@ program main
   logical :: imex_slow = .FALSE.
   real(c_double) :: hf, gamma, beta, t, tret(1), tout
   real(c_double) :: uerr, verr, uerrtot, verrtot, errtot
-  real(c_double), allocatable :: Af(:,:), bf(:), cf(:), df(:) ! Arrays for fast Butcher table, NOTE: must be in row-major order
-  real(c_double), allocatable :: As(:,:), bs(:), cs(:), ds(:) ! Arrays for slow Butcher table, NOTE: must be in row-major order
+  real(c_double), allocatable :: Af(:, :), bf(:), cf(:), df(:) ! Arrays for fast Butcher table, NOTE: must be in row-major order
+  real(c_double), allocatable :: As(:, :), bs(:), cs(:), ds(:) ! Arrays for slow Butcher table, NOTE: must be in row-major order
   integer(c_int) :: iout, argc, argi
   integer(c_long) :: nsts(1), nstf(1), nfse(1), nfsi(1), nff(1)
-  integer(c_long) :: nnif(1), nncf(1), njef(1), nnis(1), nncs(1), njes(1), tmp(1)
+  integer(c_long) :: nnif(1), nncf(1), njef(1), nnis(1), nncs(1), njes(1)
   character(len=32), dimension(:), allocatable :: argv
 
   !
@@ -622,18 +620,18 @@ program main
   LSs => null()
 
   argc = command_argument_count()
-  allocate(argv(argc))  ! I've omitted checking the return status of the allocation
+  allocate (argv(argc))  ! I've omitted checking the return status of the allocation
 
   do argi = 1, argc
     call get_command_argument(argi, argv(argi))
   end do
 
   ! Retrieve the command-line options: solve_type h G w e */
-  if (argc > 0) read(argv(1), *) solve_type
-  if (argc > 1) read(argv(2), *) hs
-  if (argc > 2) read(argv(3), *) G
-  if (argc > 3) read(argv(4), *) w
-  if (argc > 4) read(argv(5), *) e
+  if (argc > 0) read (argv(1), *) solve_type
+  if (argc > 1) read (argv(2), *) hs
+  if (argc > 2) read (argv(3), *) G
+  if (argc > 3) read (argv(4), *) w
+  if (argc > 4) read (argv(5), *) e
 
   ! Check arguments for validity
   !   0 <= solve_type <= 9
@@ -643,11 +641,11 @@ program main
   !   w >= 1.0
   if ((solve_type < 0) .or. (solve_type > 9)) then
     print *, "ERROR: solve_type be an integer in [0,9]"
-    stop -1
+    stop - 1
   end if
   if (G >= ZERO) then
     print *, "ERROR: G must be a negative real number"
-    stop -1
+    stop - 1
   end if
   implicit_slow = .false.
   if ((solve_type == 4) .or. (solve_type == 7)) then
@@ -659,15 +657,15 @@ program main
   end if
   if (hs <= ZERO) then
     print *, "ERROR: hs must be in positive"
-    stop -1
+    stop - 1
   end if
   if ((hs > ONE/abs(G)) .and. (.not. implicit_slow)) then
     print *, "ERROR: hs must be in (0, 1/|G|)"
-    stop -1
+    stop - 1
   end if
   if (w < ONE) then
     print *, "ERROR: w must be >= 1.0"
-    stop -1
+    stop - 1
   end if
   hf = hs/w
 
@@ -681,41 +679,41 @@ program main
   print '(A,E12.4,A)', "     e = ", e
 
   select case (solve_type)
-    case (0)
-      print *, "   solver: exp-3/exp-3 (standard MIS)"
-    case (1)
-      print *, "   solver: none/exp-3 (no slow, explicit fast)"
-    case (2)
-      reltol = max(hs*hs*hs, real(1e-10,8))
-      abstol = 1e-11
-      print *, "   solver: none/dirk-3 (no slow, dirk fast)"
-      print '(A,E12.4,A,E12.4)', "    reltol: ", reltol, " abstol: ", abstol
-    case (3)
-      print *, "   solver: exp-3/none (explicit slow, no fast)"
-    case (4)
-      reltol = max(hs*hs, real(1e-10,8))
-      abstol = 1e-11
-      print *, "   solver: dirk-2/none (dirk slow, no fast)"
-      print '(A,E12.4,A,E12.4)', "    reltol: ", reltol, " abstol: ", abstol
-    case (5)
-      print *, "   solver: exp-4/exp-4 (MRI-GARK-ERK45a / ERK-4-4)"
-    case (6)
-      print *, "   solver: exp-4/exp-3 (MRI-GARK-ERK45a / ERK-3-3)"
-    case (7)
-      reltol = max(hs*hs*hs, real(1e-10,8))
-      abstol = 1e-11
-      print *, "   solver: dirk-3/exp-3 (MRI-GARK-ESDIRK34a / ERK-3-3) -- solve decoupled"
-      print '(A,E12.4,A,E12.4)', "    reltol: ", reltol, " abstol: ", abstol
-    case (8)
-      reltol = max(hs*hs*hs, real(1e-10,8))
-      abstol = 1e-11
-      print *, "   solver: ars343/exp-3 (IMEX-MRI3b / ERK-3-3) -- solve decoupled"
-      print '(A,E12.4,A,E12.4)', "    reltol: ", reltol, " abstol: ", abstol
-    case (9)
-      reltol = max(hs*hs*hs*hs, real(1e-14,8))
-      abstol = 1e-14
-      print *, "   solver: imexark4/exp-4 (IMEX-MRI4 / ERK-4-4) -- solve decoupled"
-      print '(A,E12.4,A,E12.4)', "    reltol: ", reltol, " abstol: ", abstol
+  case (0)
+    print *, "   solver: exp-3/exp-3 (standard MIS)"
+  case (1)
+    print *, "   solver: none/exp-3 (no slow, explicit fast)"
+  case (2)
+    reltol = max(hs*hs*hs, real(1e-10, 8))
+    abstol = 1e-11
+    print *, "   solver: none/dirk-3 (no slow, dirk fast)"
+    print '(A,E12.4,A,E12.4)', "    reltol: ", reltol, " abstol: ", abstol
+  case (3)
+    print *, "   solver: exp-3/none (explicit slow, no fast)"
+  case (4)
+    reltol = max(hs*hs, real(1e-10, 8))
+    abstol = 1e-11
+    print *, "   solver: dirk-2/none (dirk slow, no fast)"
+    print '(A,E12.4,A,E12.4)', "    reltol: ", reltol, " abstol: ", abstol
+  case (5)
+    print *, "   solver: exp-4/exp-4 (MRI-GARK-ERK45a / ERK-4-4)"
+  case (6)
+    print *, "   solver: exp-4/exp-3 (MRI-GARK-ERK45a / ERK-3-3)"
+  case (7)
+    reltol = max(hs*hs*hs, real(1e-10, 8))
+    abstol = 1e-11
+    print *, "   solver: dirk-3/exp-3 (MRI-GARK-ESDIRK34a / ERK-3-3) -- solve decoupled"
+    print '(A,E12.4,A,E12.4)', "    reltol: ", reltol, " abstol: ", abstol
+  case (8)
+    reltol = max(hs*hs*hs, real(1e-10, 8))
+    abstol = 1e-11
+    print *, "   solver: ars343/exp-3 (IMEX-MRI3b / ERK-3-3) -- solve decoupled"
+    print '(A,E12.4,A,E12.4)', "    reltol: ", reltol, " abstol: ", abstol
+  case (9)
+    reltol = max(hs*hs*hs*hs, real(1e-14, 8))
+    abstol = 1e-14
+    print *, "   solver: imexark4/exp-4 (IMEX-MRI4 / ERK-4-4) -- solve decoupled"
+    print '(A,E12.4,A,E12.4)', "    reltol: ", reltol, " abstol: ", abstol
   end select
 
   ! Create the SUNDIALS context object for this simulation
@@ -738,23 +736,23 @@ program main
   !
 
   ! Initialize the fast integrator. Specify the fast right-hand side
-  ! function in y'=fs(t,y)+ff(t,y) = fse(t,y)+fsi(t,y)+ff(t,y), the inital time T0,
+  ! function in y'=fs(t,y)+ff(t,y) = fse(t,y)+fsi(t,y)+ff(t,y), the initial time T0,
   ! and the initial dependent variable vector y.
 
   if (solve_type == 0 .or. solve_type == 6 .or. solve_type == 7 .or. solve_type == 8) then
     ! erk-3-3 fast solver
     inner_arkode_mem = FARKStepCreate(c_funloc(ff), c_null_funptr, T0, y, sunctx)
-    allocate(Af(3,3))
-    allocate(bf(3))
-    allocate(cf(3))
-    allocate(df(3))
+    allocate (Af(3, 3))
+    allocate (bf(3))
+    allocate (cf(3))
+    allocate (df(3))
     Af = 0.d0
     bf = 0.d0
     cf = 0.d0
     df = 0.d0
-    Af(1,2) = 0.5d0
-    Af(1,3) = -ONE
-    Af(2,3) = TWO
+    Af(1, 2) = 0.5d0
+    Af(1, 3) = -ONE
+    Af(2, 3) = TWO
     bf(1) = ONE/6.0d0
     bf(2) = TWO/3.0d0
     bf(3) = ONE/6.0d0
@@ -768,17 +766,17 @@ program main
   else if (solve_type == 1) then
     ! erk-3-3 fast solver (full problem)
     inner_arkode_mem = FARKStepCreate(c_funloc(fn), c_null_funptr, T0, y, sunctx)
-    allocate(Af(3,3))
-    allocate(bf(3))
-    allocate(cf(3))
-    allocate(df(3))
+    allocate (Af(3, 3))
+    allocate (bf(3))
+    allocate (cf(3))
+    allocate (df(3))
     Af = 0.d0
     bf = 0.d0
     cf = 0.d0
     df = 0.d0
-    Af(1,2) = 0.5d0
-    Af(1,3) = -ONE
-    Af(2,3) = TWO
+    Af(1, 2) = 0.5d0
+    Af(1, 3) = -ONE
+    Af(2, 3) = TWO
     bf(1) = ONE/6.0d0
     bf(2) = TWO/3.0d0
     bf(3) = ONE/6.0d0
@@ -792,17 +790,17 @@ program main
   else if (solve_type == 5 .or. solve_type == 9) then
     ! erk-4-4 fast solver
     inner_arkode_mem = FARKStepCreate(c_funloc(ff), c_null_funptr, T0, y, sunctx)
-    allocate(Af(4,4))
-    allocate(bf(4))
-    allocate(cf(4))
-    allocate(df(4))
+    allocate (Af(4, 4))
+    allocate (bf(4))
+    allocate (cf(4))
+    allocate (df(4))
     Af = 0.d0
     bf = 0.d0
     cf = 0.d0
     df = 0.d0
-    Af(1,2) = 0.5d0
-    Af(2,3) = 0.5d0
-    Af(3,4) = ONE
+    Af(1, 2) = 0.5d0
+    Af(2, 3) = 0.5d0
+    Af(3, 4) = ONE
     bf(1) = ONE/6.0d0
     bf(2) = ONE/3.0d0
     bf(3) = ONE/3.0d0
@@ -817,21 +815,21 @@ program main
   else if (solve_type == 2) then
     ! esdirk-3-3 fast solver (full problem)
     inner_arkode_mem = FARKStepCreate(c_null_funptr, c_funloc(fn), T0, y, sunctx)
-    beta  = sqrt(3.0d0)/6.0d0 + 0.5d00
-    gamma = (-ONE/8.0d0)*(sqrt(3.0d0)+ONE)
-    allocate(Af(3,3))
-    allocate(bf(3))
-    allocate(cf(3))
-    allocate(df(3))
+    beta = sqrt(3.0d0)/6.0d0 + 0.5d00
+    gamma = (-ONE/8.0d0)*(sqrt(3.0d0) + ONE)
+    allocate (Af(3, 3))
+    allocate (bf(3))
+    allocate (cf(3))
+    allocate (df(3))
     Af = 0.d0
     bf = 0.d0
     cf = 0.d0
     df = 0.d0
-    Af(1,2) = 4.0d0*gamma+TWO*beta
-    Af(2,2) = ONE-4.0d0*gamma-TWO*beta
-    Af(1,3) = 0.5d0-beta-gamma
-    Af(2,3) = gamma
-    Af(3,3) = beta
+    Af(1, 2) = 4.0d0*gamma + TWO*beta
+    Af(2, 2) = ONE - 4.0d0*gamma - TWO*beta
+    Af(1, 3) = 0.5d0 - beta - gamma
+    Af(2, 3) = gamma
+    Af(3, 3) = beta
     bf(1) = ONE/6.0d0
     bf(2) = ONE/6.0d0
     bf(3) = TWO/3.0d0
@@ -842,27 +840,27 @@ program main
     call check_retval(retval, "FARKStepSetTables")
     MATf => FSUNDenseMatrix(NEQ, NEQ, sunctx)
     LSf => FSUNLinSol_Dense(y, MATf, sunctx)
-    retval = FARKStepSetLinearSolver(inner_arkode_mem, LSf, MATf)
-    call check_retval(retval, "FARKStepSetLinearSolver")
-    retval = FARKStepSetJacFn(inner_arkode_mem, c_funloc(Jn))
-    call check_retval(retval, "FARKStepSetJacFn")
-    retval = FARKStepSStolerances(inner_arkode_mem, reltol, abstol)
-    call check_retval(retval, "FARKStepSStolerances")
+    retval = FARKodeSetLinearSolver(inner_arkode_mem, LSf, MATf)
+    call check_retval(retval, "FARKodeSetLinearSolver")
+    retval = FARKodeSetJacFn(inner_arkode_mem, c_funloc(Jn))
+    call check_retval(retval, "FARKodeSetJacFn")
+    retval = FARKodeSStolerances(inner_arkode_mem, reltol, abstol)
+    call check_retval(retval, "FARKodeSStolerances")
     call FARKodeButcherTable_Free(BTf)
   else if (solve_type == 3 .or. solve_type == 4) then
     ! no fast dynamics ('evolve' explicitly w/ erk-3-3)
     inner_arkode_mem = FARKStepCreate(c_funloc(f0), c_null_funptr, T0, y, sunctx)
-    allocate(Af(3,3))
-    allocate(bf(3))
-    allocate(cf(3))
-    allocate(df(3))
+    allocate (Af(3, 3))
+    allocate (bf(3))
+    allocate (cf(3))
+    allocate (df(3))
     Af = 0.d0
     bf = 0.d0
     cf = 0.d0
     df = 0.d0
-    Af(1,2) = 0.5d0
-    Af(1,3) = -ONE
-    Af(2,3) = TWO
+    Af(1, 2) = 0.5d0
+    Af(1, 3) = -ONE
+    Af(2, 3) = TWO
     bf(1) = ONE/6.0d0
     bf(2) = TWO/3.0d0
     bf(3) = ONE/6.0d0
@@ -881,16 +879,16 @@ program main
   end if
 
   ! Set the fast step size */
-  retval = FARKStepSetFixedStep(inner_arkode_mem, hf)
+  retval = FARKodeSetFixedStep(inner_arkode_mem, hf)
   if (retval /= 0) then
-    print *, 'ERROR: FARKStepSetFixedStep failed'
+    print *, 'ERROR: FARKodeSetFixedStep failed'
     stop 1
   end if
 
   ! Create inner stepper */
-  retval = FARKStepCreateMRIStepInnerStepper(inner_arkode_mem, inner_stepper)
+  retval = FARKodeCreateMRIStepInnerStepper(inner_arkode_mem, inner_stepper)
   if (retval /= 0) then
-    print *, 'ERROR: FARKStepCreateMRIStepInnerStepper failed'
+    print *, 'ERROR: FARKodeCreateMRIStepInnerStepper failed'
     stop 1
   end if
 
@@ -899,7 +897,7 @@ program main
   !
 
   ! Initialize the slow integrator. Specify the slow right-hand side
-  ! function in y'=fs(t,y)+ff(t,y) = fse(t,y)+fsi(t,y)+ff(t,y), the inital time
+  ! function in y'=fs(t,y)+ff(t,y) = fse(t,y)+fsi(t,y)+ff(t,y), the initial time
   ! T0, the initial dependent variable vector y, and the fast integrator.
   if (solve_type == 0) then
     ! KW3 slow solver
@@ -926,15 +924,15 @@ program main
       print *, 'ERROR: arkode_mem = NULL'
       stop 1
     end if
-    allocate(As(2,2))
-    allocate(bs(2))
-    allocate(cs(2))
-    allocate(ds(2))
+    allocate (As(2, 2))
+    allocate (bs(2))
+    allocate (cs(2))
+    allocate (ds(2))
     As = 0.d0
     bs = 0.d0
     cs = 0.d0
     ds = 0.d0
-    As(1,2) = TWO/3.0d0
+    As(1, 2) = TWO/3.0d0
     bs(1) = 0.25d0
     bs(2) = 0.75d0
     cs(2) = TWO/3.0d0
@@ -951,12 +949,12 @@ program main
     call check_retval(retval, "FMRIStepSetCoupling")
     MATs => FSUNDenseMatrix(NEQ, NEQ, sunctx)
     LSs => FSUNLinSol_Dense(y, MATs, sunctx)
-    retval = FMRIStepSetLinearSolver(arkode_mem, LSs, MATs)
-    call check_retval(retval, "FMRIStepSetLinearSolver")
-    retval = FMRIStepSetJacFn(arkode_mem, c_funloc(Jn))
-    call check_retval(retval, "FMRIStepSetJacFn")
-    retval = FMRIStepSStolerances(arkode_mem, reltol, abstol)
-    call check_retval(retval, "FMRIStepSStolerances")
+    retval = FARKodeSetLinearSolver(arkode_mem, LSs, MATs)
+    call check_retval(retval, "FARKodeSetLinearSolver")
+    retval = FARKodeSetJacFn(arkode_mem, c_funloc(Jn))
+    call check_retval(retval, "FARKodeSetJacFn")
+    retval = FARKodeSStolerances(arkode_mem, reltol, abstol)
+    call check_retval(retval, "FARKodeSStolerances")
   else if (solve_type == 7) then
     ! MRI-GARK-ESDIRK34a, solve-decoupled slow solver
     arkode_mem = FMRIStepCreate(c_null_funptr, c_funloc(fs), T0, y, inner_stepper, sunctx)
@@ -965,12 +963,12 @@ program main
     call check_retval(retval, "FMRIStepSetCoupling")
     MATs => FSUNDenseMatrix(NEQ, NEQ, sunctx)
     LSs => FSUNLinSol_Dense(y, MATs, sunctx)
-    retval = FMRIStepSetLinearSolver(arkode_mem, LSs, MATs)
-    call check_retval(retval, "FMRIStepSetLinearSolver")
-    retval = FMRIStepSetJacFn(arkode_mem, c_funloc(Js))
-    call check_retval(retval, "FMRIStepSetJacFn")
-    retval = FMRIStepSStolerances(arkode_mem, reltol, abstol)
-    call check_retval(retval, "FMRIStepSStolerances")
+    retval = FARKodeSetLinearSolver(arkode_mem, LSs, MATs)
+    call check_retval(retval, "FARKodeSetLinearSolver")
+    retval = FARKodeSetJacFn(arkode_mem, c_funloc(Js))
+    call check_retval(retval, "FARKodeSetJacFn")
+    retval = FARKodeSStolerances(arkode_mem, reltol, abstol)
+    call check_retval(retval, "FARKodeSStolerances")
   else if (solve_type == 8) then
     ! IMEX-MRI-GARK3b, solve-decoupled slow solver
     arkode_mem = FMRIStepCreate(c_funloc(fse), c_funloc(fsi), T0, y, inner_stepper, sunctx)
@@ -979,12 +977,12 @@ program main
     call check_retval(retval, "FMRIStepSetCoupling")
     MATs => FSUNDenseMatrix(NEQ, NEQ, sunctx)
     LSs => FSUNLinSol_Dense(y, MATs, sunctx)
-    retval = FMRIStepSetLinearSolver(arkode_mem, LSs, MATs)
-    call check_retval(retval, "FMRIStepSetLinearSolver")
-    retval = FMRIStepSetJacFn(arkode_mem, c_funloc(Jsi))
-    call check_retval(retval, "FMRIStepSetJacFn")
-    retval = FMRIStepSStolerances(arkode_mem, reltol, abstol)
-    call check_retval(retval, "FMRIStepSStolerances")
+    retval = FARKodeSetLinearSolver(arkode_mem, LSs, MATs)
+    call check_retval(retval, "FARKodeSetLinearSolver")
+    retval = FARKodeSetJacFn(arkode_mem, c_funloc(Jsi))
+    call check_retval(retval, "FARKodeSetJacFn")
+    retval = FARKodeSStolerances(arkode_mem, reltol, abstol)
+    call check_retval(retval, "FARKodeSStolerances")
   else if (solve_type == 9) then
     ! IMEX-MRI-GARK4, solve-decoupled slow solver
     arkode_mem = FMRIStepCreate(c_funloc(fse), c_funloc(fsi), T0, y, inner_stepper, sunctx)
@@ -992,12 +990,12 @@ program main
     retval = FMRIStepSetCoupling(arkode_mem, SC)
     MATs => FSUNDenseMatrix(NEQ, NEQ, sunctx)
     LSs => FSUNLinSol_Dense(y, MATs, sunctx)
-    retval = FMRIStepSetLinearSolver(arkode_mem, LSs, MATs)
-    call check_retval(retval, "FMRIStepSetLinearSolver")
-    retval = FMRIStepSetJacFn(arkode_mem, c_funloc(Jsi))
-    call check_retval(retval, "FMRIStepSetJacFn")
-    retval = FMRIStepSStolerances(arkode_mem, reltol, abstol)
-    call check_retval(retval, "FMRIStepSStolerances")
+    retval = FARKodeSetLinearSolver(arkode_mem, LSs, MATs)
+    call check_retval(retval, "FARKodeSetLinearSolver")
+    retval = FARKodeSetJacFn(arkode_mem, c_funloc(Jsi))
+    call check_retval(retval, "FARKodeSetJacFn")
+    retval = FARKodeSStolerances(arkode_mem, reltol, abstol)
+    call check_retval(retval, "FARKodeSStolerances")
   end if
 
   if (.not. c_associated(arkode_mem)) then
@@ -1006,23 +1004,23 @@ program main
   end if
 
   ! Set the slow step size
-  retval = FMRIStepSetFixedStep(arkode_mem, hs)
-  call check_retval(retval, "FMRIStepSetFixedStep")
+  retval = FARKodeSetFixedStep(arkode_mem, hs)
+  call check_retval(retval, "FARKodeSetFixedStep")
 
   !
   ! Integrate ODE
   !
 
-  ! Main time-stepping loop: calls MRIStepEvolve to perform the
+  ! Main time-stepping loop: calls ARKodeEvolve to perform the
   ! integration, then prints results. Stops when the final time
   ! has been reached
   t = T0
-  tout = T0+dTout
+  tout = T0 + dTout
   uerr = ZERO
   verr = ZERO
   uerrtot = ZERO
   verrtot = ZERO
-  errtot  = ZERO
+  errtot = ZERO
   print *, "        t           u           v       uerr      verr"
   print *, "   ------------------------------------------------------"
   print '(A, F10.6, A, F10.6, A, F10.6, A, E9.2, A, E9.2)', &
@@ -1030,14 +1028,14 @@ program main
 
   do iout = 1, Nt
     ! call integrator
-    retval = FMRIStepEvolve(arkode_mem, tout, y, tret, ARK_NORMAL)
-    call check_retval(retval, "FMRIStepEvolve")
+    retval = FARKodeEvolve(arkode_mem, tout, y, tret, ARK_NORMAL)
+    call check_retval(retval, "FARKodeEvolve")
 
     ! access/print solution and error
-    uerr = abs(yarr(1)-utrue(tret(1)))
-    verr = abs(yarr(2)-vtrue(tret(1)))
+    uerr = abs(yarr(1) - utrue(tret(1)))
+    verr = abs(yarr(2) - vtrue(tret(1)))
     print '(A, F10.6, A, F10.6, A, F10.6, A, E9.2, A, E9.2)', &
-    "   ", tret(1), "  ", yarr(1), "  ", yarr(2), "  ", uerr, "  ", verr
+      "   ", tret(1), "  ", yarr(1), "  ", yarr(2), "  ", uerr, "  ", verr
     uerrtot = uerrtot + uerr*uerr
     verrtot = verrtot + verr*verr
     errtot = errtot + uerr*uerr + verr*verr
@@ -1047,10 +1045,10 @@ program main
     if (tout > Tf) then
       tout = Tf
     end if
-  enddo
-  uerrtot = sqrt(uerrtot / Nt)
-  verrtot = sqrt(verrtot / Nt)
-  errtot = sqrt(errtot / Nt / 2)
+  end do
+  uerrtot = sqrt(uerrtot/Nt)
+  verrtot = sqrt(verrtot/Nt)
+  errtot = sqrt(errtot/Nt/2)
   print *, "   ------------------------------------------------------"
 
   !
@@ -1058,12 +1056,13 @@ program main
   !
 
   ! Get some slow integrator statistics
-  retval = FMRIStepGetNumSteps(arkode_mem, nsts)
-  retval = FMRIStepGetNumRhsEvals(arkode_mem, nfse, nfsi)
+  retval = FARKodeGetNumSteps(arkode_mem, nsts)
+  retval = FARKodeGetNumRhsEvals(arkode_mem, 0, nfse)
+  retval = FARKodeGetNumRhsEvals(arkode_mem, 1, nfsi)
 
   ! Get some fast integrator statistics
-  retval = FARKStepGetNumSteps(inner_arkode_mem, nstf)
-  retval = FARKStepGetNumRhsEvals(inner_arkode_mem, nff, tmp)
+  retval = FARKodeGetNumSteps(inner_arkode_mem, nstf)
+  retval = FARKodeGetNumRhsEvals(inner_arkode_mem, 0, nff)
 
   ! Print some final statistics
   print *, "Final Solver Statistics:"
@@ -1080,10 +1079,10 @@ program main
   ! Get/print slow integrator decoupled implicit solver statistics
   if ((solve_type == 4) .or. (solve_type == 7) .or. &
       (solve_type == 8) .or. (solve_type == 9)) then
-    retval = FMRIStepGetNonlinSolvStats(arkode_mem, nnis, nncs)
-    call check_retval(retval, "MRIStepGetNonlinSolvStats")
-    retval = FMRIStepGetNumJacEvals(arkode_mem, njes)
-    call check_retval(retval, "MRIStepGetNumJacEvals")
+    retval = FARKodeGetNonlinSolvStats(arkode_mem, nnis, nncs)
+    call check_retval(retval, "ARKodeGetNonlinSolvStats")
+    retval = FARKodeGetNumJacEvals(arkode_mem, njes)
+    call check_retval(retval, "ARKodeGetNumJacEvals")
     print '(A, I7)', "   Slow Newton iters = ", nnis
     print '(A, I7)', "   Slow Newton conv fails = ", nncs
     print '(A, I7)', "   Slow Jacobian evals = ", njes
@@ -1091,34 +1090,34 @@ program main
 
   ! Get/print fast integrator implicit solver statistics
   if (solve_type == 2) then
-    retval = FARKStepGetNonlinSolvStats(inner_arkode_mem, nnif, nncf)
-    call check_retval(retval, "ARKStepGetNonlinSolvStats")
-    retval = FARKStepGetNumJacEvals(inner_arkode_mem, njef)
-    call check_retval(retval, "ARKStepGetNumJacEvals")
+    retval = FARKodeGetNonlinSolvStats(inner_arkode_mem, nnif, nncf)
+    call check_retval(retval, "ARKodeGetNonlinSolvStats")
+    retval = FARKodeGetNumJacEvals(inner_arkode_mem, njef)
+    call check_retval(retval, "ARKodeGetNumJacEvals")
     print '(A, I7)', "   Fast Newton iters = ", nnif
     print '(A, I7)', "   Fast Newton conv fails = ", nncf
     print '(A, I7)', "   Fast Jacobian evals = ", njef
   end if
 
   ! Clean up and return
-  if (allocated(argv)) deallocate(argv)
-  if (allocated(Af)) deallocate(Af)
-  if (allocated(bf)) deallocate(bf)
-  if (allocated(cf)) deallocate(cf)
-  if (allocated(df)) deallocate(df)
-  if (allocated(As)) deallocate(As)
-  if (allocated(bs)) deallocate(bs)
-  if (allocated(cs)) deallocate(cs)
-  if (allocated(ds)) deallocate(ds)
+  if (allocated(argv)) deallocate (argv)
+  if (allocated(Af)) deallocate (Af)
+  if (allocated(bf)) deallocate (bf)
+  if (allocated(cf)) deallocate (cf)
+  if (allocated(df)) deallocate (df)
+  if (allocated(As)) deallocate (As)
+  if (allocated(bs)) deallocate (bs)
+  if (allocated(cs)) deallocate (cs)
+  if (allocated(ds)) deallocate (ds)
   call FN_VDestroy(y)                                ! Free y vector
   call FMRIStepCoupling_Free(SC)                     ! Free coupling coefficients
   if (associated(MATf)) call FSUNMatDestroy(MATf)    ! Free fast matrix
   if (associated(LSf)) retval = FSUNLinSolFree(LSf)  ! Free fast linear solver
   if (associated(MATs)) call FSUNMatDestroy(MATs)    ! Free slow matrix
   if (associated(LSs)) retval = FSUNLinSolFree(LSs)  ! Free slow linear solver
-  call FARKStepFree(inner_arkode_mem)                ! Free fast integrator memory
+  call FARKodeFree(inner_arkode_mem)                 ! Free fast integrator memory
   retval = FMRIStepInnerStepper_Free(inner_stepper)  ! Free inner stepper
-  call FMRIStepFree(arkode_mem)                      ! Free slow integrator memory
+  call FARKodeFree(arkode_mem)                       ! Free slow integrator memory
   retval = FSUNContext_Free(sunctx)                  ! Free context
 
 end program main
@@ -1131,7 +1130,7 @@ subroutine check_retval(retval, name)
   integer(c_int)   :: retval
 
   if (retval /= 0) then
-    write(*,'(A,A,A)') 'ERROR: ', name,' returned nonzero'
+    write (*, '(A,A,A)') 'ERROR: ', name, ' returned nonzero'
     stop 1
   end if
 end subroutine check_retval
