@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * ---------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2023, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -37,43 +37,27 @@
  * are printed at the end.
  * ---------------------------------------------------------------------------*/
 
-#include <cstdlib>
 #include <cmath>
+#include <cstdlib>
+#include <cvode/cvode.h> // access CVODE fcts., consts.
 #include <iostream>
-
-#include <cvode/cvode.h>               // access CVODE fcts., consts.
-#include <nvector/nvector_sycl.h>      // access the SYCL NVector
+#include <nvector/nvector_sycl.h> // access the SYCL NVector
+#include <sundials/sundials_core.hpp>
 #include <sunlinsol/sunlinsol_spgmr.h> // access the SPGMR SUNLinearSolver
 
 // Real Constants
 
-#define ATOL  RCONST(1.0e-5) // scalar absolute tolerance
-#define T0    RCONST(0.0)    // initial time
-#define T1    RCONST(0.1)    // first output time
-#define DTOUT RCONST(0.1)    // output time increment
-#define NOUT  10             // number of output times
+#define ATOL  SUN_RCONST(1.0e-5) // scalar absolute tolerance
+#define T0    SUN_RCONST(0.0)    // initial time
+#define T1    SUN_RCONST(0.1)    // first output time
+#define DTOUT SUN_RCONST(0.1)    // output time increment
+#define NOUT  10                 // number of output times
 
-#define ZERO RCONST(0.0)
-#define HALF RCONST(0.5)
-#define ONE  RCONST(1.0)
-#define TWO  RCONST(2.0)
-#define FIVE RCONST(5.0)
-
-#if defined(SUNDIALS_EXTENDED_PRECISION)
-#define GSYM "Lg"
-#define ESYM "Le"
-#define FSYM "Lf"
-#else
-#define GSYM "g"
-#define ESYM "e"
-#define FSYM "f"
-#endif
-
-#if defined(SUNDIALS_INT64_T)
-#define DSYM "ld"
-#else
-#define DSYM "d"
-#endif
+#define ZERO SUN_RCONST(0.0)
+#define HALF SUN_RCONST(0.5)
+#define ONE  SUN_RCONST(1.0)
+#define TWO  SUN_RCONST(2.0)
+#define FIVE SUN_RCONST(5.0)
 
 // User data sstructure contains model and discretization parameters
 struct UserData
@@ -82,29 +66,28 @@ struct UserData
   sunindextype MX      = 10;                // interior nodes in the x-direction
   sunindextype MY      = 5;                 // interior nodes in the y-direction
   sunindextype NEQ     = MX * MY;           // number of equations
-  realtype     xmax    = RCONST(2.0);       // x-domain boundary
-  realtype     ymax    = RCONST(1.0);       // y-domain boundary
-  realtype     dx      = xmax / (MX + 1);   // x-direction mesh spacing
-  realtype     dy      = ymax / (MY + 1);   // y-directino mesh spacing
-  realtype     hdcoef  = ONE / (dx * dx);   // x-diffusion
-  realtype     vdcoef  = ONE / (dy * dy);   // y-diffusion
-  realtype     hacoef  = HALF / (TWO * dx); // x-advection
+  sunrealtype xmax     = SUN_RCONST(2.0);   // x-domain boundary
+  sunrealtype ymax     = SUN_RCONST(1.0);   // y-domain boundary
+  sunrealtype dx       = xmax / (MX + 1);   // x-direction mesh spacing
+  sunrealtype dy       = ymax / (MY + 1);   // y-directino mesh spacing
+  sunrealtype hdcoef   = ONE / (dx * dx);   // x-diffusion
+  sunrealtype vdcoef   = ONE / (dy * dy);   // y-diffusion
+  sunrealtype hacoef   = HALF / (TWO * dx); // x-advection
 };
 
 // Functions Called by the Solver
-static int f(realtype t, N_Vector u, N_Vector udot, void* user_data);
-static int jtv(N_Vector v, N_Vector Jv, realtype t,
-               N_Vector u, N_Vector fu,
+static int f(sunrealtype t, N_Vector u, N_Vector udot, void* user_data);
+static int jtv(N_Vector v, N_Vector Jv, sunrealtype t, N_Vector u, N_Vector fu,
                void* user_data, N_Vector tmp);
 
 // Private Helper Functions
-static void PrintHeader(realtype reltol, realtype abstol, realtype umax,
-                        UserData* data);
-static void PrintOutput(realtype t, realtype umax, long int nst);
+static void PrintHeader(sunrealtype reltol, sunrealtype abstol,
+                        sunrealtype umax, UserData* data);
+static void PrintOutput(sunrealtype t, sunrealtype umax, long int nst);
 static void PrintFinalStats(void* cvode_mem);
 
 // Private function to check function return values
-static int check_retval(void* returnvalue, const char *funcname, int opt);
+static int check_retval(void* returnvalue, const char* funcname, int opt);
 
 /* ---------------------------------------------------------------------------
  * Main Program
@@ -119,7 +102,7 @@ int main(int argc, char** argv)
   int retval;
 
   // Create an in-order GPU queue
-#if SYCL_LANGUAGE_VERSION >= 2020
+#if SYCL_LANGUAGE_VERSION >= 2020 && !defined(SUNDIALS_SYCL_2020_UNSUPPORTED)
   sycl::queue myQueue(sycl::gpu_selector_v,
                       sycl::property_list{sycl::property::queue::in_order{}});
 #else
@@ -129,8 +112,7 @@ int main(int argc, char** argv)
 #endif
 
   sycl::device dev = myQueue.get_device();
-  std::cout << "Running on "
-            << (dev.get_info<sycl::info::device::name>())
+  std::cout << "Running on " << (dev.get_info<sycl::info::device::name>())
             << std::endl;
 
   // Create user data and set queue
@@ -139,10 +121,10 @@ int main(int argc, char** argv)
 
   // Create a SYCL vector
   N_Vector u = N_VNew_Sycl(data.NEQ, &myQueue, sunctx);
-  if (check_retval((void*)u, "N_VNew_Sycl", 0)) return 1;
+  if (check_retval((void*)u, "N_VNew_Sycl", 0)) { return 1; }
 
   // Extract host pointer to solution vector data on the host
-  realtype* udata = N_VGetArrayPointer(u);
+  sunrealtype* udata = N_VGetArrayPointer(u);
 
   // Load initial profile into u vector
   for (sunindextype tid = 0; tid < data.NEQ; tid++)
@@ -150,11 +132,11 @@ int main(int argc, char** argv)
     sunindextype i = tid / data.MY; // x-node index
     sunindextype j = tid % data.MY; // y-node index
 
-    realtype x = (i + 1) * data.dx; // x location
-    realtype y = (j + 1) * data.dy; // y location
+    sunrealtype x = (i + 1) * data.dx; // x location
+    sunrealtype y = (j + 1) * data.dy; // y location
 
-    udata[tid] =
-      x * (data.xmax - x) * y * (data.ymax - y) * std::exp(FIVE * x * y);
+    udata[tid] = x * (data.xmax - x) * y * (data.ymax - y) *
+                 std::exp(FIVE * x * y);
   }
 
   // Copy data to device
@@ -162,51 +144,51 @@ int main(int argc, char** argv)
 
   // Create CVODE and specify the Backward Differentiation Formula
   void* cvode_mem = CVodeCreate(CV_BDF, sunctx);
-  if (check_retval((void *)cvode_mem, "CVodeCreate", 0)) return 1;
+  if (check_retval((void*)cvode_mem, "CVodeCreate", 0)) { return 1; }
 
   // Specify the right hand side function in f(t,u), initial condition (t0, u0)
   retval = CVodeInit(cvode_mem, f, T0, u);
-  if (check_retval(&retval, "CVodeInit", 1)) return 1;
+  if (check_retval(&retval, "CVodeInit", 1)) { return 1; }
 
   // Specify the scalar relative tolerance and scalar absolute tolerance
-  realtype reltol = ZERO;
-  realtype abstol = ATOL;
-  retval = CVodeSStolerances(cvode_mem, reltol, abstol);
-  if (check_retval(&retval, "CVodeSStolerances", 1)) return 1;
+  sunrealtype reltol = ZERO;
+  sunrealtype abstol = ATOL;
+  retval             = CVodeSStolerances(cvode_mem, reltol, abstol);
+  if (check_retval(&retval, "CVodeSStolerances", 1)) { return 1; }
 
   // Set the pointer to user-defined data
   retval = CVodeSetUserData(cvode_mem, &data);
-  if (check_retval(&retval, "CVodeSetUserData", 1)) return 1;
+  if (check_retval(&retval, "CVodeSetUserData", 1)) { return 1; }
 
   // Create SPGMR solver without preconditioning and default Krylov dimension
   SUNLinearSolver LS = SUNLinSol_SPGMR(u, SUN_PREC_NONE, 0, sunctx);
-  if (check_retval(&retval, "SUNLinSol_SPGMR", 1)) return 1;
+  if (check_retval(&retval, "SUNLinSol_SPGMR", 1)) { return 1; }
 
-  // Attach the linear sovler to CVODE
+  // Attach the linear solver to CVODE
   retval = CVodeSetLinearSolver(cvode_mem, LS, NULL);
-  if (check_retval(&retval, "CVodeSetLinearSolver", 1)) return 1;
+  if (check_retval(&retval, "CVodeSetLinearSolver", 1)) { return 1; }
 
   // Set the Jacobian-times-vector function
   retval = CVodeSetJacTimes(cvode_mem, NULL, jtv);
-  if (check_retval(&retval, "CVodeSetJacTimesVecFn", 1)) return 1;
+  if (check_retval(&retval, "CVodeSetJacTimesVecFn", 1)) { return 1; }
 
   // In loop over output points: call CVODE, print results, test for errors
-  realtype umax = N_VMaxNorm(u);
+  sunrealtype umax = N_VMaxNorm(u);
   PrintHeader(reltol, abstol, umax, &data);
 
-  realtype tout = T1; // output time
-  realtype t;         // CVODE return time
-  long int nst;       // number of time steps
+  sunrealtype tout = T1; // output time
+  sunrealtype t;         // CVODE return time
+  long int nst;          // number of time steps
 
   for (int iout = 0; iout < NOUT; iout++)
   {
     // Advance in time
     retval = CVode(cvode_mem, tout, u, &t, CV_NORMAL);
-    if (check_retval(&retval, "CVode", 1)) break;
+    if (check_retval(&retval, "CVode", 1)) { break; }
 
     // Output status
     retval = CVodeGetNumSteps(cvode_mem, &nst);
-    if (check_retval(&retval, "CVodeGetNumSteps", 1)) break;
+    if (check_retval(&retval, "CVodeGetNumSteps", 1)) { break; }
 
     umax = N_VMaxNorm(u);
     PrintOutput(t, umax, nst);
@@ -215,97 +197,101 @@ int main(int argc, char** argv)
     tout += DTOUT;
   }
 
-  PrintFinalStats(cvode_mem);  // Print some final statistics
+  PrintFinalStats(cvode_mem); // Print some final statistics
 
-  N_VDestroy(u);          // Free the u vector
-  CVodeFree(&cvode_mem);  // Free the integrator memory
-  SUNLinSolFree(LS);      // Free linear solver memory
+  N_VDestroy(u);         // Free the u vector
+  CVodeFree(&cvode_mem); // Free the integrator memory
+  SUNLinSolFree(LS);     // Free linear solver memory
 
   return 0;
 }
 
-
 /* ---------------------------------------------------------------------------
  * Functions called by the solver
  * ---------------------------------------------------------------------------*/
 
 // Compute the ODE right-hand side function f(t,u).
-static int f(realtype t, N_Vector u, N_Vector udot, void* user_data)
+static int f(sunrealtype t, N_Vector u, N_Vector udot, void* user_data)
 {
   UserData* data = static_cast<UserData*>(user_data);
 
   // Extract needed constants from data
-  const size_t   MX    = static_cast<size_t>(data->MX);
-  const size_t   MY    = static_cast<size_t>(data->MY);
-  const realtype hordc = data->hdcoef;
-  const realtype horac = data->hacoef;
-  const realtype verdc = data->vdcoef;
+  const size_t MX         = static_cast<size_t>(data->MX);
+  const size_t MY         = static_cast<size_t>(data->MY);
+  const sunrealtype hordc = data->hdcoef;
+  const sunrealtype horac = data->hacoef;
+  const sunrealtype verdc = data->vdcoef;
 
   // Extract pointers to vector data
-  const realtype* udata  = N_VGetDeviceArrayPointer(u);
-  realtype*       dudata = N_VGetDeviceArrayPointer(udot);
+  const sunrealtype* udata = N_VGetDeviceArrayPointer(u);
+  sunrealtype* dudata      = N_VGetDeviceArrayPointer(udot);
 
-  data->myQueue->submit([&](sycl::handler& h)
-  {
-    h.parallel_for(sycl::range{MX, MY}, [=](sycl::id<2> idx)
+  data->myQueue->submit(
+    [&](sycl::handler& h)
     {
-      sunindextype i   = idx[0];
-      sunindextype j   = idx[1];
-      sunindextype tid = i * MY + j;
+      h.parallel_for(sycl::range{MX, MY},
+                     [=](sycl::id<2> idx)
+                     {
+                       size_t i   = idx[0];
+                       size_t j   = idx[1];
+                       size_t tid = i * MY + j;
 
-      realtype uij = udata[tid];
-      realtype udn = (j ==      0) ? ZERO : udata[tid - 1];
-      realtype uup = (j == MY - 1) ? ZERO : udata[tid + 1];
-      realtype ult = (i ==      0) ? ZERO : udata[tid - MY];
-      realtype urt = (i == MX - 1) ? ZERO : udata[tid + MY];
+                       sunrealtype uij = udata[tid];
+                       sunrealtype udn = (j == 0) ? ZERO : udata[tid - 1];
+                       sunrealtype uup = (j == MY - 1) ? ZERO : udata[tid + 1];
+                       sunrealtype ult = (i == 0) ? ZERO : udata[tid - MY];
+                       sunrealtype urt = (i == MX - 1) ? ZERO : udata[tid + MY];
 
-      // Set diffusion and advection terms and load into udot
-      realtype hdiff = hordc * (ult - TWO * uij + urt);
-      realtype vdiff = verdc * (uup - TWO * uij + udn);
-      realtype hadv  = horac * (urt - ult);
+                       // Set diffusion and advection terms and load into udot
+                       sunrealtype hdiff = hordc * (ult - TWO * uij + urt);
+                       sunrealtype vdiff = verdc * (uup - TWO * uij + udn);
+                       sunrealtype hadv  = horac * (urt - ult);
 
-      dudata[tid] = hdiff + vdiff + hadv;
+                       dudata[tid] = hdiff + vdiff + hadv;
+                     });
     });
-  });
 
   return 0;
 }
 
-
 // Jacobian-times-vector routine.
-static int jtv(N_Vector v, N_Vector Jv, realtype t, N_Vector u, N_Vector fu,
+static int jtv(N_Vector v, N_Vector Jv, sunrealtype t, N_Vector u, N_Vector fu,
                void* user_data, N_Vector tmp)
 {
   UserData* data = static_cast<UserData*>(user_data);
 
   // Extract needed constants from data
-  const size_t   MX    = static_cast<size_t>(data->MX);
-  const size_t   MY    = static_cast<size_t>(data->MY);
-  const realtype hordc = data->hdcoef;
-  const realtype horac = data->hacoef;
-  const realtype verdc = data->vdcoef;
+  const size_t MX         = static_cast<size_t>(data->MX);
+  const size_t MY         = static_cast<size_t>(data->MY);
+  const sunrealtype hordc = data->hdcoef;
+  const sunrealtype horac = data->hacoef;
+  const sunrealtype verdc = data->vdcoef;
 
   // Extract pointers to vector data
-  const realtype *vdata  = N_VGetDeviceArrayPointer(v);
-  realtype       *Jvdata = N_VGetDeviceArrayPointer(Jv);
+  const sunrealtype* vdata = N_VGetDeviceArrayPointer(v);
+  sunrealtype* Jvdata      = N_VGetDeviceArrayPointer(Jv);
 
-  data->myQueue->submit([&](sycl::handler& h)
-  {
-    h.parallel_for(sycl::range{MX, MY}, [=](sycl::id<2> idx)
+  data->myQueue->submit(
+    [&](sycl::handler& h)
     {
-      sunindextype i   = idx[0];
-      sunindextype j   = idx[1];
-      sunindextype tid = i * MY + j;
+      h.parallel_for(sycl::range{MX, MY},
+                     [=](sycl::id<2> idx)
+                     {
+                       size_t i   = idx[0];
+                       size_t j   = idx[1];
+                       size_t tid = i * MY + j;
 
-      // set the tid-th element of Jv
-      Jvdata[tid] = -TWO * (verdc + hordc) * vdata[tid];
+                       // set the tid-th element of Jv
+                       Jvdata[tid] = -TWO * (verdc + hordc) * vdata[tid];
 
-      if (i !=      0) Jvdata[tid] += (hordc - horac) * vdata[tid - MY];
-      if (i != MX - 1) Jvdata[tid] += (hordc + horac) * vdata[tid + MY];
-      if (j !=      0) Jvdata[tid] += verdc * vdata[tid - 1];
-      if (j != MY - 1) Jvdata[tid] += verdc * vdata[tid + 1];
+                       if (i != 0)
+                         Jvdata[tid] += (hordc - horac) * vdata[tid - MY];
+                       if (i != MX - 1)
+                         Jvdata[tid] += (hordc + horac) * vdata[tid + MY];
+                       if (j != 0) Jvdata[tid] += verdc * vdata[tid - 1];
+                       if (j != MY - 1) Jvdata[tid] += verdc * vdata[tid + 1];
+                     });
     });
-  });
 
   return 0;
 }
@@ -315,22 +301,23 @@ static int jtv(N_Vector v, N_Vector Jv, realtype t, N_Vector u, N_Vector fu,
  * ---------------------------------------------------------------------------*/
 
 // Print first lines of output (problem description)
-static void PrintHeader(realtype reltol, realtype abstol, realtype umax,
-                        UserData* data)
+static void PrintHeader(sunrealtype reltol, sunrealtype abstol,
+                        sunrealtype umax, UserData* data)
 {
   std::cout << "\n2-D Advection-Diffusion Equation" << std::endl;
-  std::cout << "Mesh dimensions = " << data->MX << " X " <<  data->MY << std::endl;
+  std::cout << "Mesh dimensions = " << data->MX << " X " << data->MY << std::endl;
   std::cout << "Total system size = " << data->NEQ << std::endl;
   std::cout << "Tolerance parameters: reltol = " << reltol
-            << "   abstol = " << abstol << std::endl << std::endl;
+            << "   abstol = " << abstol << std::endl
+            << std::endl;
   std::cout << "At t = " << T0 << "      max.norm(u) = " << umax << std::endl;
   return;
 }
 
 // Print current value
-static void PrintOutput(realtype t, realtype umax, long int nst)
+static void PrintOutput(sunrealtype t, sunrealtype umax, long int nst)
 {
-  std::cout << "At t = " << t << "   max.norm(u) = "<< umax
+  std::cout << "At t = " << t << "   max.norm(u) = " << umax
             << "   nst = " << nst << std::endl;
   return;
 }
@@ -338,7 +325,7 @@ static void PrintOutput(realtype t, realtype umax, long int nst)
 // Get and print some final statistics
 static void PrintFinalStats(void* cvode_mem)
 {
-  long lenrw, leniw ;
+  long lenrw, leniw;
   long lenrwLS, leniwLS;
   long int nst, nfe, nsetups, nni, ncfn, netf;
   long int nli, npe, nps, ncfl, nfeLS;
@@ -373,14 +360,14 @@ static void PrintFinalStats(void* cvode_mem)
   check_retval(&retval, "CVodeGetNumLinRhsEvals", 1);
 
   std::cout << "\nFinal Statistics.. \n\n";
-  std::cout << "lenrw   = " << lenrw   << "     leniw   = " << leniw   << "\n";
+  std::cout << "lenrw   = " << lenrw << "     leniw   = " << leniw << "\n";
   std::cout << "lenrwLS = " << lenrwLS << "     leniwLS = " << leniwLS << "\n";
-  std::cout << "nst     = " << nst     << "\n";
-  std::cout << "nfe     = " << nfe     << "     nfeLS   = " << nfeLS << "\n";
-  std::cout << "nni     = " << nni     << "     nli     = " << nli   << "\n";
-  std::cout << "nsetups = " << nsetups << "     netf    = " << netf  << "\n";
-  std::cout << "npe     = " << npe     << "     nps     = " << nps   << "\n";
-  std::cout << "ncfn    = " << ncfn    << "     ncfl    = " << ncfl  << "\n\n";
+  std::cout << "nst     = " << nst << "\n";
+  std::cout << "nfe     = " << nfe << "     nfeLS   = " << nfeLS << "\n";
+  std::cout << "nni     = " << nni << "     nli     = " << nli << "\n";
+  std::cout << "nsetups = " << nsetups << "     netf    = " << netf << "\n";
+  std::cout << "npe     = " << npe << "     nps     = " << nps << "\n";
+  std::cout << "ncfn    = " << ncfn << "     ncfl    = " << ncfl << "\n\n";
 
   return;
 }
@@ -392,9 +379,9 @@ static void PrintFinalStats(void* cvode_mem)
               retval >= 0
      opt == 2 means function allocates memory so check if returned
               NULL pointer */
-static int check_retval(void* returnvalue, const char *funcname, int opt)
+static int check_retval(void* returnvalue, const char* funcname, int opt)
 {
-  int *retval;
+  int* retval;
 
   if (opt == 0 && returnvalue == NULL)
   {
