@@ -2,7 +2,7 @@
 ! Programmer(s): David J. Gardner, and Cody J. Balos @ LLNL
 ! ------------------------------------------------------------------
 ! SUNDIALS Copyright Start
-! Copyright (c) 2002-2024, Lawrence Livermore National Security
+! Copyright (c) 2002-2025, Lawrence Livermore National Security
 ! and Southern Methodist University.
 ! All rights reserved.
 !
@@ -14,12 +14,12 @@
 ! The following is a simple example problem with an analytical
 ! solution.
 !
-!   dy/dt = lamda*y + 1/(1+t^2) - lamda*atan(t)
+!   dy/dt = lambda*y + 1/(1+t^2) - lambda*atan(t)
 !
 ! for t in the interval [0.0, 10.0], with initial condition: y=0.
 !
 ! The stiffness of the problem is directly proportional to the
-! value of lamda. The value of lamda should be negative to
+! value of lambda. The value of lambda should be negative to
 ! result in a well-posed ODE; for values with magnitude larger
 ! than 100 the problem becomes quite stiff.
 ! ------------------------------------------------------------------
@@ -34,10 +34,10 @@ module ode_mod
   implicit none
 
   ! number of equations
-  integer(c_long), parameter :: neq = 1
+  integer(c_int64_t), parameter :: neq = 1
 
   ! ODE parameters
-  double precision, parameter :: lamda = -100.0d0
+  double precision, parameter :: lambda = -100.0d0
 
 contains
 
@@ -51,12 +51,11 @@ contains
   !   -1 = non-recoverable error
   ! ----------------------------------------------------------------
   integer(c_int) function RhsFn(tn, sunvec_y, sunvec_f, user_data) &
-       result(ierr) bind(C,name='RhsFn')
+    result(ierr) bind(C, name='RhsFn')
 
     !======= Inclusions ===========
     use, intrinsic :: iso_c_binding
 
-
     !======= Declarations =========
     implicit none
 
@@ -77,7 +76,7 @@ contains
     fvec => FN_VGetArrayPointer(sunvec_f)
 
     ! fill RHS vector
-    fvec(1) = lamda*yvec(1) + 1.0/(1.0+tn*tn) - lamda*atan(tn)
+    fvec(1) = lambda*yvec(1) + 1.0/(1.0 + tn*tn) - lambda*atan(tn)
 
     ! return success
     ierr = 0
@@ -87,7 +86,6 @@ contains
 
 end module ode_mod
 
-
 program main
 
   !======= Inclusions ===========
@@ -126,11 +124,11 @@ program main
 
   ! initialize ODE
   tstart = 0.0d0
-  tend   = 10.0d0
-  tcur   = tstart
-  tout   = tstart
-  dtout  = 1.0d0
-  nout   = ceiling(tend/dtout)
+  tend = 10.0d0
+  tcur = tstart
+  tout = tstart
+  dtout = 1.0d0
+  nout = ceiling(tend/dtout)
 
   ! initialize solution vector
   yvec(1) = 0.0d0
@@ -138,22 +136,22 @@ program main
   ! create SUNDIALS N_Vector
   sunvec_y => FN_VMake_Serial(neq, yvec, ctx)
   if (.not. associated(sunvec_y)) then
-     print *, 'ERROR: sunvec = NULL'
-     stop 1
+    print *, 'ERROR: sunvec = NULL'
+    stop 1
   end if
 
   ! create CVode memory
   cvode_mem = FCVodeCreate(CV_ADAMS, ctx)
   if (.not. c_associated(cvode_mem)) then
-     print *, 'ERROR: cvode_mem = NULL'
-     stop 1
+    print *, 'ERROR: cvode_mem = NULL'
+    stop 1
   end if
 
   ! initialize CVode
   ierr = FCVodeInit(cvode_mem, c_funloc(RhsFn), tstart, sunvec_y)
   if (ierr /= 0) then
-     print *, 'Error in FCVodeInit, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeInit, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   ! set relative and absolute tolerances
@@ -162,18 +160,18 @@ program main
 
   ierr = FCVodeSStolerances(cvode_mem, rtol, atol)
   if (ierr /= 0) then
-     print *, 'Error in FCVodeSStolerances, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeSStolerances, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   ! create fixed point nonlinear solver object
   sunnls => FSUNNonlinSol_FixedPoint(sunvec_y, 0, ctx)
   if (.not. associated(sunnls)) then
-     print *,'ERROR: sunnls = NULL'
-     stop 1
+    print *, 'ERROR: sunnls = NULL'
+    stop 1
   end if
 
-  ! attache nonlinear solver object to CVode
+  ! attach nonlinear solver object to CVode
   ierr = FCVodeSetNonlinearSolver(cvode_mem, sunnls)
   if (ierr /= 0) then
     print *, 'Error in FCVodeSetNonlinearSolver, ierr = ', ierr, '; halting'
@@ -187,20 +185,20 @@ program main
   print *, '       t           y        '
   print *, '----------------------------'
   print '(2x,2(es12.5,1x))', tcur, yvec(1)
-  do outstep = 1,nout
+  do outstep = 1, nout
 
-     ! call CVode
-     tout = min(tout + dtout, tend)
-     ierr = FCVode(cvode_mem, tout, sunvec_y, tcur, CV_NORMAL)
-     if (ierr /= 0) then
-        print *, 'Error in FCVODE, ierr = ', ierr, '; halting'
-        stop 1
-     endif
+    ! call CVode
+    tout = min(tout + dtout, tend)
+    ierr = FCVode(cvode_mem, tout, sunvec_y, tcur, CV_NORMAL)
+    if (ierr /= 0) then
+      print *, 'Error in FCVODE, ierr = ', ierr, '; halting'
+      stop 1
+    end if
 
-     ! output current solution
-     print '(2x,2(es12.5,1x))', tcur, yvec(1)
+    ! output current solution
+    print '(2x,2(es12.5,1x))', tcur, yvec(1)
 
-  enddo
+  end do
 
   ! diagnostics output
   call CVodeStats(cvode_mem)
@@ -213,7 +211,6 @@ program main
 
 end program main
 
-
 ! ----------------------------------------------------------------
 ! CVodeStats
 !
@@ -252,33 +249,33 @@ subroutine CVodeStats(cvode_mem)
 
   ! general solver statistics
   ierr = FCVodeGetIntegratorStats(cvode_mem, nsteps, nfevals, nlinsetups, &
-       netfails, qlast, qcur, hinused, hlast, hcur, tcur)
+                                  netfails, qlast, qcur, hinused, hlast, hcur, tcur)
   if (ierr /= 0) then
-     print *, 'Error in FCVodeGetIntegratorStats, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeGetIntegratorStats, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   ! nonlinear solver statistics
   ierr = FCVodeGetNonlinSolvStats(cvode_mem, nniters, nncfails)
   if (ierr /= 0) then
-     print *, 'Error in FCVodeGetNonlinSolvStats, ierr = ', ierr, '; halting'
-     stop 1
+    print *, 'Error in FCVodeGetNonlinSolvStats, ierr = ', ierr, '; halting'
+    stop 1
   end if
 
   print *, ' '
   print *, ' General Solver Stats:'
-  print '(4x,A,i9)'    ,'Total internal steps taken =',nsteps
-  print '(4x,A,i9)'    ,'Total rhs function calls   =',nfevals
-  print '(4x,A,i9)'    ,'Num lin solver setup calls =',nlinsetups
-  print '(4x,A,i9)'    ,'Num error test failures    =',netfails
-  print '(4x,A,i9)'    ,'Last method order          =',qlast
-  print '(4x,A,i9)'    ,'Next method order          =',qcur
-  print '(4x,A,es12.5)','First internal step size   =',hinused
-  print '(4x,A,es12.5)','Last internal step size    =',hlast
-  print '(4x,A,es12.5)','Next internal step size    =',hcur
-  print '(4x,A,es12.5)','Current internal time      =',tcur
-  print '(4x,A,i9)'    ,'Num nonlinear solver iters =',nniters
-  print '(4x,A,i9)'    ,'Num nonlinear solver fails =',nncfails
+  print '(4x,A,i9)', 'Total internal steps taken =', nsteps
+  print '(4x,A,i9)', 'Total rhs function calls   =', nfevals
+  print '(4x,A,i9)', 'Num lin solver setup calls =', nlinsetups
+  print '(4x,A,i9)', 'Num error test failures    =', netfails
+  print '(4x,A,i9)', 'Last method order          =', qlast
+  print '(4x,A,i9)', 'Next method order          =', qcur
+  print '(4x,A,es12.5)', 'First internal step size   =', hinused
+  print '(4x,A,es12.5)', 'Last internal step size    =', hlast
+  print '(4x,A,es12.5)', 'Next internal step size    =', hcur
+  print '(4x,A,es12.5)', 'Current internal time      =', tcur
+  print '(4x,A,i9)', 'Num nonlinear solver iters =', nniters
+  print '(4x,A,i9)', 'Num nonlinear solver fails =', nncfails
   print *, ' '
 
   return
