@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -61,7 +61,7 @@ constexpr auto N_VNew = N_VNew_Cuda;
 #include <nvector/nvector_hip.h>
 #define HIP_OR_CUDA_OR_SYCL(a, b, c) a
 constexpr auto N_VNew = N_VNew_Hip;
-#elif defined(USE_DPCPP)
+#elif defined(USE_SYCL)
 #include <nvector/nvector_sycl.h>
 #define HIP_OR_CUDA_OR_SYCL(a, b, c) c
 constexpr auto N_VNew = N_VNew_Sycl;
@@ -117,12 +117,20 @@ int main(int argc, char* argv[])
   // ---------------------------------------
 
 #if defined(USE_CUDA)
+#if GKO_VERSION_MAJOR > 1 || (GKO_VERSION_MAJOR == 1 && GKO_VERSION_MINOR >= 7)
+  auto gko_exec{gko::CudaExecutor::create(0, gko::OmpExecutor::create())};
+#else
   auto gko_exec{gko::CudaExecutor::create(0, gko::OmpExecutor::create(), false,
                                           gko::allocation_mode::device)};
+#endif
 #elif defined(USE_HIP)
+#if GKO_VERSION_MAJOR > 1 || (GKO_VERSION_MAJOR == 1 && GKO_VERSION_MINOR >= 7)
+  auto gko_exec{gko::HipExecutor::create(0, gko::OmpExecutor::create())};
+#else
   auto gko_exec{gko::HipExecutor::create(0, gko::OmpExecutor::create(), false,
                                          gko::allocation_mode::device)};
-#elif defined(USE_DPCPP)
+#endif
+#elif defined(USE_SYCL)
   auto gko_exec{gko::DpcppExecutor::create(0, gko::ReferenceExecutor::create())};
 #elif defined(USE_OMP)
   auto gko_exec{gko::OmpExecutor::create()};
@@ -137,7 +145,7 @@ int main(int argc, char* argv[])
   // ---------------
 
   // Create solution vector
-#if defined(USE_DPCPP)
+#if defined(USE_SYCL)
   N_Vector u = N_VNew(udata.nodes, gko_exec->get_queue(), sunctx);
 #else
   N_Vector u = N_VNew(udata.nodes, sunctx);
@@ -223,7 +231,7 @@ int main(int argc, char* argv[])
   sunrealtype dTout = udata.tf / udata.nout;
   sunrealtype tout  = dTout;
 
-  // Inital output
+  // Initial output
   flag = OpenOutput(udata);
   if (check_flag(flag, "OpenOutput")) { return 1; }
 
@@ -372,7 +380,7 @@ int f(sunrealtype t, N_Vector u, N_Vector f, void* user_data)
 
   HIP_OR_CUDA_OR_SYCL(hipDeviceSynchronize(), cudaDeviceSynchronize(), );
 
-#elif defined(USE_DPCPP)
+#elif defined(USE_SYCL)
   // Access device data arrays
   sunrealtype* uarray = N_VGetDeviceArrayPointer(u);
   if (check_ptr(uarray, "N_VGetDeviceArrayPointer")) return -1;
@@ -612,7 +620,7 @@ int J(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix J, void* user_data,
                                                   col_idxs, mat_data);
 
   HIP_OR_CUDA_OR_SYCL(hipDeviceSynchronize(), cudaDeviceSynchronize(), );
-#elif defined(USE_DPCPP)
+#elif defined(USE_SYCL)
   auto queue =
     std::dynamic_pointer_cast<const gko::DpcppExecutor>(udata->exec)->get_queue();
   // J_sn_kernel
