@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -32,7 +32,7 @@
 #include <nvector/nvector_cuda.h>
 #elif defined(USE_HIP)
 #include <nvector/nvector_hip.h>
-#elif defined(USE_DPCPP)
+#elif defined(USE_SYCL)
 #include <nvector/nvector_sycl.h>
 #endif
 
@@ -43,11 +43,10 @@
 #include <example_utilities.hpp>
 
 // Macros for problem constants
-#define PI    SUN_RCONST(3.141592653589793238462643383279502884197169)
-#define ZERO  SUN_RCONST(0.0)
-#define ONE   SUN_RCONST(1.0)
-#define TWO   SUN_RCONST(2.0)
-#define EIGHT SUN_RCONST(8.0)
+#define PI   SUN_RCONST(3.141592653589793238462643383279502884197169)
+#define ZERO SUN_RCONST(0.0)
+#define ONE  SUN_RCONST(1.0)
+#define TWO  SUN_RCONST(2.0)
 
 // -----------------------------------------------------------------------------
 // User data structure
@@ -86,7 +85,7 @@ struct UserData
   int liniters       = 20;   // number of linear iterations
   sunrealtype epslin = ZERO; // linear solver tolerance factor
 
-  // Ouput variables
+  // Output variables
   bool output = false; // write solution to disk
   int nout    = 20;    // number of output times
   std::ofstream uout;  // output file stream
@@ -124,7 +123,7 @@ __global__ void solution_kernel(const sunindextype nx, const sunindextype ny,
 #endif
 
 // Compute the exact solution
-int Solution(sunrealtype t, N_Vector u, UserData& udata)
+static int Solution(sunrealtype t, N_Vector u, UserData& udata)
 {
   // Access problem data and set shortcuts
   const auto nx = udata.nx;
@@ -152,7 +151,7 @@ int Solution(sunrealtype t, N_Vector u, UserData& udata)
 
   solution_kernel<<<num_blocks, threads_per_block>>>(nx, ny, dx, dy, cos_sqr_t,
                                                      uarray);
-#elif defined(USE_DPCPP)
+#elif defined(USE_SYCL)
   sunrealtype* uarray = N_VGetDeviceArrayPointer(u);
   if (check_ptr(uarray, "N_VGetDeviceArrayPointer")) return -1;
   std::dynamic_pointer_cast<const gko::DpcppExecutor>(udata.exec)
@@ -206,7 +205,7 @@ int Solution(sunrealtype t, N_Vector u, UserData& udata)
 }
 
 // Compute the solution error
-int SolutionError(sunrealtype t, N_Vector u, N_Vector e, UserData& udata)
+static int SolutionError(sunrealtype t, N_Vector u, N_Vector e, UserData& udata)
 {
   // Compute true solution
   int flag = Solution(t, e, udata);
@@ -220,7 +219,7 @@ int SolutionError(sunrealtype t, N_Vector u, N_Vector e, UserData& udata)
 }
 
 // Print command line options
-void InputHelp()
+static void InputHelp()
 {
   std::cout << std::endl
             << "Command line options:\n"
@@ -232,7 +231,7 @@ void InputHelp()
             << "  --kx <ky>          : y diffusion coefficient\n"
             << "  --tf <time>        : final time\n"
             << "  --rtol <rtol>      : relative tolerance\n"
-            << "  --atol <atol>      : absoltue tolerance\n"
+            << "  --atol <atol>      : absolute tolerance\n"
             << "  --liniters <iters> : max number of iterations\n"
             << "  --epslin <factor>  : linear tolerance factor\n"
             << "  --msbp <steps>     : max steps between prec setups\n"
@@ -243,7 +242,7 @@ void InputHelp()
 }
 
 // Read command line inputs
-int ReadInputs(std::vector<std::string>& args, UserData& udata)
+static int ReadInputs(std::vector<std::string>& args, UserData& udata)
 {
   if (find(args.begin(), args.end(), "--help") != args.end())
   {
@@ -276,7 +275,7 @@ int ReadInputs(std::vector<std::string>& args, UserData& udata)
 }
 
 // Print user data
-void PrintUserData(UserData& udata)
+static void PrintUserData(UserData& udata)
 {
   std::cout << std::endl
             << "2D Heat problem:\n"
@@ -303,7 +302,7 @@ void PrintUserData(UserData& udata)
 }
 
 // Initialize output
-int OpenOutput(UserData& udata)
+static int OpenOutput(UserData& udata)
 {
   // Header for status output
   std::cout << std::scientific
@@ -340,7 +339,7 @@ int OpenOutput(UserData& udata)
 }
 
 // Write output
-int WriteOutput(sunrealtype t, N_Vector u, N_Vector e, UserData& udata)
+static int WriteOutput(sunrealtype t, N_Vector u, N_Vector e, UserData& udata)
 {
   // Compute the error
   int flag = SolutionError(t, u, e, udata);
@@ -366,7 +365,7 @@ int WriteOutput(sunrealtype t, N_Vector u, N_Vector e, UserData& udata)
 #elif defined(USE_HIP)
     N_VCopyFromDevice_Hip(u);
     N_VCopyFromDevice_Hip(e);
-#elif defined(USE_DPCPP)
+#elif defined(USE_SYCL)
     N_VCopyFromDevice_Sycl(u);
     N_VCopyFromDevice_Sycl(e);
 #endif
@@ -398,7 +397,7 @@ int WriteOutput(sunrealtype t, N_Vector u, N_Vector e, UserData& udata)
 }
 
 // Finalize output
-int CloseOutput(UserData& udata)
+static int CloseOutput(UserData& udata)
 {
   // Footer for status output
   std::cout << " ----------------------------------------------"
