@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -27,489 +27,8 @@
 #include "arkode_erkstep_impl.h"
 
 /*===============================================================
-  ERKStep Optional input functions (wrappers for generic ARKODE
-  utility routines).  All are documented in arkode_io.c.
+  Exported optional input functions.
   ===============================================================*/
-int ERKStepSetDenseOrder(void* arkode_mem, int dord)
-{
-  return (ERKStepSetInterpolantDegree(arkode_mem, dord));
-}
-
-int ERKStepSetInterpolantDegree(void* arkode_mem, int degree)
-{
-  if (degree < 0) { degree = ARK_INTERP_MAX_DEGREE; }
-  return (arkSetInterpolantDegree(arkode_mem, degree));
-}
-
-int ERKStepSetInterpolantType(void* arkode_mem, int itype)
-{
-  return (arkSetInterpolantType(arkode_mem, itype));
-}
-
-int ERKStepSetUserData(void* arkode_mem, void* user_data)
-{
-  return (arkSetUserData(arkode_mem, user_data));
-}
-
-int ERKStepSetMaxNumSteps(void* arkode_mem, long int mxsteps)
-{
-  return (arkSetMaxNumSteps(arkode_mem, mxsteps));
-}
-
-int ERKStepSetMaxHnilWarns(void* arkode_mem, int mxhnil)
-{
-  return (arkSetMaxHnilWarns(arkode_mem, mxhnil));
-}
-
-int ERKStepSetInitStep(void* arkode_mem, sunrealtype hin)
-{
-  return (arkSetInitStep(arkode_mem, hin));
-}
-
-int ERKStepSetMinStep(void* arkode_mem, sunrealtype hmin)
-{
-  return (arkSetMinStep(arkode_mem, hmin));
-}
-
-int ERKStepSetMaxStep(void* arkode_mem, sunrealtype hmax)
-{
-  return (arkSetMaxStep(arkode_mem, hmax));
-}
-
-int ERKStepSetStopTime(void* arkode_mem, sunrealtype tstop)
-{
-  return (arkSetStopTime(arkode_mem, tstop));
-}
-
-int ERKStepSetInterpolateStopTime(void* arkode_mem, sunbooleantype interp)
-{
-  return (arkSetInterpolateStopTime(arkode_mem, interp));
-}
-
-int ERKStepClearStopTime(void* arkode_mem)
-{
-  return (arkClearStopTime(arkode_mem));
-}
-
-int ERKStepSetRootDirection(void* arkode_mem, int* rootdir)
-{
-  return (arkSetRootDirection(arkode_mem, rootdir));
-}
-
-int ERKStepSetNoInactiveRootWarn(void* arkode_mem)
-{
-  return (arkSetNoInactiveRootWarn(arkode_mem));
-}
-
-int ERKStepSetConstraints(void* arkode_mem, N_Vector constraints)
-{
-  return (arkSetConstraints(arkode_mem, constraints));
-}
-
-int ERKStepSetMaxNumConstrFails(void* arkode_mem, int maxfails)
-{
-  return (arkSetMaxNumConstrFails(arkode_mem, maxfails));
-}
-
-int ERKStepSetPostprocessStepFn(void* arkode_mem, ARKPostProcessFn ProcessStep)
-{
-  return (arkSetPostprocessStepFn(arkode_mem, ProcessStep));
-}
-
-int ERKStepSetPostprocessStageFn(void* arkode_mem, ARKPostProcessFn ProcessStage)
-{
-  return (arkSetPostprocessStageFn(arkode_mem, ProcessStage));
-}
-
-int ERKStepSetAdaptivityAdjustment(void* arkode_mem, int adjust)
-{
-  return (arkSetAdaptivityAdjustment(arkode_mem, adjust));
-}
-
-int ERKStepSetCFLFraction(void* arkode_mem, sunrealtype cfl_frac)
-{
-  return (arkSetCFLFraction(arkode_mem, cfl_frac));
-}
-
-int ERKStepSetSafetyFactor(void* arkode_mem, sunrealtype safety)
-{
-  return (arkSetSafetyFactor(arkode_mem, safety));
-}
-
-int ERKStepSetMaxGrowth(void* arkode_mem, sunrealtype mx_growth)
-{
-  return (arkSetMaxGrowth(arkode_mem, mx_growth));
-}
-
-int ERKStepSetMinReduction(void* arkode_mem, sunrealtype eta_min)
-{
-  return (arkSetMinReduction(arkode_mem, eta_min));
-}
-
-int ERKStepSetFixedStepBounds(void* arkode_mem, sunrealtype lb, sunrealtype ub)
-{
-  return (arkSetFixedStepBounds(arkode_mem, lb, ub));
-}
-
-int ERKStepSetMaxFirstGrowth(void* arkode_mem, sunrealtype etamx1)
-{
-  return (arkSetMaxFirstGrowth(arkode_mem, etamx1));
-}
-
-int ERKStepSetMaxEFailGrowth(void* arkode_mem, sunrealtype etamxf)
-{
-  return (arkSetMaxEFailGrowth(arkode_mem, etamxf));
-}
-
-int ERKStepSetSmallNumEFails(void* arkode_mem, int small_nef)
-{
-  return (arkSetSmallNumEFails(arkode_mem, small_nef));
-}
-
-int ERKStepSetStabilityFn(void* arkode_mem, ARKExpStabFn EStab, void* estab_data)
-{
-  return (arkSetStabilityFn(arkode_mem, EStab, estab_data));
-}
-
-int ERKStepSetMaxErrTestFails(void* arkode_mem, int maxnef)
-{
-  return (arkSetMaxErrTestFails(arkode_mem, maxnef));
-}
-
-int ERKStepSetFixedStep(void* arkode_mem, sunrealtype hfixed)
-{
-  return (arkSetFixedStep(arkode_mem, hfixed));
-}
-
-int ERKStepSetAdaptController(void* arkode_mem, SUNAdaptController C)
-{
-  return (arkSetAdaptController(arkode_mem, C));
-}
-
-/*===============================================================
-  ERKStep Optional output functions (wrappers for generic ARKODE
-  utility routines). All are documented in arkode_io.c.
-  ===============================================================*/
-
-int ERKStepGetNumStepAttempts(void* arkode_mem, long int* nstep_attempts)
-{
-  return (arkGetNumStepAttempts(arkode_mem, nstep_attempts));
-}
-
-int ERKStepGetNumSteps(void* arkode_mem, long int* nsteps)
-{
-  return (arkGetNumSteps(arkode_mem, nsteps));
-}
-
-int ERKStepGetActualInitStep(void* arkode_mem, sunrealtype* hinused)
-{
-  return (arkGetActualInitStep(arkode_mem, hinused));
-}
-
-int ERKStepGetLastStep(void* arkode_mem, sunrealtype* hlast)
-{
-  return (arkGetLastStep(arkode_mem, hlast));
-}
-
-int ERKStepGetCurrentStep(void* arkode_mem, sunrealtype* hcur)
-{
-  return (arkGetCurrentStep(arkode_mem, hcur));
-}
-
-int ERKStepGetCurrentTime(void* arkode_mem, sunrealtype* tcur)
-{
-  return (arkGetCurrentTime(arkode_mem, tcur));
-}
-
-int ERKStepGetTolScaleFactor(void* arkode_mem, sunrealtype* tolsfact)
-{
-  return (arkGetTolScaleFactor(arkode_mem, tolsfact));
-}
-
-int ERKStepGetErrWeights(void* arkode_mem, N_Vector eweight)
-{
-  return (arkGetErrWeights(arkode_mem, eweight));
-}
-
-int ERKStepGetWorkSpace(void* arkode_mem, long int* lenrw, long int* leniw)
-{
-  return (arkGetWorkSpace(arkode_mem, lenrw, leniw));
-}
-
-int ERKStepGetNumGEvals(void* arkode_mem, long int* ngevals)
-{
-  return (arkGetNumGEvals(arkode_mem, ngevals));
-}
-
-int ERKStepGetRootInfo(void* arkode_mem, int* rootsfound)
-{
-  return (arkGetRootInfo(arkode_mem, rootsfound));
-}
-
-int ERKStepGetStepStats(void* arkode_mem, long int* nsteps, sunrealtype* hinused,
-                        sunrealtype* hlast, sunrealtype* hcur, sunrealtype* tcur)
-{
-  return (arkGetStepStats(arkode_mem, nsteps, hinused, hlast, hcur, tcur));
-}
-
-int ERKStepGetNumConstrFails(void* arkode_mem, long int* nconstrfails)
-{
-  return (arkGetNumConstrFails(arkode_mem, nconstrfails));
-}
-
-int ERKStepGetNumExpSteps(void* arkode_mem, long int* nsteps)
-{
-  return (arkGetNumExpSteps(arkode_mem, nsteps));
-}
-
-int ERKStepGetNumAccSteps(void* arkode_mem, long int* nsteps)
-{
-  return (arkGetNumAccSteps(arkode_mem, nsteps));
-}
-
-int ERKStepGetNumErrTestFails(void* arkode_mem, long int* netfails)
-{
-  return (arkGetNumErrTestFails(arkode_mem, netfails));
-}
-
-int ERKStepGetUserData(void* arkode_mem, void** user_data)
-{
-  return (arkGetUserData(arkode_mem, user_data));
-}
-
-char* ERKStepGetReturnFlagName(long int flag)
-{
-  return (arkGetReturnFlagName(flag));
-}
-
-/* -----------------------------------------------------------------------------
- * Wrappers for the ARKODE relaxation module
- * ---------------------------------------------------------------------------*/
-
-int ERKStepSetRelaxFn(void* arkode_mem, ARKRelaxFn rfn, ARKRelaxJacFn rjac)
-{
-  return arkRelaxCreate(arkode_mem, rfn, rjac, erkStep_RelaxDeltaE,
-                        erkStep_GetOrder);
-}
-
-int ERKStepSetRelaxEtaFail(void* arkode_mem, sunrealtype eta_rf)
-{
-  return arkRelaxSetEtaFail(arkode_mem, eta_rf);
-}
-
-int ERKStepSetRelaxLowerBound(void* arkode_mem, sunrealtype lower)
-{
-  return arkRelaxSetLowerBound(arkode_mem, lower);
-}
-
-int ERKStepSetRelaxMaxFails(void* arkode_mem, int max_fails)
-{
-  return arkRelaxSetMaxFails(arkode_mem, max_fails);
-}
-
-int ERKStepSetRelaxMaxIters(void* arkode_mem, int max_iters)
-{
-  return arkRelaxSetMaxIters(arkode_mem, max_iters);
-}
-
-int ERKStepSetRelaxSolver(void* arkode_mem, ARKRelaxSolver solver)
-{
-  return arkRelaxSetSolver(arkode_mem, solver);
-}
-
-int ERKStepSetRelaxResTol(void* arkode_mem, sunrealtype res_tol)
-{
-  return arkRelaxSetResTol(arkode_mem, res_tol);
-}
-
-int ERKStepSetRelaxTol(void* arkode_mem, sunrealtype rel_tol, sunrealtype abs_tol)
-{
-  return arkRelaxSetTol(arkode_mem, rel_tol, abs_tol);
-}
-
-int ERKStepSetRelaxUpperBound(void* arkode_mem, sunrealtype upper)
-{
-  return arkRelaxSetUpperBound(arkode_mem, upper);
-}
-
-int ERKStepGetNumRelaxFnEvals(void* arkode_mem, long int* r_evals)
-{
-  return arkRelaxGetNumRelaxFnEvals(arkode_mem, r_evals);
-}
-
-int ERKStepGetNumRelaxJacEvals(void* arkode_mem, long int* J_evals)
-{
-  return arkRelaxGetNumRelaxJacEvals(arkode_mem, J_evals);
-}
-
-int ERKStepGetNumRelaxFails(void* arkode_mem, long int* relax_fails)
-{
-  return arkRelaxGetNumRelaxFails(arkode_mem, relax_fails);
-}
-
-int ERKStepGetNumRelaxBoundFails(void* arkode_mem, long int* fails)
-{
-  return arkRelaxGetNumRelaxBoundFails(arkode_mem, fails);
-}
-
-int ERKStepGetNumRelaxSolveFails(void* arkode_mem, long int* fails)
-{
-  return arkRelaxGetNumRelaxSolveFails(arkode_mem, fails);
-}
-
-int ERKStepGetNumRelaxSolveIters(void* arkode_mem, long int* iters)
-{
-  return arkRelaxGetNumRelaxSolveIters(arkode_mem, iters);
-}
-
-/*===============================================================
-  DEPRECATED ERKStep optional input/output functions
-  ===============================================================*/
-
-/*---------------------------------------------------------------
-  ERKStepSetAdaptivityMethod: user should create/attach a
-  specific SUNAdaptController object.
-  ---------------------------------------------------------------*/
-int ERKStepSetAdaptivityMethod(void* arkode_mem, int imethod, int idefault,
-                               int pq, sunrealtype adapt_params[3])
-{
-  return (arkSetAdaptivityMethod(arkode_mem, imethod, idefault, pq, adapt_params));
-}
-
-/*---------------------------------------------------------------
-  ERKStepSetAdaptivityFn: user should create/attach a custom
-  SUNAdaptController object.
-  ---------------------------------------------------------------*/
-int ERKStepSetAdaptivityFn(void* arkode_mem, ARKAdaptFn hfun, void* h_data)
-{
-  return (arkSetAdaptivityFn(arkode_mem, hfun, h_data));
-}
-
-/*---------------------------------------------------------------
-  ERKStepSetErrorBias: user should set this value directly in the
-  SUNAdaptController object.
-  ---------------------------------------------------------------*/
-int ERKStepSetErrorBias(void* arkode_mem, sunrealtype bias)
-{
-  return (arkSetErrorBias(arkode_mem, bias));
-}
-
-/*===============================================================
-  ERKStep optional input functions -- stepper-specific
-  ===============================================================*/
-
-/*---------------------------------------------------------------
-  ERKStepSetDefaults:
-
-  Resets all ERKStep optional inputs to their default values.
-  Does not change problem-defining function pointers or
-  user_data pointer.
-  ---------------------------------------------------------------*/
-int ERKStepSetDefaults(void* arkode_mem)
-{
-  ARKodeMem ark_mem;
-  ARKodeERKStepMem step_mem;
-  int retval;
-  long int lenrw, leniw;
-
-  /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
-  if (retval != ARK_SUCCESS) { return (retval); }
-
-  /* Set default ARKODE infrastructure parameters */
-  retval = arkSetDefaults(arkode_mem);
-  if (retval != ARK_SUCCESS)
-  {
-    arkProcessError(NULL, ARK_MEM_NULL, __LINE__, __func__, __FILE__,
-                    "Error setting ARKODE infrastructure defaults");
-    return (retval);
-  }
-
-  /* Remove current SUNAdaptController object, and replace with "PI" */
-  retval = SUNAdaptController_Space(ark_mem->hadapt_mem->hcontroller, &lenrw,
-                                    &leniw);
-  if (retval == SUN_SUCCESS)
-  {
-    ark_mem->liw -= leniw;
-    ark_mem->lrw -= lenrw;
-  }
-  if (ark_mem->hadapt_mem->owncontroller)
-  {
-    retval = SUNAdaptController_Destroy(ark_mem->hadapt_mem->hcontroller);
-    ark_mem->hadapt_mem->owncontroller = SUNFALSE;
-    if (retval != SUN_SUCCESS)
-    {
-      arkProcessError(ark_mem, ARK_MEM_FAIL, __LINE__, __func__, __FILE__,
-                      "SUNAdaptController_Destroy failure");
-      return (ARK_MEM_FAIL);
-    }
-  }
-  ark_mem->hadapt_mem->hcontroller = NULL;
-  ark_mem->hadapt_mem->hcontroller = SUNAdaptController_PI(ark_mem->sunctx);
-  if (ark_mem->hadapt_mem->hcontroller == NULL)
-  {
-    arkProcessError(ark_mem, ARK_MEM_FAIL, __LINE__, __func__, __FILE__,
-                    "SUNAdaptControllerPI allocation failure");
-    return (ARK_MEM_FAIL);
-  }
-  ark_mem->hadapt_mem->owncontroller = SUNTRUE;
-  retval = SUNAdaptController_Space(ark_mem->hadapt_mem->hcontroller, &lenrw,
-                                    &leniw);
-  if (retval == SUN_SUCCESS)
-  {
-    ark_mem->liw += leniw;
-    ark_mem->lrw += lenrw;
-  }
-
-  /* Set default values for integrator optional inputs
-     (overwrite some adaptivity params for ERKStep use) */
-  step_mem->q      = Q_DEFAULT;                  /* method order */
-  step_mem->p      = 0;                          /* embedding order */
-  step_mem->stages = 0;                          /* no stages */
-  step_mem->B      = NULL;                       /* no Butcher table */
-  ark_mem->hadapt_mem->etamxf = SUN_RCONST(0.3); /* max change on error-failed step */
-  ark_mem->hadapt_mem->safety = SUN_RCONST(0.99); /* step adaptivity safety factor  */
-  ark_mem->hadapt_mem->growth = SUN_RCONST(25.0); /* step adaptivity growth factor */
-  (void)SUNAdaptController_SetErrorBias(ark_mem->hadapt_mem->hcontroller,
-                                        SUN_RCONST(1.2));
-  (void)SUNAdaptController_SetParams_PI(ark_mem->hadapt_mem->hcontroller,
-                                        SUN_RCONST(0.8), -SUN_RCONST(0.31));
-  return (ARK_SUCCESS);
-}
-
-/*---------------------------------------------------------------
-  ERKStepSetOrder:
-
-  Specifies the method order
-  ---------------------------------------------------------------*/
-int ERKStepSetOrder(void* arkode_mem, int ord)
-{
-  ARKodeMem ark_mem;
-  ARKodeERKStepMem step_mem;
-  sunindextype Blrw, Bliw;
-  int retval;
-
-  /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
-  if (retval != ARK_SUCCESS) { return (retval); }
-
-  /* set user-provided value, or default, depending on argument */
-  if (ord <= 0) { step_mem->q = Q_DEFAULT; }
-  else { step_mem->q = ord; }
-
-  /* clear Butcher tables, since user is requesting a change in method
-     or a reset to defaults.  Tables will be set in ARKInitialSetup. */
-  step_mem->stages = 0;
-  step_mem->p      = 0;
-
-  ARKodeButcherTable_Space(step_mem->B, &Bliw, &Blrw);
-  ARKodeButcherTable_Free(step_mem->B);
-  step_mem->B = NULL;
-  ark_mem->liw -= Bliw;
-  ark_mem->lrw -= Blrw;
-
-  return (ARK_SUCCESS);
-}
 
 /*---------------------------------------------------------------
   ERKStepSetTable:
@@ -529,8 +48,8 @@ int ERKStepSetTable(void* arkode_mem, ARKodeButcherTable B)
   sunindextype Blrw, Bliw;
   int retval;
 
-  /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
+  /* access ARKodeMem and ARKodeERKStepMem structures */
+  retval = erkStep_AccessARKODEStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
   if (retval != ARK_SUCCESS) { return (retval); }
 
   /* check for legal inputs */
@@ -587,8 +106,8 @@ int ERKStepSetTableNum(void* arkode_mem, ARKODE_ERKTableID etable)
   sunindextype Blrw, Bliw;
   int retval;
 
-  /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
+  /* access ARKodeMem and ARKodeERKStepMem structures */
+  retval = erkStep_AccessARKODEStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
   if (retval != ARK_SUCCESS) { return (retval); }
 
   /* check that argument specifies an explicit table */
@@ -642,28 +161,45 @@ int ERKStepSetTableName(void* arkode_mem, const char* etable)
 }
 
 /*===============================================================
-  ERKStep optional output functions -- stepper-specific
+  Exported optional output functions.
   ===============================================================*/
 
 /*---------------------------------------------------------------
-  ERKStepGetNumRhsEvals:
+  erkStep_GetNumRhsEvals:
 
-  Returns the current number of calls to fe and fi
+  Returns the current number of RHS calls
   ---------------------------------------------------------------*/
-int ERKStepGetNumRhsEvals(void* arkode_mem, long int* fevals)
+int erkStep_GetNumRhsEvals(ARKodeMem ark_mem, int partition_index,
+                           long int* rhs_evals)
 {
-  ARKodeMem ark_mem;
-  ARKodeERKStepMem step_mem;
-  int retval;
+  ARKodeERKStepMem step_mem = NULL;
 
   /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
-  if (retval != ARK_SUCCESS) { return (retval); }
+  int retval = erkStep_AccessStepMem(ark_mem, __func__, &step_mem);
+  if (retval != ARK_SUCCESS) { return retval; }
 
-  /* get values from step_mem */
-  *fevals = step_mem->nfe;
+  if (rhs_evals == NULL)
+  {
+    arkProcessError(ark_mem, ARK_ILL_INPUT, __LINE__, __func__, __FILE__,
+                    "rhs_evals is NULL");
+    return ARK_ILL_INPUT;
+  }
 
-  return (ARK_SUCCESS);
+  if (partition_index > 0)
+  {
+    arkProcessError(ark_mem, ARK_ILL_INPUT, __LINE__, __func__, __FILE__,
+                    "Invalid partition index");
+    return ARK_ILL_INPUT;
+  }
+
+  *rhs_evals = step_mem->nfe;
+
+  return ARK_SUCCESS;
+}
+
+int ERKStepGetNumRhsEvals(void* arkode_mem, long int* fevals)
+{
+  return ARKodeGetNumRhsEvals(arkode_mem, 0, fevals);
 }
 
 /*---------------------------------------------------------------
@@ -677,8 +213,8 @@ int ERKStepGetCurrentButcherTable(void* arkode_mem, ARKodeButcherTable* B)
   ARKodeERKStepMem step_mem;
   int retval;
 
-  /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
+  /* access ARKodeMem and ARKodeERKStepMem structures */
+  retval = erkStep_AccessARKODEStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
   if (retval != ARK_SUCCESS) { return (retval); }
 
   /* get tables from step_mem */
@@ -686,29 +222,6 @@ int ERKStepGetCurrentButcherTable(void* arkode_mem, ARKodeButcherTable* B)
   return (ARK_SUCCESS);
 }
 
-/*---------------------------------------------------------------
-  ERKStepGetEstLocalErrors: (updated to the correct vector, but
-  need to verify that it is unchanged between filling the
-  estimated error and the end of the time step)
-
-  Returns an estimate of the local error
-  ---------------------------------------------------------------*/
-int ERKStepGetEstLocalErrors(void* arkode_mem, N_Vector ele)
-{
-  ARKodeMem ark_mem;
-  ARKodeERKStepMem step_mem;
-  int retval;
-
-  /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
-  if (retval != ARK_SUCCESS) { return (retval); }
-
-  /* copy vector to output */
-  N_VScale(ONE, ark_mem->tempv1, ele);
-
-  return (ARK_SUCCESS);
-}
-
 /*---------------------------------------------------------------
   ERKStepGetTimestepperStats:
 
@@ -722,8 +235,8 @@ int ERKStepGetTimestepperStats(void* arkode_mem, long int* expsteps,
   ARKodeERKStepMem step_mem;
   int retval;
 
-  /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
+  /* access ARKodeMem and ARKodeERKStepMem structures */
+  retval = erkStep_AccessARKODEStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
   if (retval != ARK_SUCCESS) { return (retval); }
 
   /* set expsteps and accsteps from adaptivity structure */
@@ -738,69 +251,151 @@ int ERKStepGetTimestepperStats(void* arkode_mem, long int* expsteps,
   return (ARK_SUCCESS);
 }
 
-/*---------------------------------------------------------------
-  ERKStepPrintAllStats:
+/*===============================================================
+  Private functions attached to ARKODE
+  ===============================================================*/
 
-  Prints integrator statistics
+/*---------------------------------------------------------------
+  erkStep_SetRelaxFn:
+
+  Sets up the relaxation module using ERKStep's utility routines.
   ---------------------------------------------------------------*/
-int ERKStepPrintAllStats(void* arkode_mem, FILE* outfile, SUNOutputFormat fmt)
+int erkStep_SetRelaxFn(ARKodeMem ark_mem, ARKRelaxFn rfn, ARKRelaxJacFn rjac)
+{
+  return (
+    arkRelaxCreate(ark_mem, rfn, rjac, erkStep_RelaxDeltaE, erkStep_GetOrder));
+}
+
+/*---------------------------------------------------------------
+  erkStep_SetDefaults:
+
+  Resets all ERKStep optional inputs to their default values.
+  Does not change problem-defining function pointers or
+  user_data pointer.
+  ---------------------------------------------------------------*/
+int erkStep_SetDefaults(ARKodeMem ark_mem)
 {
-  ARKodeMem ark_mem;
   ARKodeERKStepMem step_mem;
+  sunindextype Blrw, Bliw;
   int retval;
 
   /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
+  retval = erkStep_AccessStepMem(ark_mem, __func__, &step_mem);
   if (retval != ARK_SUCCESS) { return (retval); }
 
-  retval = arkPrintAllStats(arkode_mem, outfile, fmt);
-  if (retval != ARK_SUCCESS) { return (retval); }
+  /* Set default values for integrator optional inputs */
+  step_mem->q      = Q_DEFAULT;                  /* method order */
+  step_mem->p      = 0;                          /* embedding order */
+  step_mem->stages = 0;                          /* no stages */
+  ark_mem->hadapt_mem->etamxf = SUN_RCONST(0.3); /* max change on error-failed step */
+  ark_mem->hadapt_mem->safety = SUN_RCONST(0.99); /* step adaptivity safety factor  */
+  ark_mem->hadapt_mem->growth = SUN_RCONST(25.0); /* step adaptivity growth factor */
 
-  switch (fmt)
+  /* Remove pre-existing Butcher table */
+  if (step_mem->B)
   {
-  case SUN_OUTPUTFORMAT_TABLE:
-    fprintf(outfile, "RHS fn evals                 = %ld\n", step_mem->nfe);
-    break;
-  case SUN_OUTPUTFORMAT_CSV:
-    fprintf(outfile, ",RHS fn evals,%ld", step_mem->nfe);
-    fprintf(outfile, "\n");
-    break;
-  default:
-    arkProcessError(ark_mem, ARK_ILL_INPUT, __LINE__, __func__, __FILE__,
-                    "Invalid formatting option.");
-    return (ARK_ILL_INPUT);
+    ARKodeButcherTable_Space(step_mem->B, &Bliw, &Blrw);
+    ark_mem->liw -= Bliw;
+    ark_mem->lrw -= Blrw;
+    ARKodeButcherTable_Free(step_mem->B);
   }
+  step_mem->B = NULL;
+
+  /* Load the default SUNAdaptController */
+  retval = arkReplaceAdaptController(ark_mem, NULL, SUNTRUE);
+  if (retval) { return retval; }
 
   return (ARK_SUCCESS);
 }
 
-/*===============================================================
-  ERKStep parameter output
-  ===============================================================*/
+/*---------------------------------------------------------------
+  erkStep_SetOrder:
+
+  Specifies the method order
+  ---------------------------------------------------------------*/
+int erkStep_SetOrder(ARKodeMem ark_mem, int ord)
+{
+  ARKodeERKStepMem step_mem;
+  sunindextype Blrw, Bliw;
+  int retval;
+
+  /* access ARKodeERKStepMem structure */
+  retval = erkStep_AccessStepMem(ark_mem, __func__, &step_mem);
+  if (retval != ARK_SUCCESS) { return (retval); }
+
+  /* set user-provided value, or default, depending on argument */
+  if (ord <= 0) { step_mem->q = Q_DEFAULT; }
+  else { step_mem->q = ord; }
+
+  /* clear Butcher tables, since user is requesting a change in method
+     or a reset to defaults.  Tables will be set in ARKInitialSetup. */
+  step_mem->stages = 0;
+  step_mem->p      = 0;
+
+  ARKodeButcherTable_Space(step_mem->B, &Bliw, &Blrw);
+  ARKodeButcherTable_Free(step_mem->B);
+  step_mem->B = NULL;
+  ark_mem->liw -= Bliw;
+  ark_mem->lrw -= Blrw;
+
+  return (ARK_SUCCESS);
+}
 
 /*---------------------------------------------------------------
-  ERKStepWriteParameters:
-
-  Outputs all solver parameters to the provided file pointer.
+  erkStep_GetEstLocalErrors: Returns the current local truncation
+  error estimate vector
   ---------------------------------------------------------------*/
-int ERKStepWriteParameters(void* arkode_mem, FILE* fp)
+int erkStep_GetEstLocalErrors(ARKodeMem ark_mem, N_Vector ele)
+{
+  int retval;
+  ARKodeERKStepMem step_mem;
+  retval = erkStep_AccessStepMem(ark_mem, __func__, &step_mem);
+  if (retval != ARK_SUCCESS) { return (retval); }
+
+  /* return an error if local truncation error is not computed */
+  if ((ark_mem->fixedstep && (ark_mem->AccumErrorType == ARK_ACCUMERROR_NONE)) ||
+      (step_mem->p <= 0))
+  {
+    return (ARK_STEPPER_UNSUPPORTED);
+  }
+
+  /* otherwise, copy local truncation error vector to output */
+  N_VScale(ONE, ark_mem->tempv1, ele);
+  return (ARK_SUCCESS);
+}
+
+/*---------------------------------------------------------------
+  erkStep_PrintAllStats:
+
+  Prints integrator statistics
+  ---------------------------------------------------------------*/
+int erkStep_PrintAllStats(ARKodeMem ark_mem, FILE* outfile, SUNOutputFormat fmt)
 {
-  ARKodeMem ark_mem;
   ARKodeERKStepMem step_mem;
   int retval;
 
   /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
+  retval = erkStep_AccessStepMem(ark_mem, __func__, &step_mem);
   if (retval != ARK_SUCCESS) { return (retval); }
 
-  /* output ARKODE infrastructure parameters first */
-  retval = arkWriteParameters(arkode_mem, fp);
-  if (retval != ARK_SUCCESS)
-  {
-    arkProcessError(ark_mem, ARK_MEM_NULL, __LINE__, __func__, __FILE__,
-                    "Error writing ARKODE infrastructure parameters");
-    return (retval);
-  }
+  sunfprintf_long(outfile, fmt, SUNFALSE, "RHS fn evals", step_mem->nfe);
+
+  return (ARK_SUCCESS);
+}
+
+/*---------------------------------------------------------------
+  erkStep_WriteParameters:
+
+  Outputs all solver parameters to the provided file pointer.
+  ---------------------------------------------------------------*/
+int erkStep_WriteParameters(ARKodeMem ark_mem, FILE* fp)
+{
+  ARKodeERKStepMem step_mem;
+  int retval;
+
+  /* access ARKodeERKStepMem structure */
+  retval = erkStep_AccessStepMem(ark_mem, __func__, &step_mem);
+  if (retval != ARK_SUCCESS) { return (retval); }
 
   /* print integrator parameters to file */
   fprintf(fp, "ERKStep time step module parameters:\n");
@@ -810,19 +405,341 @@ int ERKStepWriteParameters(void* arkode_mem, FILE* fp)
   return (ARK_SUCCESS);
 }
 
-/*---------------------------------------------------------------
-  ERKStepWriteButcher:
+/*===============================================================
+  Exported-but-deprecated user-callable functions.
+  ===============================================================*/
+
+int ERKStepResize(void* arkode_mem, N_Vector y0, sunrealtype hscale,
+                  sunrealtype t0, ARKVecResizeFn resize, void* resize_data)
+{
+  return (ARKodeResize(arkode_mem, y0, hscale, t0, resize, resize_data));
+}
+
+int ERKStepReset(void* arkode_mem, sunrealtype tR, N_Vector yR)
+{
+  return (ARKodeReset(arkode_mem, tR, yR));
+}
+
+int ERKStepSStolerances(void* arkode_mem, sunrealtype reltol, sunrealtype abstol)
+{
+  return (ARKodeSStolerances(arkode_mem, reltol, abstol));
+}
+
+int ERKStepSVtolerances(void* arkode_mem, sunrealtype reltol, N_Vector abstol)
+{
+  return (ARKodeSVtolerances(arkode_mem, reltol, abstol));
+}
+
+int ERKStepWFtolerances(void* arkode_mem, ARKEwtFn efun)
+{
+  return (ARKodeWFtolerances(arkode_mem, efun));
+}
+
+int ERKStepRootInit(void* arkode_mem, int nrtfn, ARKRootFn g)
+{
+  return (ARKodeRootInit(arkode_mem, nrtfn, g));
+}
+
+int ERKStepSetDefaults(void* arkode_mem)
+{
+  return (ARKodeSetDefaults(arkode_mem));
+}
+
+int ERKStepSetOrder(void* arkode_mem, int ord)
+{
+  return (ARKodeSetOrder(arkode_mem, ord));
+}
+
+int ERKStepSetInterpolantType(void* arkode_mem, int itype)
+{
+  return (ARKodeSetInterpolantType(arkode_mem, itype));
+}
+
+int ERKStepSetInterpolantDegree(void* arkode_mem, int degree)
+{
+  return (ARKodeSetInterpolantDegree(arkode_mem, degree));
+}
+
+int ERKStepSetDenseOrder(void* arkode_mem, int dord)
+{
+  return (ARKodeSetInterpolantDegree(arkode_mem, dord));
+}
+
+int ERKStepSetAdaptController(void* arkode_mem, SUNAdaptController C)
+{
+  return (ARKodeSetAdaptController(arkode_mem, C));
+}
+
+int ERKStepSetAdaptivityAdjustment(void* arkode_mem, int adjust)
+{
+  return (ARKodeSetAdaptivityAdjustment(arkode_mem, adjust));
+}
+
+int ERKStepSetCFLFraction(void* arkode_mem, sunrealtype cfl_frac)
+{
+  return (ARKodeSetCFLFraction(arkode_mem, cfl_frac));
+}
+
+int ERKStepSetSafetyFactor(void* arkode_mem, sunrealtype safety)
+{
+  return (ARKodeSetSafetyFactor(arkode_mem, safety));
+}
+
+int ERKStepSetErrorBias(void* arkode_mem, sunrealtype bias)
+{
+  return (ARKodeSetErrorBias(arkode_mem, bias));
+}
+
+int ERKStepSetMaxGrowth(void* arkode_mem, sunrealtype mx_growth)
+{
+  return (ARKodeSetMaxGrowth(arkode_mem, mx_growth));
+}
+
+int ERKStepSetMinReduction(void* arkode_mem, sunrealtype eta_min)
+{
+  return (ARKodeSetMinReduction(arkode_mem, eta_min));
+}
+
+int ERKStepSetFixedStepBounds(void* arkode_mem, sunrealtype lb, sunrealtype ub)
+{
+  return (ARKodeSetFixedStepBounds(arkode_mem, lb, ub));
+}
+
+int ERKStepSetAdaptivityMethod(void* arkode_mem, int imethod, int idefault,
+                               int pq, sunrealtype adapt_params[3])
+{
+  return (arkSetAdaptivityMethod(arkode_mem, imethod, idefault, pq, adapt_params));
+}
+
+int ERKStepSetAdaptivityFn(void* arkode_mem, ARKAdaptFn hfun, void* h_data)
+{
+  return (arkSetAdaptivityFn(arkode_mem, hfun, h_data));
+}
+
+int ERKStepSetMaxFirstGrowth(void* arkode_mem, sunrealtype etamx1)
+{
+  return (ARKodeSetMaxFirstGrowth(arkode_mem, etamx1));
+}
+
+int ERKStepSetMaxEFailGrowth(void* arkode_mem, sunrealtype etamxf)
+{
+  return (ARKodeSetMaxEFailGrowth(arkode_mem, etamxf));
+}
+
+int ERKStepSetSmallNumEFails(void* arkode_mem, int small_nef)
+{
+  return (ARKodeSetSmallNumEFails(arkode_mem, small_nef));
+}
+
+int ERKStepSetStabilityFn(void* arkode_mem, ARKExpStabFn EStab, void* estab_data)
+{
+  return (ARKodeSetStabilityFn(arkode_mem, EStab, estab_data));
+}
+
+int ERKStepSetMaxErrTestFails(void* arkode_mem, int maxnef)
+{
+  return (ARKodeSetMaxErrTestFails(arkode_mem, maxnef));
+}
+
+int ERKStepSetConstraints(void* arkode_mem, N_Vector constraints)
+{
+  return (ARKodeSetConstraints(arkode_mem, constraints));
+}
+
+int ERKStepSetMaxNumSteps(void* arkode_mem, long int mxsteps)
+{
+  return (ARKodeSetMaxNumSteps(arkode_mem, mxsteps));
+}
+
+int ERKStepSetMaxHnilWarns(void* arkode_mem, int mxhnil)
+{
+  return (ARKodeSetMaxHnilWarns(arkode_mem, mxhnil));
+}
+
+int ERKStepSetInitStep(void* arkode_mem, sunrealtype hin)
+{
+  return (ARKodeSetInitStep(arkode_mem, hin));
+}
+
+int ERKStepSetMinStep(void* arkode_mem, sunrealtype hmin)
+{
+  return (ARKodeSetMinStep(arkode_mem, hmin));
+}
+
+int ERKStepSetMaxStep(void* arkode_mem, sunrealtype hmax)
+{
+  return (ARKodeSetMaxStep(arkode_mem, hmax));
+}
+
+int ERKStepSetInterpolateStopTime(void* arkode_mem, sunbooleantype interp)
+{
+  return (ARKodeSetInterpolateStopTime(arkode_mem, interp));
+}
+
+int ERKStepSetStopTime(void* arkode_mem, sunrealtype tstop)
+{
+  return (ARKodeSetStopTime(arkode_mem, tstop));
+}
+
+int ERKStepClearStopTime(void* arkode_mem)
+{
+  return (ARKodeClearStopTime(arkode_mem));
+}
+
+int ERKStepSetFixedStep(void* arkode_mem, sunrealtype hfixed)
+{
+  return (ARKodeSetFixedStep(arkode_mem, hfixed));
+}
+
+int ERKStepSetMaxNumConstrFails(void* arkode_mem, int maxfails)
+{
+  return (ARKodeSetMaxNumConstrFails(arkode_mem, maxfails));
+}
+
+int ERKStepSetRootDirection(void* arkode_mem, int* rootdir)
+{
+  return (ARKodeSetRootDirection(arkode_mem, rootdir));
+}
+
+int ERKStepSetNoInactiveRootWarn(void* arkode_mem)
+{
+  return (ARKodeSetNoInactiveRootWarn(arkode_mem));
+}
+
+int ERKStepSetUserData(void* arkode_mem, void* user_data)
+{
+  return (ARKodeSetUserData(arkode_mem, user_data));
+}
+
+int ERKStepSetPostprocessStepFn(void* arkode_mem, ARKPostProcessFn ProcessStep)
+{
+  return (ARKodeSetPostprocessStepFn(arkode_mem, ProcessStep));
+}
+
+int ERKStepSetPostprocessStageFn(void* arkode_mem, ARKPostProcessFn ProcessStage)
+{
+  return (ARKodeSetPostprocessStageFn(arkode_mem, ProcessStage));
+}
+
+int ERKStepEvolve(void* arkode_mem, sunrealtype tout, N_Vector yout,
+                  sunrealtype* tret, int itask)
+{
+  return (ARKodeEvolve(arkode_mem, tout, yout, tret, itask));
+}
+
+int ERKStepGetDky(void* arkode_mem, sunrealtype t, int k, N_Vector dky)
+{
+  return (ARKodeGetDky(arkode_mem, t, k, dky));
+}
+
+int ERKStepGetNumExpSteps(void* arkode_mem, long int* nsteps)
+{
+  return (ARKodeGetNumExpSteps(arkode_mem, nsteps));
+}
+
+int ERKStepGetNumAccSteps(void* arkode_mem, long int* nsteps)
+{
+  return (ARKodeGetNumAccSteps(arkode_mem, nsteps));
+}
+
+int ERKStepGetNumStepAttempts(void* arkode_mem, long int* nstep_attempts)
+{
+  return (ARKodeGetNumStepAttempts(arkode_mem, nstep_attempts));
+}
+
+int ERKStepGetNumErrTestFails(void* arkode_mem, long int* netfails)
+{
+  return (ARKodeGetNumErrTestFails(arkode_mem, netfails));
+}
+
+int ERKStepGetEstLocalErrors(void* arkode_mem, N_Vector ele)
+{
+  return (ARKodeGetEstLocalErrors(arkode_mem, ele));
+}
+
+int ERKStepGetWorkSpace(void* arkode_mem, long int* lenrw, long int* leniw)
+{
+  return (ARKodeGetWorkSpace(arkode_mem, lenrw, leniw));
+}
+
+int ERKStepGetNumSteps(void* arkode_mem, long int* nsteps)
+{
+  return (ARKodeGetNumSteps(arkode_mem, nsteps));
+}
+
+int ERKStepGetActualInitStep(void* arkode_mem, sunrealtype* hinused)
+{
+  return (ARKodeGetActualInitStep(arkode_mem, hinused));
+}
+
+int ERKStepGetLastStep(void* arkode_mem, sunrealtype* hlast)
+{
+  return (ARKodeGetLastStep(arkode_mem, hlast));
+}
+
+int ERKStepGetCurrentStep(void* arkode_mem, sunrealtype* hcur)
+{
+  return (ARKodeGetCurrentStep(arkode_mem, hcur));
+}
+
+int ERKStepGetCurrentTime(void* arkode_mem, sunrealtype* tcur)
+{
+  return (ARKodeGetCurrentTime(arkode_mem, tcur));
+}
+
+int ERKStepGetTolScaleFactor(void* arkode_mem, sunrealtype* tolsfact)
+{
+  return (ARKodeGetTolScaleFactor(arkode_mem, tolsfact));
+}
+
+int ERKStepGetErrWeights(void* arkode_mem, N_Vector eweight)
+{
+  return (ARKodeGetErrWeights(arkode_mem, eweight));
+}
+
+int ERKStepGetNumGEvals(void* arkode_mem, long int* ngevals)
+{
+  return (ARKodeGetNumGEvals(arkode_mem, ngevals));
+}
+
+int ERKStepGetRootInfo(void* arkode_mem, int* rootsfound)
+{
+  return (ARKodeGetRootInfo(arkode_mem, rootsfound));
+}
+
+int ERKStepGetNumConstrFails(void* arkode_mem, long int* nconstrfails)
+{
+  return (ARKodeGetNumConstrFails(arkode_mem, nconstrfails));
+}
+
+int ERKStepGetUserData(void* arkode_mem, void** user_data)
+{
+  return (ARKodeGetUserData(arkode_mem, user_data));
+}
+
+int ERKStepPrintAllStats(void* arkode_mem, FILE* outfile, SUNOutputFormat fmt)
+{
+  return (ARKodePrintAllStats(arkode_mem, outfile, fmt));
+}
+
+char* ERKStepGetReturnFlagName(long int flag)
+{
+  return (ARKodeGetReturnFlagName(flag));
+}
+
+int ERKStepWriteParameters(void* arkode_mem, FILE* fp)
+{
+  return (ARKodeWriteParameters(arkode_mem, fp));
+}
 
-  Outputs Butcher tables to the provided file pointer.
-  ---------------------------------------------------------------*/
 int ERKStepWriteButcher(void* arkode_mem, FILE* fp)
 {
   int retval;
   ARKodeMem ark_mem;
   ARKodeERKStepMem step_mem;
 
-  /* access ARKodeERKStepMem structure */
-  retval = erkStep_AccessStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
+  /* access ARKodeMem and ARKodeERKStepMem structures */
+  retval = erkStep_AccessARKODEStepMem(arkode_mem, __func__, &ark_mem, &step_mem);
   if (retval != ARK_SUCCESS) { return (retval); }
 
   /* check that Butcher table is non-NULL (otherwise report error) */
@@ -841,6 +758,94 @@ int ERKStepWriteButcher(void* arkode_mem, FILE* fp)
   return (ARK_SUCCESS);
 }
 
-/*---------------------------------------------------------------
+int ERKStepGetStepStats(void* arkode_mem, long int* nsteps, sunrealtype* hinused,
+                        sunrealtype* hlast, sunrealtype* hcur, sunrealtype* tcur)
+{
+  return (ARKodeGetStepStats(arkode_mem, nsteps, hinused, hlast, hcur, tcur));
+}
+
+void ERKStepFree(void** arkode_mem) { ARKodeFree(arkode_mem); }
+
+void ERKStepPrintMem(void* arkode_mem, FILE* outfile)
+{
+  ARKodePrintMem(arkode_mem, outfile);
+}
+
+int ERKStepSetRelaxFn(void* arkode_mem, ARKRelaxFn rfn, ARKRelaxJacFn rjac)
+{
+  return (ARKodeSetRelaxFn(arkode_mem, rfn, rjac));
+}
+
+int ERKStepSetRelaxEtaFail(void* arkode_mem, sunrealtype eta_rf)
+{
+  return (ARKodeSetRelaxEtaFail(arkode_mem, eta_rf));
+}
+
+int ERKStepSetRelaxLowerBound(void* arkode_mem, sunrealtype lower)
+{
+  return (ARKodeSetRelaxLowerBound(arkode_mem, lower));
+}
+
+int ERKStepSetRelaxMaxFails(void* arkode_mem, int max_fails)
+{
+  return (ARKodeSetRelaxMaxFails(arkode_mem, max_fails));
+}
+
+int ERKStepSetRelaxMaxIters(void* arkode_mem, int max_iters)
+{
+  return (ARKodeSetRelaxMaxIters(arkode_mem, max_iters));
+}
+
+int ERKStepSetRelaxSolver(void* arkode_mem, ARKRelaxSolver solver)
+{
+  return (ARKodeSetRelaxSolver(arkode_mem, solver));
+}
+
+int ERKStepSetRelaxResTol(void* arkode_mem, sunrealtype res_tol)
+{
+  return (ARKodeSetRelaxResTol(arkode_mem, res_tol));
+}
+
+int ERKStepSetRelaxTol(void* arkode_mem, sunrealtype rel_tol, sunrealtype abs_tol)
+{
+  return (ARKodeSetRelaxTol(arkode_mem, rel_tol, abs_tol));
+}
+
+int ERKStepSetRelaxUpperBound(void* arkode_mem, sunrealtype upper)
+{
+  return (ARKodeSetRelaxUpperBound(arkode_mem, upper));
+}
+
+int ERKStepGetNumRelaxFnEvals(void* arkode_mem, long int* r_evals)
+{
+  return (ARKodeGetNumRelaxFnEvals(arkode_mem, r_evals));
+}
+
+int ERKStepGetNumRelaxJacEvals(void* arkode_mem, long int* J_evals)
+{
+  return (ARKodeGetNumRelaxJacEvals(arkode_mem, J_evals));
+}
+
+int ERKStepGetNumRelaxFails(void* arkode_mem, long int* relax_fails)
+{
+  return (ARKodeGetNumRelaxFails(arkode_mem, relax_fails));
+}
+
+int ERKStepGetNumRelaxBoundFails(void* arkode_mem, long int* fails)
+{
+  return (ARKodeGetNumRelaxBoundFails(arkode_mem, fails));
+}
+
+int ERKStepGetNumRelaxSolveFails(void* arkode_mem, long int* fails)
+{
+  return (ARKodeGetNumRelaxSolveFails(arkode_mem, fails));
+}
+
+int ERKStepGetNumRelaxSolveIters(void* arkode_mem, long int* iters)
+{
+  return (ARKodeGetNumRelaxSolveIters(arkode_mem, iters));
+}
+
+/*===============================================================
   EOF
-  ---------------------------------------------------------------*/
+  ===============================================================*/
