@@ -4,7 +4,7 @@
  *                Daniel Reynolds @ SMU
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -22,23 +22,16 @@
 #include <cvode/cvode.h>
 #include <sundials/priv/sundials_context_impl.h>
 #include <sundials/priv/sundials_errors_impl.h>
+#include <sundials/sundials_math.h>
 
 #include "cvode_proj_impl.h"
-#include "sundials/sundials_math.h"
 #include "sundials_logger_impl.h"
+#include "sundials_macros.h"
 
 #ifdef __cplusplus /* wrapper to enable C++ usage */
 extern "C" {
 #endif
 
-#if defined(SUNDIALS_EXTENDED_PRECISION)
-#define RSYM  ".32Lg"
-#define RSYMW "19.32Lg"
-#else
-#define RSYM  ".16g"
-#define RSYMW "23.16g"
-#endif
-
 /*===============================================================
   SHORTCUTS
   ===============================================================*/
@@ -295,7 +288,7 @@ typedef struct CVodeMemRec
   sunrealtype cv_delp;        /* norm of previous nonlinear solver update    */
   sunrealtype cv_acnrm;       /* | acor |                                    */
   sunbooleantype cv_acnrmcur; /* is | acor | current?                        */
-  sunrealtype cv_nlscoef;     /* coeficient in nonlinear convergence test    */
+  sunrealtype cv_nlscoef;     /* coefficient in nonlinear convergence test    */
 
   /*------
     Limits
@@ -466,6 +459,12 @@ typedef struct CVodeMemRec
 
   sunbooleantype cv_usefused; /* flag indicating if CVODE specific fused kernels should be used */
 
+  /*----------------
+    Resizing History
+    ----------------*/
+
+  sunbooleantype first_step_after_resize; /* Flag to signal a resize happened */
+
 }* CVodeMem;
 
 /*
@@ -634,37 +633,47 @@ void cvRestore(CVodeMem cv_mem, sunrealtype saved_t);
 
 void cvRescale(CVodeMem cv_mem);
 
+#ifdef SUNDIALS_BUILD_PACKAGE_FUSED_KERNELS
+int cvEwtSetSS_fused(const sunbooleantype atolmin0, const sunrealtype reltol,
+                     const sunrealtype Sabstol, const N_Vector ycur,
+                     N_Vector tempv, N_Vector weight);
+
+int cvEwtSetSV_fused(const sunbooleantype atolmin0, const sunrealtype reltol,
+                     const N_Vector Vabstol, const N_Vector ycur,
+                     N_Vector tempv, N_Vector weight);
+
+int cvCheckConstraints_fused(const N_Vector c, const N_Vector ewt,
+                             const N_Vector y, const N_Vector mm, N_Vector tempv);
+
+int cvNlsResid_fused(const sunrealtype rl1, const sunrealtype ngamma,
+                     const N_Vector zn1, const N_Vector ycor,
+                     const N_Vector ftemp, N_Vector res);
+
+int cvDiagSetup_formY(const sunrealtype h, const sunrealtype r,
+                      const N_Vector fpred, const N_Vector zn1,
+                      const N_Vector ypred, N_Vector ftemp, N_Vector y);
+
+int cvDiagSetup_buildM(const sunrealtype fract, const sunrealtype uround,
+                       const sunrealtype h, const N_Vector ftemp,
+                       const N_Vector fpred, const N_Vector ewt, N_Vector bit,
+                       N_Vector bitcomp, N_Vector y, N_Vector M);
+
+int cvDiagSolve_updateM(const sunrealtype r, N_Vector M);
+#endif
+
 /*
  * =================================================================
  *    E R R O R    M E S S A G E S
  * =================================================================
  */
 
-#if defined(SUNDIALS_EXTENDED_PRECISION)
-
-#define MSG_TIME       "t = %Lg"
-#define MSG_TIME_H     "t = %Lg and h = %Lg"
-#define MSG_TIME_INT   "t = %Lg is not between tcur - hu = %Lg and tcur = %Lg."
-#define MSG_TIME_TOUT  "tout = %Lg"
-#define MSG_TIME_TSTOP "tstop = %Lg"
-
-#elif defined(SUNDIALS_DOUBLE_PRECISION)
-
-#define MSG_TIME       "t = %lg"
-#define MSG_TIME_H     "t = %lg and h = %lg"
-#define MSG_TIME_INT   "t = %lg is not between tcur - hu = %lg and tcur = %lg."
-#define MSG_TIME_TOUT  "tout = %lg"
-#define MSG_TIME_TSTOP "tstop = %lg"
-
-#else
-
-#define MSG_TIME       "t = %g"
-#define MSG_TIME_H     "t = %g and h = %g"
-#define MSG_TIME_INT   "t = %g is not between tcur - hu = %g and tcur = %g."
-#define MSG_TIME_TOUT  "tout = %g"
-#define MSG_TIME_TSTOP "tstop = %g"
-
-#endif
+#define MSG_TIME   "t = " SUN_FORMAT_G
+#define MSG_TIME_H "t = " SUN_FORMAT_G " and h = " SUN_FORMAT_G
+#define MSG_TIME_INT                                                \
+  "t = " SUN_FORMAT_G " is not between tcur - hold = " SUN_FORMAT_G \
+  " and tcur = " SUN_FORMAT_G
+#define MSG_TIME_TOUT  "tout = " SUN_FORMAT_G
+#define MSG_TIME_TSTOP "tstop = " SUN_FORMAT_G
 
 /* Initialization and I/O error messages */
 
