@@ -4,7 +4,7 @@
  *                Radu Serban and Aaron Collier @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -479,9 +479,10 @@ int CVBBDPrecGetNumGfnEvals(void* cvode_mem, long int* ngevalsBBDP)
     0  if successful,
     1  for a recoverable error (step will be retried).
   -----------------------------------------------------------------*/
-static int cvBBDPrecSetup(sunrealtype t, N_Vector y, N_Vector fy,
-                          sunbooleantype jok, sunbooleantype* jcurPtr,
-                          sunrealtype gamma, void* bbd_data)
+static int cvBBDPrecSetup(sunrealtype t, N_Vector y,
+                          SUNDIALS_MAYBE_UNUSED N_Vector fy, sunbooleantype jok,
+                          sunbooleantype* jcurPtr, sunrealtype gamma,
+                          void* bbd_data)
 {
   CVBBDPrecData pdata;
   CVodeMem cv_mem;
@@ -568,9 +569,12 @@ static int cvBBDPrecSetup(sunrealtype t, N_Vector y, N_Vector fy,
   The value returned by the cvBBDPrecSolve function is always 0,
   indicating success.
   -----------------------------------------------------------------*/
-static int cvBBDPrecSolve(sunrealtype t, N_Vector y, N_Vector fy, N_Vector r,
-                          N_Vector z, sunrealtype gamma, sunrealtype delta,
-                          int lr, void* bbd_data)
+static int cvBBDPrecSolve(SUNDIALS_MAYBE_UNUSED sunrealtype t,
+                          SUNDIALS_MAYBE_UNUSED N_Vector y,
+                          SUNDIALS_MAYBE_UNUSED N_Vector fy, N_Vector r,
+                          N_Vector z, SUNDIALS_MAYBE_UNUSED sunrealtype gamma,
+                          SUNDIALS_MAYBE_UNUSED sunrealtype delta,
+                          SUNDIALS_MAYBE_UNUSED int lr, void* bbd_data)
 {
   int retval;
   CVBBDPrecData pdata;
