@@ -3,7 +3,7 @@
  *                Alan C. Hindmarsh and Radu Serban @ LLNL
  *-----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -413,7 +413,7 @@ int IDASetLSNormFactor(void* ida_mem, sunrealtype nrmfac)
   }
   else
   {
-    /* compute default factor for WRMS norm from vector legnth */
+    /* compute default factor for WRMS norm from vector length */
     idals_mem->nrmfac = SUNRsqrt(N_VGetLength(idals_mem->ytemp));
   }
 
@@ -901,7 +901,8 @@ int idaLsPSetup(void* ida_mem)
   is the only case in which the user's psolve routine is allowed
   to be NULL.
   ---------------------------------------------------------------*/
-int idaLsPSolve(void* ida_mem, N_Vector r, N_Vector z, sunrealtype tol, int lr)
+int idaLsPSolve(void* ida_mem, N_Vector r, N_Vector z, sunrealtype tol,
+                SUNDIALS_MAYBE_UNUSED int lr)
 {
   IDAMem IDA_mem;
   IDALsMem idals_mem;
@@ -1010,7 +1011,7 @@ int idaLsDenseDQJac(sunrealtype tt, sunrealtype c_j, N_Vector yy, N_Vector yp,
   /* access matrix dimension */
   N = SUNDenseMatrix_Columns(Jac);
 
-  /* Rename work vectors for readibility */
+  /* Rename work vectors for readability */
   rtemp = tmp1;
 
   /* Create an empty vector for matrix column calculations */
@@ -1179,7 +1180,7 @@ int idaLsBandDQJac(sunrealtype tt, sunrealtype c_j, N_Vector yy, N_Vector yp,
 
       /* Increment yj and ypj. */
       ytemp_data[j] += inc;
-      yptemp_data[j] += IDA_mem->ida_cj * inc;
+      yptemp_data[j] += c_j * inc;
     }
 
     /* Call res routine with incremented arguments. */
@@ -1263,7 +1264,7 @@ int idaLsDQJtimes(sunrealtype tt, N_Vector yy, N_Vector yp, N_Vector rr,
   }
   else { sig = idals_mem->dqincfac / N_VWrmsNorm(v, IDA_mem->ida_ewt); }
 
-  /* Rename work1 and work2 for readibility */
+  /* Rename work1 and work2 for readability */
   y_tmp  = work1;
   yp_tmp = work2;
 
@@ -1475,9 +1476,14 @@ int idaLsSolve(IDAMem IDA_mem, N_Vector b, N_Vector weight, N_Vector ycur,
                N_Vector ypcur, N_Vector rescur)
 {
   IDALsMem idals_mem;
-  int nli_inc, retval;
+  int retval;
+  int nli_inc = 0;
   sunrealtype tol, w_mean;
 
+  /* only used with logging */
+  SUNDIALS_MAYBE_UNUSED long int nps_inc    = 0;
+  SUNDIALS_MAYBE_UNUSED sunrealtype resnorm = SUN_RCONST(0.0);
+
   /* access IDALsMem structure */
   if (IDA_mem->ida_lmem == NULL)
   {
@@ -1495,8 +1501,16 @@ int idaLsSolve(IDAMem IDA_mem, N_Vector b, N_Vector weight, N_Vector ycur,
   if (idals_mem->iterative)
   {
     tol = idals_mem->nrmfac * idals_mem->eplifac * IDA_mem->ida_epsNewt;
+
+    SUNLogInfo(IDA_LOGGER, "begin-linear-solve",
+               "iterative = 1, res-tol = %.16g", tol);
+  }
+  else
+  {
+    tol = ZERO;
+
+    SUNLogInfo(IDA_LOGGER, "begin-linear-solve", "iterative = 0");
   }
-  else { tol = ZERO; }
 
   /* Set vectors ycur, ypcur and rcur for use by the Atimes and
      Psolve interface routines */
@@ -1513,6 +1527,10 @@ int idaLsSolve(IDAMem IDA_mem, N_Vector b, N_Vector weight, N_Vector ycur,
       IDAProcessError(IDA_mem, IDALS_SUNLS_FAIL, __LINE__, __func__, __FILE__,
                       "Error in calling SUNLinSolSetScalingVectors");
       idals_mem->last_flag = IDALS_SUNLS_FAIL;
+
+      SUNLogInfo(IDA_LOGGER, "end-linear-solve",
+                 "status = failed set scaling vectors");
+
       return (idals_mem->last_flag);
     }
 
@@ -1543,7 +1561,15 @@ int idaLsSolve(IDAMem IDA_mem, N_Vector b, N_Vector weight, N_Vector ycur,
 
   /* Set zero initial guess flag */
   retval = SUNLinSolSetZeroGuess(idals_mem->LS, SUNTRUE);
-  if (retval != SUN_SUCCESS) { return (-1); }
+  if (retval != SUN_SUCCESS)
+  {
+    SUNLogInfo(IDA_LOGGER, "end-linear-solve", "status = failed set zero guess",
+               "");
+    return (-1);
+  }
+
+  /* Store previous nps value in nps_inc */
+  nps_inc = idals_mem->nps;
 
   /* If a user-provided jtsetup routine is supplied, call that here */
   if (idals_mem->jtsetup)
@@ -1556,6 +1582,8 @@ int idaLsSolve(IDAMem IDA_mem, N_Vector b, N_Vector weight, N_Vector ycur,
     {
       IDAProcessError(IDA_mem, retval, __LINE__, __func__, __FILE__,
                       MSG_LS_JTSETUP_FAILED);
+
+      SUNLogInfo(IDA_LOGGER, "end-linear-solve", "status = failed J-times setup");
       return (idals_mem->last_flag);
     }
   }
@@ -1568,6 +1596,7 @@ int idaLsSolve(IDAMem IDA_mem, N_Vector b, N_Vector weight, N_Vector ycur,
   {
     /* Retrieve solver statistics */
     nli_inc = SUNLinSolNumIters(idals_mem->LS);
+    resnorm = SUNLinSolResNorm(idals_mem->LS);
 
     /* Copy x (or preconditioned residual vector if no iterations required) to b */
     if ((nli_inc == 0) &&
@@ -1599,6 +1628,13 @@ int idaLsSolve(IDAMem IDA_mem, N_Vector b, N_Vector weight, N_Vector ycur,
   /* Interpret solver return value  */
   idals_mem->last_flag = retval;
 
+  SUNLogInfoIf(retval == SUN_SUCCESS, IDA_LOGGER, "end-linear-solve",
+               "status = success, iters = %i, p-solves = %i, res-norm = %.16g",
+               nli_inc, (int)(idals_mem->nps - nps_inc), resnorm);
+  SUNLogInfoIf(retval != SUN_SUCCESS, IDA_LOGGER,
+               "end-linear-solve", "status = failed, retval = %i, iters = %i, p-solves = %i, res-norm = %.16g",
+               retval, nli_inc, (int)(idals_mem->nps - nps_inc), resnorm);
+
   switch (retval)
   {
   case SUN_SUCCESS: return (0); break;
