@@ -7,7 +7,7 @@
  *                   @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -20,16 +20,18 @@
  * of the NVECTOR module.
  * -----------------------------------------------------------------*/
 
-#include <nvector/nvector_openmp.h>
 #include <omp.h>
 #include <stdio.h>
 #include <stdlib.h>
+
+#include <nvector/nvector_openmp.h>
 #include <sundials/priv/sundials_context_impl.h>
 #include <sundials/priv/sundials_errors_impl.h>
+#include <sundials/sundials_context.h>
 #include <sundials/sundials_core.h>
+#include <sundials/sundials_errors.h>
 
-#include "sundials/sundials_context.h"
-#include "sundials/sundials_errors.h"
+#include "sundials_macros.h"
 
 #define ZERO   SUN_RCONST(0.0)
 #define HALF   SUN_RCONST(0.5)
@@ -82,7 +84,10 @@ static void VaxpyVectorArray_OpenMP(int nvec, sunrealtype a, N_Vector* X,
  * Returns vector type ID. Used to identify vector implementation
  * from abstract N_Vector interface.
  */
-N_Vector_ID N_VGetVectorID_OpenMP(N_Vector v) { return SUNDIALS_NVEC_OPENMP; }
+N_Vector_ID N_VGetVectorID_OpenMP(SUNDIALS_MAYBE_UNUSED N_Vector v)
+{
+  return SUNDIALS_NVEC_OPENMP;
+}
 
 /* ----------------------------------------------------------------------------
  * Function to create a new empty vector
@@ -260,17 +265,7 @@ void N_VPrintFile_OpenMP(N_Vector x, FILE* outfile)
   N  = NV_LENGTH_OMP(x);
   xd = NV_DATA_OMP(x);
 
-  for (i = 0; i < N; i++)
-  {
-#if defined(SUNDIALS_EXTENDED_PRECISION)
-    fprintf(outfile, "%11.8Lg\n", xd[i]);
-#elif defined(SUNDIALS_DOUBLE_PRECISION)
-    fprintf(outfile, "%11.8g\n", xd[i]);
-#else
-    fprintf(outfile, "%11.8g\n", xd[i]);
-#endif
-  }
-  fprintf(outfile, "\n");
+  for (i = 0; i < N; i++) { fprintf(outfile, SUN_FORMAT_E "\n", xd[i]); }
 
   return;
 }
