@@ -4,7 +4,7 @@
  *                Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -38,99 +38,47 @@ sunindextype SUNDlsMat_DenseGETRF(SUNDlsMat A, sunindextype* p)
   return (SUNDlsMat_denseGETRF(A->cols, A->M, A->N, p));
 }
 
-sunindextype DenseGETRF(SUNDlsMat A, sunindextype* p)
-{
-  return (SUNDlsMat_denseGETRF(A->cols, A->M, A->N, p));
-}
-
 void SUNDlsMat_DenseGETRS(SUNDlsMat A, sunindextype* p, sunrealtype* b)
 {
   SUNDlsMat_denseGETRS(A->cols, A->N, p, b);
 }
 
-void DenseGETRS(SUNDlsMat A, sunindextype* p, sunrealtype* b)
-{
-  SUNDlsMat_denseGETRS(A->cols, A->N, p, b);
-}
-
 sunindextype SUNDlsMat_DensePOTRF(SUNDlsMat A)
 {
   return (SUNDlsMat_densePOTRF(A->cols, A->M));
 }
 
-sunindextype DensePOTRF(SUNDlsMat A)
-{
-  return (SUNDlsMat_densePOTRF(A->cols, A->M));
-}
-
 void SUNDlsMat_DensePOTRS(SUNDlsMat A, sunrealtype* b)
 {
   SUNDlsMat_densePOTRS(A->cols, A->M, b);
 }
 
-void DensePOTRS(SUNDlsMat A, sunrealtype* b)
-{
-  SUNDlsMat_densePOTRS(A->cols, A->M, b);
-}
-
 int SUNDlsMat_DenseGEQRF(SUNDlsMat A, sunrealtype* beta, sunrealtype* wrk)
 {
   return (SUNDlsMat_denseGEQRF(A->cols, A->M, A->N, beta, wrk));
 }
 
-int DenseGEQRF(SUNDlsMat A, sunrealtype* beta, sunrealtype* wrk)
-{
-  return (SUNDlsMat_denseGEQRF(A->cols, A->M, A->N, beta, wrk));
-}
-
 int SUNDlsMat_DenseORMQR(SUNDlsMat A, sunrealtype* beta, sunrealtype* vn,
                          sunrealtype* vm, sunrealtype* wrk)
 {
   return (SUNDlsMat_denseORMQR(A->cols, A->M, A->N, beta, vn, vm, wrk));
 }
 
-int DenseORMQR(SUNDlsMat A, sunrealtype* beta, sunrealtype* vn, sunrealtype* vm,
-               sunrealtype* wrk)
-{
-  return (SUNDlsMat_denseORMQR(A->cols, A->M, A->N, beta, vn, vm, wrk));
-}
-
 void SUNDlsMat_DenseCopy(SUNDlsMat A, SUNDlsMat B)
 {
   SUNDlsMat_denseCopy(A->cols, B->cols, A->M, A->N);
 }
 
-void DenseCopy(SUNDlsMat A, SUNDlsMat B)
-{
-  SUNDlsMat_denseCopy(A->cols, B->cols, A->M, A->N);
-}
-
 void SUNDlsMat_DenseScale(sunrealtype c, SUNDlsMat A)
 {
   SUNDlsMat_denseScale(c, A->cols, A->M, A->N);
 }
 
-void DenseScale(sunrealtype c, SUNDlsMat A)
-{
-  SUNDlsMat_denseScale(c, A->cols, A->M, A->N);
-}
-
 void SUNDlsMat_DenseMatvec(SUNDlsMat A, sunrealtype* x, sunrealtype* y)
 {
   SUNDlsMat_denseMatvec(A->cols, x, y, A->M, A->N);
 }
 
-void DenseMatvec(SUNDlsMat A, sunrealtype* x, sunrealtype* y)
-{
-  SUNDlsMat_denseMatvec(A->cols, x, y, A->M, A->N);
-}
-
-sunindextype denseGETRF(sunrealtype** a, sunindextype m, sunindextype n,
-                        sunindextype* p)
-{
-  return (SUNDlsMat_denseGETRF(a, m, n, p));
-}
-
 sunindextype SUNDlsMat_denseGETRF(sunrealtype** a, sunindextype m,
                                   sunindextype n, sunindextype* p)
 {
@@ -199,11 +147,6 @@ sunindextype SUNDlsMat_denseGETRF(sunrealtype** a, sunindextype m,
   return (0);
 }
 
-void denseGETRS(sunrealtype** a, sunindextype n, sunindextype* p, sunrealtype* b)
-{
-  SUNDlsMat_denseGETRS(a, n, p, b);
-}
-
 void SUNDlsMat_denseGETRS(sunrealtype** a, sunindextype n, sunindextype* p,
                           sunrealtype* b)
 {
@@ -246,11 +189,6 @@ void SUNDlsMat_denseGETRS(sunrealtype** a, sunindextype n, sunindextype* p,
  * the lower triangle of C.
  */
 
-sunindextype densePOTRF(sunrealtype** a, sunindextype m)
-{
-  return (SUNDlsMat_densePOTRF(a, m));
-}
-
 sunindextype SUNDlsMat_densePOTRF(sunrealtype** a, sunindextype m)
 {
   sunrealtype *a_col_j, *a_col_k;
@@ -289,11 +227,6 @@ sunindextype SUNDlsMat_densePOTRF(sunrealtype** a, sunindextype m)
  *
  */
 
-void densePOTRS(sunrealtype** a, sunindextype m, sunrealtype* b)
-{
-  SUNDlsMat_densePOTRS(a, m, b);
-}
-
 void SUNDlsMat_densePOTRS(sunrealtype** a, sunindextype m, sunrealtype* b)
 {
   sunrealtype *col_j, *col_i;
@@ -334,12 +267,6 @@ void SUNDlsMat_densePOTRS(sunrealtype** a, sunindextype m, sunrealtype* b)
  *
  */
 
-int denseGEQRF(sunrealtype** a, sunindextype m, sunindextype n,
-               sunrealtype* beta, sunrealtype* v)
-{
-  return (SUNDlsMat_denseGEQRF(a, m, n, beta, v));
-}
-
 int SUNDlsMat_denseGEQRF(sunrealtype** a, sunindextype m, sunindextype n,
                          sunrealtype* beta, sunrealtype* v)
 {
@@ -404,12 +331,6 @@ int SUNDlsMat_denseGEQRF(sunrealtype** a, sunindextype m, sunindextype n,
  * v (of length m) must be provided as workspace.
  */
 
-int denseORMQR(sunrealtype** a, sunindextype m, sunindextype n, sunrealtype* beta,
-               sunrealtype* vn, sunrealtype* vm, sunrealtype* v)
-{
-  return (SUNDlsMat_denseORMQR(a, m, n, beta, vn, vm, v));
-}
-
 int SUNDlsMat_denseORMQR(sunrealtype** a, sunindextype m, sunindextype n,
                          sunrealtype* beta, sunrealtype* vn, sunrealtype* vm,
                          sunrealtype* v)
@@ -441,11 +362,6 @@ int SUNDlsMat_denseORMQR(sunrealtype** a, sunindextype m, sunindextype n,
   return (0);
 }
 
-void denseCopy(sunrealtype** a, sunrealtype** b, sunindextype m, sunindextype n)
-{
-  SUNDlsMat_denseCopy(a, b, m, n);
-}
-
 void SUNDlsMat_denseCopy(sunrealtype** a, sunrealtype** b, sunindextype m,
                          sunindextype n)
 {
@@ -460,11 +376,6 @@ void SUNDlsMat_denseCopy(sunrealtype** a, sunrealtype** b, sunindextype m,
   }
 }
 
-void denseScale(sunrealtype c, sunrealtype** a, sunindextype m, sunindextype n)
-{
-  SUNDlsMat_denseScale(c, a, m, n);
-}
-
 void SUNDlsMat_denseScale(sunrealtype c, sunrealtype** a, sunindextype m,
                           sunindextype n)
 {
@@ -478,11 +389,6 @@ void SUNDlsMat_denseScale(sunrealtype c, sunrealtype** a, sunindextype m,
   }
 }
 
-void denseAddIdentity(sunrealtype** a, sunindextype n)
-{
-  SUNDlsMat_denseAddIdentity(a, n);
-}
-
 void SUNDlsMat_denseAddIdentity(sunrealtype** a, sunindextype n)
 {
   sunindextype i;
@@ -490,19 +396,13 @@ void SUNDlsMat_denseAddIdentity(sunrealtype** a, sunindextype n)
   for (i = 0; i < n; i++) { a[i][i] += ONE; }
 }
 
-void denseMatvec(sunrealtype** a, sunrealtype* x, sunrealtype* y,
-                 sunindextype m, sunindextype n)
-{
-  SUNDlsMat_denseMatvec(a, x, y, m, n);
-}
-
 void SUNDlsMat_denseMatvec(sunrealtype** a, sunrealtype* x, sunrealtype* y,
                            sunindextype m, sunindextype n)
 {
   sunindextype i, j;
   sunrealtype* col_j;
 
-  for (i = 0; i < m; i++) { y[i] = 0.0; }
+  for (i = 0; i < m; i++) { y[i] = ZERO; }
 
   for (j = 0; j < n; j++)
   {
