@@ -2,7 +2,7 @@
  * Programmer(s): Cody J. Balos
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2023, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -14,16 +14,35 @@
  * SUNDIALS Fortran 2003 interface utility implementations.
  * -----------------------------------------------------------------*/
 
+#include <string.h>
+#include <sundials/priv/sundials_errors_impl.h>
+#include <sundials/sundials_errors.h>
 #include <sundials/sundials_futils.h>
 
 /* Create a file pointer with the given file name and mode. */
-FILE* SUNDIALSFileOpen(const char* filename, const char* mode)
+SUNErrCode SUNDIALSFileOpen(const char* filename, const char* mode, FILE** fp_out)
 {
-  return fopen(filename, mode);
+  SUNErrCode err = SUN_SUCCESS;
+  FILE* fp       = *fp_out;
+
+  if (filename)
+  {
+    if (!strcmp(filename, "stdout")) { fp = stdout; }
+    else if (!strcmp(filename, "stderr")) { fp = stderr; }
+    else { fp = fopen(filename, mode); }
+  }
+
+  if (!fp) { err = SUN_ERR_FILE_OPEN; }
+
+  *fp_out = fp;
+  return err;
 }
 
 /* Close a file pointer with the given file name. */
-void SUNDIALSFileClose(FILE* fp)
+SUNErrCode SUNDIALSFileClose(FILE** fp_ptr)
 {
-  fclose(fp);
+  if (!fp_ptr) { return SUN_SUCCESS; }
+  FILE* fp = *fp_ptr;
+  if (fp && (fp != stdout) && (fp != stderr)) { fclose(fp); }
+  return SUN_SUCCESS;
 }
