@@ -5,7 +5,7 @@
  *     Alan C. Hindmarsh and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -20,10 +20,12 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+
 #include <sundials/priv/sundials_errors_impl.h>
+#include <sundials/sundials_errors.h>
 #include <sunmatrix/sunmatrix_dense.h>
 
-#include "sundials/sundials_errors.h"
+#include "sundials_macros.h"
 
 #define ZERO SUN_RCONST(0.0)
 #define ONE  SUN_RCONST(1.0)
@@ -59,15 +61,16 @@ SUNMatrix SUNDenseMatrix(sunindextype M, sunindextype N, SUNContext sunctx)
   SUNCheckLastErrNull();
 
   /* Attach operations */
-  A->ops->getid     = SUNMatGetID_Dense;
-  A->ops->clone     = SUNMatClone_Dense;
-  A->ops->destroy   = SUNMatDestroy_Dense;
-  A->ops->zero      = SUNMatZero_Dense;
-  A->ops->copy      = SUNMatCopy_Dense;
-  A->ops->scaleadd  = SUNMatScaleAdd_Dense;
-  A->ops->scaleaddi = SUNMatScaleAddI_Dense;
-  A->ops->matvec    = SUNMatMatvec_Dense;
-  A->ops->space     = SUNMatSpace_Dense;
+  A->ops->getid                    = SUNMatGetID_Dense;
+  A->ops->clone                    = SUNMatClone_Dense;
+  A->ops->destroy                  = SUNMatDestroy_Dense;
+  A->ops->zero                     = SUNMatZero_Dense;
+  A->ops->copy                     = SUNMatCopy_Dense;
+  A->ops->scaleadd                 = SUNMatScaleAdd_Dense;
+  A->ops->scaleaddi                = SUNMatScaleAddI_Dense;
+  A->ops->matvec                   = SUNMatMatvec_Dense;
+  A->ops->mathermitiantransposevec = SUNMatHermitianTransposeVec_Dense;
+  A->ops->space                    = SUNMatSpace_Dense;
 
   /* Create content */
   content = NULL;
@@ -112,17 +115,10 @@ void SUNDenseMatrix_Print(SUNMatrix A, FILE* outfile)
   {
     for (j = 0; j < SM_COLUMNS_D(A); j++)
     {
-#if defined(SUNDIALS_EXTENDED_PRECISION)
-      fprintf(outfile, "%12Lg  ", SM_ELEMENT_D(A, i, j));
-#elif defined(SUNDIALS_DOUBLE_PRECISION)
-      fprintf(outfile, "%12g  ", SM_ELEMENT_D(A, i, j));
-#else
-      fprintf(outfile, "%12g  ", SM_ELEMENT_D(A, i, j));
-#endif
+      fprintf(outfile, SUN_FORMAT_E "  ", SM_ELEMENT_D(A, i, j));
     }
     fprintf(outfile, "\n");
   }
-  fprintf(outfile, "\n");
   return;
 }
 
@@ -178,7 +174,10 @@ sunrealtype* SUNDenseMatrix_Column(SUNMatrix A, sunindextype j)
  * -----------------------------------------------------------------
  */
 
-SUNMatrix_ID SUNMatGetID_Dense(SUNMatrix A) { return SUNMATRIX_DENSE; }
+SUNMatrix_ID SUNMatGetID_Dense(SUNDIALS_MAYBE_UNUSED SUNMatrix A)
+{
+  return SUNMATRIX_DENSE;
+}
 
 SUNMatrix SUNMatClone_Dense(SUNMatrix A)
 {
@@ -303,8 +302,7 @@ SUNErrCode SUNMatScaleAdd_Dense(sunrealtype c, SUNMatrix A, SUNMatrix B)
 SUNErrCode SUNMatMatvec_Dense(SUNMatrix A, N_Vector x, N_Vector y)
 {
   SUNFunctionBegin(A->sunctx);
-  sunindextype i, j;
-  sunrealtype *col_j, *xd, *yd;
+  sunrealtype *xd, *yd;
 
   SUNAssert(SUNMatGetID(A) == SUNMATRIX_DENSE, SUN_ERR_ARG_WRONGTYPE);
   SUNCheck(compatibleMatrixAndVectors(A, x, y), SUN_ERR_ARG_DIMSMISMATCH);
@@ -320,11 +318,45 @@ SUNErrCode SUNMatMatvec_Dense(SUNMatrix A, N_Vector x, N_Vector y)
   SUNAssert(xd != yd, SUN_ERR_MEM_FAIL);
 
   /* Perform operation y = Ax */
-  for (i = 0; i < SM_ROWS_D(A); i++) { yd[i] = ZERO; }
-  for (j = 0; j < SM_COLUMNS_D(A); j++)
+  for (sunindextype i = 0; i < SM_ROWS_D(A); i++) { yd[i] = ZERO; }
+  for (sunindextype j = 0; j < SM_COLUMNS_D(A); j++)
   {
-    col_j = SM_COLUMN_D(A, j);
-    for (i = 0; i < SM_ROWS_D(A); i++) { yd[i] += col_j[i] * xd[j]; }
+    sunrealtype* col_j = SM_COLUMN_D(A, j);
+    for (sunindextype i = 0; i < SM_ROWS_D(A); i++)
+    {
+      yd[i] += col_j[i] * xd[j];
+    }
+  }
+  return SUN_SUCCESS;
+}
+
+SUNErrCode SUNMatHermitianTransposeVec_Dense(SUNMatrix A, N_Vector x, N_Vector y)
+{
+  SUNFunctionBegin(A->sunctx);
+
+  SUNAssert(SUNMatGetID(A) == SUNMATRIX_DENSE, SUN_ERR_ARG_WRONGTYPE);
+  SUNCheck(compatibleMatrixAndVectors(A, y, x), SUN_ERR_ARG_DIMSMISMATCH);
+
+  /* access vector data (return if NULL data pointers) */
+  sunrealtype *xd, *yd;
+  xd = N_VGetArrayPointer(x);
+  SUNCheckLastErr();
+  yd = N_VGetArrayPointer(y);
+  SUNCheckLastErr();
+
+  SUNAssert(xd, SUN_ERR_MEM_FAIL);
+  SUNAssert(yd, SUN_ERR_MEM_FAIL);
+  SUNAssert(xd != yd, SUN_ERR_MEM_FAIL);
+
+  /* Perform operation y = A^T x */
+  for (sunindextype i = 0; i < SM_COLUMNS_D(A); i++) { yd[i] = ZERO; }
+  for (sunindextype i = 0; i < SM_COLUMNS_D(A); i++)
+  {
+    sunrealtype* row_i = SM_COLUMN_D(A, i);
+    for (sunindextype j = 0; j < SM_ROWS_D(A); j++)
+    {
+      yd[i] += row_i[j] * xd[j];
+    }
   }
   return SUN_SUCCESS;
 }
@@ -346,6 +378,7 @@ SUNErrCode SUNMatSpace_Dense(SUNMatrix A, long int* lenrw, long int* leniw)
  * -----------------------------------------------------------------
  */
 
+SUNDIALS_MAYBE_UNUSED
 static sunbooleantype compatibleMatrices(SUNMatrix A, SUNMatrix B)
 {
   /* both matrices must have the same shape */
@@ -357,6 +390,7 @@ static sunbooleantype compatibleMatrices(SUNMatrix A, SUNMatrix B)
   return SUNTRUE;
 }
 
+SUNDIALS_MAYBE_UNUSED
 static sunbooleantype compatibleMatrixAndVectors(SUNMatrix A, N_Vector x,
                                                  N_Vector y)
 {
