@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -35,16 +35,6 @@
 #include "sundials/sundials_types.h"  // def. of type 'sunrealtype'
 #include "sunlinsol/sunlinsol_pcg.h"  // access to PCG SUNLinearSolver
 
-#if defined(SUNDIALS_EXTENDED_PRECISION)
-#define GSYM "Lg"
-#define ESYM "Le"
-#define FSYM "Lf"
-#else
-#define GSYM "g"
-#define ESYM "e"
-#define FSYM "f"
-#endif
-
 using namespace std;
 
 // accessor macros between (x,y) location and 1D NVector array
@@ -225,8 +215,8 @@ int main(int argc, char* argv[])
   if (check_flag((void*)inner_mem, "ARKStepCreate", 0)) { return 1; }
 
   MRIStepInnerStepper inner_stepper = NULL;
-  flag = ARKStepCreateMRIStepInnerStepper(inner_mem, &inner_stepper);
-  if (check_flag(&flag, "ARKStepCreateMRIStepInnerStepper", 1)) { return 1; }
+  flag = ARKodeCreateMRIStepInnerStepper(inner_mem, &inner_stepper);
+  if (check_flag(&flag, "ARKodeCreateMRIStepInnerStepper", 1)) { return 1; }
 
   mristep_mem = MRIStepCreate(NULL, f, T0, y, inner_stepper, ctx);
   if (check_flag((void*)mristep_mem, "MRIStepCreate", 0)) { return 1; }
@@ -258,86 +248,88 @@ int main(int argc, char* argv[])
   if (check_flag((void*)C, "MRIStepCoupling_MIStoMRI", 0)) { return 1; }
 
   // Set routines
-  flag = ARKStepSetUserData(arkstep_mem,
-                            (void*)udata); // Pass udata to user functions
-  if (check_flag(&flag, "ARKStepSetUserData", 1)) { return 1; }
-  flag = ARKStepSetNonlinConvCoef(arkstep_mem,
-                                  SUN_RCONST(1.e-7)); // Update solver convergence coeff.
-  if (check_flag(&flag, "ARKStepSetNonlinConvCoef", 1)) { return 1; }
-  flag = ARKStepSStolerances(arkstep_mem, rtol, atol); // Specify tolerances
-  if (check_flag(&flag, "ARKStepSStolerances", 1)) { return 1; }
-  flag = ARKStepSetFixedStep(arkstep_mem, Tf / Nt); // Specify fixed time step size
-  if (check_flag(&flag, "ARKStepSetFixedStep", 1)) { return 1; }
+  flag = ARKodeSetUserData(arkstep_mem,
+                           (void*)udata); // Pass udata to user functions
+  if (check_flag(&flag, "ARKodeSetUserData", 1)) { return 1; }
+  flag = ARKodeSetNonlinConvCoef(arkstep_mem,
+                                 SUN_RCONST(1.e-7)); // Update solver convergence coeff.
+  if (check_flag(&flag, "ARKodeSetNonlinConvCoef", 1)) { return 1; }
+  flag = ARKodeSStolerances(arkstep_mem, rtol, atol); // Specify tolerances
+  if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
+  flag = ARKodeSetFixedStep(arkstep_mem, Tf / Nt); // Specify fixed time step size
+  if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
   flag = ARKStepSetTables(arkstep_mem, 2, 0, B, NULL); // Specify Butcher table
   if (check_flag(&flag, "ARKStepSetTables", 1)) { return 1; }
-  flag = ARKStepSetMaxNumSteps(arkstep_mem, 2 * Nt); // Increase num internal steps
-  if (check_flag(&flag, "ARKStepSetMaxNumSteps", 1)) { return 1; }
+  flag = ARKodeSetMaxNumSteps(arkstep_mem, 2 * Nt); // Increase num internal steps
+  if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
-  flag = MRIStepSetUserData(mristep_mem,
-                            (void*)udata); // Pass udata to user functions
-  if (check_flag(&flag, "MRIStepSetUserData", 1)) { return 1; }
-  flag = MRIStepSetNonlinConvCoef(mristep_mem,
-                                  SUN_RCONST(1.e-7)); // Update solver convergence coeff.
-  if (check_flag(&flag, "MRIStepSetNonlinConvCoef", 1)) { return 1; }
-  flag = MRIStepSStolerances(mristep_mem, rtol, atol); // Specify tolerances
-  if (check_flag(&flag, "MRIStepSStolerances", 1)) { return 1; }
-  flag = MRIStepSetFixedStep(mristep_mem, Tf / Nt); // Specify fixed time step sizes
-  if (check_flag(&flag, "MRIStepSetFixedStep", 1)) { return 1; }
-  flag = ARKStepSetFixedStep(inner_mem, Tf / Nt / 10);
-  if (check_flag(&flag, "ARKStepSetFixedStep", 1)) { return 1; }
-  flag = MRIStepSetCoupling(mristep_mem, C); // Specify Butcher table
+  flag = ARKodeSetUserData(mristep_mem,
+                           (void*)udata); // Pass udata to user functions
+  if (check_flag(&flag, "ARKodeSetUserData", 1)) { return 1; }
+  flag = ARKodeSetNonlinConvCoef(mristep_mem,
+                                 SUN_RCONST(1.e-7)); // Update solver convergence coeff.
+  if (check_flag(&flag, "ARKodeSetNonlinConvCoef", 1)) { return 1; }
+  flag = ARKodeSStolerances(mristep_mem, rtol, atol); // Specify tolerances
+  if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
+  flag = ARKodeSetFixedStep(mristep_mem, Tf / Nt); // Specify fixed time step sizes
+  if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
+  flag = ARKodeSetFixedStep(inner_mem, Tf / Nt / 10);
+  if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
+  flag = MRIStepSetCoupling(mristep_mem, C); // Specify coupling table
   if (check_flag(&flag, "MRIStepSetCoupling", 1)) { return 1; }
-  flag = MRIStepSetMaxNumSteps(mristep_mem, 2 * Nt); // Increase num internal steps
-  if (check_flag(&flag, "MRIStepSetMaxNumSteps", 1)) { return 1; }
+  flag = ARKodeSetMaxNumSteps(mristep_mem, 2 * Nt); // Increase num internal steps
+  if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
   // Linear solver interface
-  flag = ARKStepSetLinearSolver(arkstep_mem, LSa, NULL); // Attach linear solver
-  if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) { return 1; }
-  flag = ARKStepSetPreconditioner(arkstep_mem, PSet,
-                                  PSol); // Specify the Preconditoner
-  if (check_flag(&flag, "ARKStepSetPreconditioner", 1)) { return 1; }
+  flag = ARKodeSetLinearSolver(arkstep_mem, LSa, NULL); // Attach linear solver
+  if (check_flag(&flag, "ARKodeSetLinearSolver", 1)) { return 1; }
+  flag = ARKodeSetPreconditioner(arkstep_mem, PSet,
+                                 PSol); // Specify the Preconditioner
+  if (check_flag(&flag, "ARKodeSetPreconditioner", 1)) { return 1; }
 
-  flag = MRIStepSetLinearSolver(mristep_mem, LSm, NULL); // Attach linear solver
-  if (check_flag(&flag, "MRIStepSetLinearSolver", 1)) { return 1; }
-  flag = MRIStepSetPreconditioner(mristep_mem, PSet,
-                                  PSol); // Specify the Preconditoner
-  if (check_flag(&flag, "MRIStepSetPreconditioner", 1)) { return 1; }
+  flag = ARKodeSetLinearSolver(mristep_mem, LSm, NULL); // Attach linear solver
+  if (check_flag(&flag, "ARKodeSetLinearSolver", 1)) { return 1; }
+  flag = ARKodeSetPreconditioner(mristep_mem, PSet,
+                                 PSol); // Specify the Preconditioner
+  if (check_flag(&flag, "ARKodeSetPreconditioner", 1)) { return 1; }
 
   // Optionally specify linearly implicit RHS, with non-time-dependent preconditioner
   if (linear)
   {
-    flag = ARKStepSetLinear(arkstep_mem, 0);
-    if (check_flag(&flag, "ARKStepSetLinear", 1)) { return 1; }
+    flag = ARKodeSetLinear(arkstep_mem, 0);
+    if (check_flag(&flag, "ARKodeSetLinear", 1)) { return 1; }
 
-    flag = MRIStepSetLinear(mristep_mem, 0);
-    if (check_flag(&flag, "MRIStepSetLinear", 1)) { return 1; }
+    flag = ARKodeSetLinear(mristep_mem, 0);
+    if (check_flag(&flag, "ARKodeSetLinear", 1)) { return 1; }
   }
 
-  // First call ARKStep to evolve the full problem, and print results
+  // First call ARKodeEvolve to evolve the full problem, and print results
   t = T0;
   N_VConst(ZERO, y);
-  flag = ARKStepEvolve(arkstep_mem, Tf, y, &t, ARK_NORMAL);
-  if (check_flag(&flag, "ARKStepEvolve", 1)) { return 1; }
-  flag = ARKStepGetNumSteps(arkstep_mem, &ark_nst);
-  if (check_flag(&flag, "ARKStepGetNumSteps", 1)) { return 1; }
-  flag = ARKStepGetNumRhsEvals(arkstep_mem, &ark_nfe, &ark_nfi);
-  if (check_flag(&flag, "ARKStepGetNumRhsEvals", 1)) { return 1; }
-  flag = ARKStepGetNumLinSolvSetups(arkstep_mem, &ark_nsetups);
-  if (check_flag(&flag, "ARKStepGetNumLinSolvSetups", 1)) { return 1; }
-  flag = ARKStepGetNumNonlinSolvIters(arkstep_mem, &ark_nni);
-  if (check_flag(&flag, "ARKStepGetNumNonlinSolvIters", 1)) { return 1; }
-  flag = ARKStepGetNumNonlinSolvConvFails(arkstep_mem, &ark_ncfn);
-  if (check_flag(&flag, "ARKStepGetNumNonlinSolvConvFails", 1)) { return 1; }
-  flag = ARKStepGetNumLinIters(arkstep_mem, &ark_nli);
-  if (check_flag(&flag, "ARKStepGetNumLinIters", 1)) { return 1; }
-  flag = ARKStepGetNumJtimesEvals(arkstep_mem, &ark_nJv);
-  if (check_flag(&flag, "ARKStepGetNumJtimesEvals", 1)) { return 1; }
-  flag = ARKStepGetNumLinConvFails(arkstep_mem, &ark_nlcf);
-  if (check_flag(&flag, "ARKStepGetNumLinConvFails", 1)) { return 1; }
-  flag = ARKStepGetNumPrecEvals(arkstep_mem, &ark_npe);
-  if (check_flag(&flag, "ARKStepGetNumPrecEvals", 1)) { return 1; }
-  flag = ARKStepGetNumPrecSolves(arkstep_mem, &ark_nps);
-  if (check_flag(&flag, "ARKStepGetNumPrecSolves", 1)) { return 1; }
+  flag = ARKodeEvolve(arkstep_mem, Tf, y, &t, ARK_NORMAL);
+  if (check_flag(&flag, "ARKodeEvolve", 1)) { return 1; }
+  flag = ARKodeGetNumSteps(arkstep_mem, &ark_nst);
+  if (check_flag(&flag, "ARKodeGetNumSteps", 1)) { return 1; }
+  flag = ARKodeGetNumRhsEvals(arkstep_mem, 0, &ark_nfe);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return 1; }
+  flag = ARKodeGetNumRhsEvals(arkstep_mem, 1, &ark_nfi);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return 1; }
+  flag = ARKodeGetNumLinSolvSetups(arkstep_mem, &ark_nsetups);
+  if (check_flag(&flag, "ARKodeGetNumLinSolvSetups", 1)) { return 1; }
+  flag = ARKodeGetNumNonlinSolvIters(arkstep_mem, &ark_nni);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvIters", 1)) { return 1; }
+  flag = ARKodeGetNumNonlinSolvConvFails(arkstep_mem, &ark_ncfn);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvConvFails", 1)) { return 1; }
+  flag = ARKodeGetNumLinIters(arkstep_mem, &ark_nli);
+  if (check_flag(&flag, "ARKodeGetNumLinIters", 1)) { return 1; }
+  flag = ARKodeGetNumJtimesEvals(arkstep_mem, &ark_nJv);
+  if (check_flag(&flag, "ARKodeGetNumJtimesEvals", 1)) { return 1; }
+  flag = ARKodeGetNumLinConvFails(arkstep_mem, &ark_nlcf);
+  if (check_flag(&flag, "ARKodeGetNumLinConvFails", 1)) { return 1; }
+  flag = ARKodeGetNumPrecEvals(arkstep_mem, &ark_npe);
+  if (check_flag(&flag, "ARKodeGetNumPrecEvals", 1)) { return 1; }
+  flag = ARKodeGetNumPrecSolves(arkstep_mem, &ark_nps);
+  if (check_flag(&flag, "ARKodeGetNumPrecSolves", 1)) { return 1; }
   if (outproc)
   {
     cout << "\nARKStep Solver Statistics:\n";
@@ -356,31 +348,33 @@ int main(int argc, char* argv[])
          << ark_ncfn << "\n";
   }
 
-  // Second call MRIStep to evolve the full problem, and print results
+  // Second call ARKodeEvolve to evolve the full problem, and print results
   t = T0;
   N_VConst(ZERO, y);
-  flag = MRIStepEvolve(mristep_mem, Tf, y, &t, ARK_NORMAL);
-  if (check_flag(&flag, "MRIStepEvolve", 1)) { return 1; }
-  flag = MRIStepGetNumSteps(mristep_mem, &mri_nst);
-  if (check_flag(&flag, "MRIStepGetNumSteps", 1)) { return 1; }
-  flag = MRIStepGetNumRhsEvals(mristep_mem, &mri_nfse, &mri_nfsi);
-  if (check_flag(&flag, "MRIStepGetNumRhsEvals", 1)) { return 1; }
-  flag = MRIStepGetNumLinSolvSetups(mristep_mem, &mri_nsetups);
-  if (check_flag(&flag, "MRIStepGetNumLinSolvSetups", 1)) { return 1; }
-  flag = MRIStepGetNumNonlinSolvIters(mristep_mem, &mri_nni);
-  if (check_flag(&flag, "MRIStepGetNumNonlinSolvIters", 1)) { return 1; }
-  flag = MRIStepGetNumNonlinSolvConvFails(mristep_mem, &mri_ncfn);
-  if (check_flag(&flag, "MRIStepGetNumNonlinSolvConvFails", 1)) { return 1; }
-  flag = MRIStepGetNumLinIters(mristep_mem, &mri_nli);
-  if (check_flag(&flag, "MRIStepGetNumLinIters", 1)) { return 1; }
-  flag = MRIStepGetNumJtimesEvals(mristep_mem, &mri_nJv);
-  if (check_flag(&flag, "MRIStepGetNumJtimesEvals", 1)) { return 1; }
-  flag = MRIStepGetNumLinConvFails(mristep_mem, &mri_nlcf);
-  if (check_flag(&flag, "MRIStepGetNumLinConvFails", 1)) { return 1; }
-  flag = MRIStepGetNumPrecEvals(mristep_mem, &mri_npe);
-  if (check_flag(&flag, "MRIStepGetNumPrecEvals", 1)) { return 1; }
-  flag = MRIStepGetNumPrecSolves(mristep_mem, &mri_nps);
-  if (check_flag(&flag, "MRIStepGetNumPrecSolves", 1)) { return 1; }
+  flag = ARKodeEvolve(mristep_mem, Tf, y, &t, ARK_NORMAL);
+  if (check_flag(&flag, "ARKodeEvolve", 1)) { return 1; }
+  flag = ARKodeGetNumSteps(mristep_mem, &mri_nst);
+  if (check_flag(&flag, "ARKodeGetNumSteps", 1)) { return 1; }
+  flag = ARKodeGetNumRhsEvals(mristep_mem, 0, &mri_nfse);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return 1; }
+  flag = ARKodeGetNumRhsEvals(mristep_mem, 1, &mri_nfsi);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return 1; }
+  flag = ARKodeGetNumLinSolvSetups(mristep_mem, &mri_nsetups);
+  if (check_flag(&flag, "ARKodeGetNumLinSolvSetups", 1)) { return 1; }
+  flag = ARKodeGetNumNonlinSolvIters(mristep_mem, &mri_nni);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvIters", 1)) { return 1; }
+  flag = ARKodeGetNumNonlinSolvConvFails(mristep_mem, &mri_ncfn);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvConvFails", 1)) { return 1; }
+  flag = ARKodeGetNumLinIters(mristep_mem, &mri_nli);
+  if (check_flag(&flag, "ARKodeGetNumLinIters", 1)) { return 1; }
+  flag = ARKodeGetNumJtimesEvals(mristep_mem, &mri_nJv);
+  if (check_flag(&flag, "ARKodeGetNumJtimesEvals", 1)) { return 1; }
+  flag = ARKodeGetNumLinConvFails(mristep_mem, &mri_nlcf);
+  if (check_flag(&flag, "ARKodeGetNumLinConvFails", 1)) { return 1; }
+  flag = ARKodeGetNumPrecEvals(mristep_mem, &mri_npe);
+  if (check_flag(&flag, "ARKodeGetNumPrecEvals", 1)) { return 1; }
+  flag = ARKodeGetNumPrecSolves(mristep_mem, &mri_nps);
+  if (check_flag(&flag, "ARKodeGetNumPrecSolves", 1)) { return 1; }
   if (outproc)
   {
     cout << "\nMRIStep Solver Statistics:\n";
@@ -491,9 +485,9 @@ int main(int argc, char* argv[])
   ARKodeButcherTable_Free(B);  // Free Butcher table
   ARKodeButcherTable_Free(Bc); // Free Butcher table
   MRIStepCoupling_Free(C);     // Free MRI coupling table
-  ARKStepFree(&arkstep_mem);   // Free integrator memory
-  MRIStepFree(&mristep_mem);
-  ARKStepFree(&inner_mem);
+  ARKodeFree(&arkstep_mem);    // Free integrator memory
+  ARKodeFree(&mristep_mem);
+  ARKodeFree(&inner_mem);
   MRIStepInnerStepper_Free(&inner_stepper);
   SUNLinSolFree(LSa); // Free linear solver
   SUNLinSolFree(LSm);
