@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -89,7 +89,7 @@ static int ytrue(sunrealtype t, N_Vector y)
  *   [a  b] * [ (-1 + u^2 - r(t)) / (2*u) ] + [ r'(t) / (2u) ]
  *   [c  d]   [ (-2 + v^2 - s(t)) / (2*v) ]   [ s'(t) / (2v) ]
  * ---------------------------------------------------------------------------*/
-int f(sunrealtype t, N_Vector y, N_Vector ydot, void* user_data)
+static int f(sunrealtype t, N_Vector y, N_Vector ydot, void* user_data)
 {
   sunrealtype* udata  = (sunrealtype*)user_data;
   const sunrealtype a = udata[0];
@@ -117,8 +117,8 @@ int f(sunrealtype t, N_Vector y, N_Vector ydot, void* user_data)
  *   [a/2 + (a(1+r(t))-rdot(t))/(2u^2)     b/2 + b*(2+s(t))/(2*v^2)         ]
  *   [c/2 + c(1+r(t))/(2u^2)               d/2 + (d(2+s(t))-sdot(t))/(2u^2) ]
  * ---------------------------------------------------------------------------*/
-int J(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix J, void* user_data,
-      N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)
+static int J(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix J,
+             void* user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)
 {
   sunrealtype* udata  = (sunrealtype*)user_data;
   const sunrealtype a = udata[0];
@@ -145,7 +145,7 @@ int J(sunrealtype t, N_Vector y, N_Vector fy, SUNMatrix J, void* user_data,
 // -----------------------------------------------------------------------------
 
 // Check function return flag
-int check_flag(int flag, const std::string funcname)
+static int check_flag(int flag, const std::string funcname)
 {
   if (!flag) { return 0; }
   if (flag < 0) { std::cerr << "ERROR: "; }
@@ -155,7 +155,7 @@ int check_flag(int flag, const std::string funcname)
 }
 
 // Check if a function returned a NULL pointer
-int check_ptr(void* ptr, const std::string funcname)
+static int check_ptr(void* ptr, const std::string funcname)
 {
   if (ptr) { return 0; }
   std::cerr << "ERROR: " << funcname << " returned NULL" << std::endl;
@@ -214,8 +214,8 @@ int main(int argc, char* argv[])
   void* arkode_mem = ARKStepCreate(nullptr, f, ZERO, y, sunctx);
   if (check_ptr(arkode_mem, "ARKStepCreate")) { return 1; }
 
-  flag = ARKStepSStolerances(arkode_mem, rtol, atol);
-  if (check_flag(flag, "ARKStepSStolerances")) { return 1; }
+  flag = ARKodeSStolerances(arkode_mem, rtol, atol);
+  if (check_flag(flag, "ARKodeSStolerances")) { return 1; }
 
   SUNMatrix A = SUNDenseMatrix(2, 2, sunctx);
   if (check_ptr(A, "SUNDenseMatrix")) { return 1; }
@@ -223,35 +223,35 @@ int main(int argc, char* argv[])
   SUNLinearSolver LS = SUNLinSol_Dense(y, A, sunctx);
   if (check_ptr(LS, "SUNLinSol_Dense")) { return 1; }
 
-  flag = ARKStepSetLinearSolver(arkode_mem, LS, A);
-  if (check_flag(flag, "ARKStepSetLinearSolver")) { return 1; }
+  flag = ARKodeSetLinearSolver(arkode_mem, LS, A);
+  if (check_flag(flag, "ARKodeSetLinearSolver")) { return 1; }
 
   sunrealtype udata[4] = {-TWO, HALF, HALF, -ONE};
 
-  flag = ARKStepSetUserData(arkode_mem, udata);
-  if (check_flag(flag, "ARKStepSetUserData")) { return 1; }
+  flag = ARKodeSetUserData(arkode_mem, udata);
+  if (check_flag(flag, "ARKodeSetUserData")) { return 1; }
 
   // Initial time and fist output time
   sunrealtype tret = ZERO;
   sunrealtype tout = tret + SUN_RCONST(0.1);
 
   // Advance one step in time
-  flag = ARKStepEvolve(arkode_mem, tout, y, &tret, ARK_ONE_STEP);
-  if (check_flag(flag, "ARKStep")) { return 1; }
+  flag = ARKodeEvolve(arkode_mem, tout, y, &tret, ARK_ONE_STEP);
+  if (check_flag(flag, "ARKode")) { return 1; }
 
   // Get the internal finite difference approximation to J
   SUNMatrix Jdq;
-  flag = ARKStepGetJac(arkode_mem, &Jdq);
-  if (check_flag(flag, "ARKStepGetJac")) { return 1; }
+  flag = ARKodeGetJac(arkode_mem, &Jdq);
+  if (check_flag(flag, "ARKodeGetJac")) { return 1; }
 
   // Get the step and time at which the approximation was computed
   long int nst_Jdq;
-  flag = ARKStepGetJacNumSteps(arkode_mem, &nst_Jdq);
-  if (check_flag(flag, "ARKStepGetJacNumSteps")) { return 1; }
+  flag = ARKodeGetJacNumSteps(arkode_mem, &nst_Jdq);
+  if (check_flag(flag, "ARKodeGetJacNumSteps")) { return 1; }
 
   sunrealtype t_Jdq;
-  flag = ARKStepGetJacTime(arkode_mem, &t_Jdq);
-  if (check_flag(flag, "ARKStepGetJacTime")) { return 1; }
+  flag = ARKodeGetJacTime(arkode_mem, &t_Jdq);
+  if (check_flag(flag, "ARKodeGetJacTime")) { return 1; }
 
   // Compute the true Jacobian
   SUNMatrix Jtrue = SUNDenseMatrix(2, 2, sunctx);
@@ -302,7 +302,7 @@ int main(int argc, char* argv[])
   SUNMatDestroy(A);
   SUNMatDestroy(Jtrue);
   SUNLinSolFree(LS);
-  ARKStepFree(&arkode_mem);
+  ARKodeFree(&arkode_mem);
 
   return result;
 }
