@@ -1,6 +1,6 @@
 /*------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -14,8 +14,8 @@
 #include <sundials/sundials_core.hpp>
 #include <sunmemory/sunmemory_system.h>
 
-int test_instance(SUNMemoryHelper helper, SUNMemoryType mem_type,
-                  bool print_test_status)
+static int test_instance(SUNMemoryHelper helper, SUNMemoryType mem_type,
+                         bool print_test_status)
 {
   // Try and allocate some memory
   int N                 = 8;
